from random import randbytes, randint

from slhdsa import KeyPair, sha2_128s, sha2_128f, sha2_192s, sha2_192f, sha2_256s, sha2_256f
from slhdsa import shake_128s, shake_128f, shake_192s, shake_192f, shake_256s, shake_256f


def _for_all(judger):
    judger(sha2_128s)
    judger(sha2_128f)
    judger(sha2_192s)
    judger(sha2_192f)
    judger(sha2_256s)
    judger(sha2_256f)
    judger(shake_128s)
    judger(shake_128f)
    judger(shake_192s)
    judger(shake_192f)
    judger(shake_256s)
    judger(shake_256f)


def test1():
    def judge(para):
        kp = KeyPair.gen(para)
        msg = randbytes(100)
        sig1 = kp.sign(msg)
        sig2 = kp.sign(msg)
        assert kp.verify(msg, sig1) and sig1 == sig2
        sig3 = kp.sign(msg, True)
        sig4 = kp.sign(msg, True)
        assert kp.verify(msg, sig3) and kp.verify(msg, sig4) and sig3 != sig4
    _for_all(judge)

def test2():
    def judge(para):
        kp1 = KeyPair.gen(para)
        digest = kp1.digest()
        kp2 = KeyPair.from_digest(digest, para)
        assert kp1.sec.key == kp2.sec.key and kp1.pub.key == kp2.pub.key
    _for_all(judge)
def test3():
    def judge(para):
        kp = KeyPair.gen(para)
        sec = kp.sec
        pub = kp.pub
        assert len(sec.key) == 4 and len(sec.key[0])==len(sec.key[1])==len(sec.key[2])==len(sec.key[3]) == para.n
        assert len(pub.key) == 2 and len(pub.key[0]) == len(pub.key[1]) == para.n
    _for_all(judge)

def test4():
    kp = KeyPair.from_digest(bytes.fromhex("0bd44144e520a2eb669edbc659658ad2a24f91ac5f65006acea5e34008e1fbef148f89dd363bd277d2b0105bd250f152891e1ae7e5125045c644f342aa50b6f10bd44144e520a2eb669edbc659658ad2a24f91ac5f65006acea5e34008e1fbef"), sha2_128f)
    sig = b'uWw\xbd\xb4\xa78\x10,\x14GmD5\xa278\xf40\x8cO\xec\xec\xf4Rf\xe8\x05>c0\xfe\x88\xb5\x1b\xf3\x13\xcd\r\xd9mP\x12\xe3\xa7\xa5|\x8f\xf2\x8c0\x92\xef]B\x89H\xc9\xda#\xf6\x11\x95\xa7C\x19q\xd1YHJ\x96\x08\x1c\xc7\xfc\x90\x8aB\x85\xfc\xfd\xcd\xfbX\x88\xc3fD\xec\x19\x07zqp\xe0\xcf"\xce1\xab\xcf\x06^\xe5\n\xfd\x80\xe5&bg3~\x1c\xbb\xff\xefKW\xadj\x99]c\x8d\xa7T\xa2\x15\x8ca \x98l\x80\xa1\\\xd8i\x9d}\xe0C\xdd+\xaf*b&HH\xa6\xc8O\x94\xab\xf7\xac\xfa#S?\xd5\xf9\xee$+\xc4\xf05\x11\xa28\xe0\x80\x98fA[BB\x91CP\xb0/>xtq\xe8\xce\xcd\x1aU\x19J^1\x83\xdb\xe66h\x9a@g\xb08\xc1J\x02\xa1\xf8\x13s\x8eR\xfd\xe5\xbd\tP\xcf\t\x99\xe3\x85\x8fC\xb3\x8b\xd5bdU\x12\xaf\x85A\x8dA\x81\xf6\xaf\x82\x0f\xcc\xba\xe4f\xc9f\xc9Z7\x7f\x12\xaekGS_\xf4c\x00\x17~Oj\x14\r\xd5\xa4\x02\xb7k\x84\xd1y\xf6\xd5\x8d\x88\x87c\xcf\x95\x82j\xb9N\xba\xe8\x03\xf5\x93V\xc8"YO\xb1\x9b\xe2\xe1\xa5\xc7\xd1J i\xe1\xdcfP\x97:\x16.\xc2\x05\x89\xaa\x9b_f\xd0\x91\xaf\xe2J\xd9I\xad7@\xc7\x186\xad\n\x87\xbcs\xcc9\xc9\xf9\xc0\xabYK\xad\xb4\xe6M\xdd\x1e\x8b=V{\x19 \xc3\x8e\xd9\x19\xa91\xe1a\x94\x8b\x84\x8d\xf8\x93\xfb\xddQ\xc4\x7f\x12\xbe`\xb5\x8f\xc8\xd0\xddJ\x8a\xe8\xc7\xd08`)ZZ@\x89}\xd3\x93\xdf\x1e\xd1\xa1\xc4\x97\xc0\t"lO\xf9\x8epN\xea\xd2\xfd\xd8{yY\x9a1\x9c\xa5\xb0\x81\xae\xb7\xd2\xa0\xc6\xc6\xd2\x0e\xd1\x93\xea\x0f\x99>)\xb7\x82xE\xfe\xc9\xa4Tvr\xfb=\xd1ph1Y,\x99\xfa\\\x95/\x03;\rP\x8cc$H\xc7-\xecR\xe5\x16jPN\xf4Mt\xbd\x97\x8c:1\x89&\x15/:\x1c\xf2\xfb\xc7T\xc6\xf5sC\xbdOlv\xf3\xd4?\xd2\xd6\xb4%\xa3\xad!\x16\xacQe\xd7\x9dp;\x08O\x04\xc6\x9b7H\xa3*w\r>\x96\x8a<\xf5\x0br\xf1V\xc3f\xc1\xe1<\xf7n\x8b\xc3!\xa6j\rR\xc2\x97\x7f=\xb1 \x82\x82\xcc$\x82\xbc\x1cP\x11{\x8dL?\xb4\x07\xcd\xa6\xd7\x0c\xe5:\xc6\\\xb8ple\xcf\x9b\xd4v\x11\xbc\xb6\xd9v\xedx\xec\xf45\xe5+\x80\x82\xe4I\x00\xed\x03\xd9q\xf7P*\xef\xfa\xe0\xcaY\xe0 \x9b\x88\xc3\xb3\xb0,\xfe\xe4C\xea\xd8\x01W`\xbeYf\x17\xa5\xcfN\x8b^xH\xb7I\xfaT8Q\x08uj\xd2\xe5\xea\x83\xa2\x0c\xe6Z \x0e3\xae\xe8\xc1\x8585r.v1\xc5KT\x98\x8c\xafTJ\x8b\xa4+R\x98\xda\x89\x9b\x04\x88W\xea\xf8M\xcc\x12\x12\x0f\x7f\r\xc0\xb4_\xff8\x7f\xc42\x1f\xdboc\xf3~=\xc2\x0c\x8f\xdb\xb9\xfdp\x8b\x1a0\xab\xc2\xd4\x86\xdb}\x19\x87\x86\x98\xcfo\x05EI\xf2\xb6\x86e\xb9~\x14\\\xb1\xdf\xecV\xa7_!\xc1\xc2_\xf3$\xd7\xa7\xf1f\x0f\x92\x1c\xc9\x16\x90\x8fm1"\xf7\xd0\x12($p_!>\xacAg\x14\xb6\x84\xad\xcd/\x91H\xbd\xe6\x9d\xc6\x1f\x16^\xb5M|\x8f\x95\xb3 %\x13\x8f\x97\r\xbfu\xcaf?\n \xc3j\x9d;E\xf6\xaeF\xc8F\xc5f\xd7\x8fw\xac0!\x8c\x92\xca!\x08\x82\xe6\x08\x9a-]\xb9~\x03\x80\xeb\xf8u\x9d xn\xbe\x1f\x13\x05\xf8\xe0E\x80-s\xbfP\xd5/T\x96_\x0c\xfb\xbd\xd89\x96\x8b\xf1\xbd\x90\xe7J\x87Z\xa5\xbe&EZ\xf2\x8c!\xc0\x9c\x05\x1c\x02M\xa8:\xc9y\x02z{\xb77h<\x1a\x1e\x18\xa6j\x93\x8b\x1a\xbd@ \\q\xbaH\x96\x9a\x93\x93\xb5;\x05w9\x1e\xf0\xc3\x9cX\xdc\x1a\xecU\x0fv\xfa\x19s\x12\x14\x8a\x82\xcc}\x9em\xd8\xbe\xbb\xfa\x9d\xee\xb5\xad\x02\xaa*\xee\x95<P\x1b\x97\xbb\x9d\x1a%w\xad\x11F\xcd\x9a\xda\xce\xe2\x97\xf96(\xf2\x1aLq/\x02+\xea\x95Vd\xeb\x18K\xa3*^\x97\xfdH,2\xd0\xd2\xa6C\x07\x1aH\xcbD\xbc@,\xb2\xff\x1a\xb1h\x1f}\xa9\x83e\t\xe2\x9f\xe4Wh\x8c\x10\x7f?b\x96\xc4\xab\xf0\xc7E\x0f\x05O/0<\x04?0\xa9\xec\x90N\xa3\xedD\xb9~\xeb_A\xf4\xa0\xc8P\xe7\t\x0b\x85)\xa8\x1b\xc8\x1a7\x84\x96~d\xa9f\x08\xac\xe6\x89\x1b\xf9f\x85\x92\x07\x8b\xd1\xb3\xb3\x1d\x0bS\xbb\xfb\xa4\xf1\xf4\x1ej~\x9b=\xafB-\x0c\xbc\x93\xbe\x1d\xf8\x87R\xa6\r\xf7<\x1b\x12\x184\xff\x93K\xf7+\xfe\x9e4\xe0&\x7fY\xde._4\xb5HE\x01\x96|UVMZ\x91<\r\x94\x1e\x985\x03\x8e\x86&\x12g\xab\xac\x03\xf4\xe0\xe9\xf8\xf0{Z\xc4\xfe\xad\xb0&:\'`/\x0b\xb7>-O\xc5O\xa6\t\xde\xfer\xa7\r\xb7S\x17\x036\xd3\x82\xf0\x01\xba\xe0\x01t\xa8\xb7\xc6\xd8J\x9d\xb4E\xf5\x1e\x9c&X\xb5\x83\x9d\xe1\xd6\xab\xe5\n\xfc\xce\x17\x86R\xf8{\xed\x1b\xc5\x0e\xf6\xbf\xb3F\xde\x07\t6\xc9;\x82\xd0Z\xd7\xd3\xbcQ\x84Z\x04\xc1d\x9e!\xf8 z\x9a\xa4\xa9\xcb\x88\xa3*\x92\x13f\xaeTx\xb9\x11\x16\xd6\xc4=Dd\x89<\x84\xa0\xb0\xdceb\xc4\x08\x8f\xabmF\xd1;\xb7a\xd8\x95y\xf4\x16\t\x9fN\xc8\xe3PT\x81\xe3>T\xf1\xd9\x95\xee\x08\xce\xe9\xa2\xe2\xed\xb3\xc7\x0c}\xd3\x17\x9e|\xe9\x87\xb4\r\xb7H<;\x19\x87\xc0\x85P(\xff\xa3\x80e\x08\x9d#\xe9do\x06\x84\xa0\xa9\xce\xdf\x9d\xb9;.\x94\xcdD|`e\xfe\xe93m\xf1\x92\xba\xf2\x85\xe5\x0b\x1b\x8a\xad\x9a&\xe7\xc1\xa5eT\xf7\x93\x8b\xda\xe9Wf\xf2\xc3\xd9uUd\xf4\xc1\xfc"\x1f\xb6I\x10\xa8\x88q\x8bK%Wf\x017\xee#;8\xcb\xfbY.0!\xbdpP\xc15:\xba\xcd[nV\x8f\x06\tg;=\xbdk\x00\xbat\xaf\x0b\x93\xfa\xf5\x0e\n#\xa4a\xfd\xaf4\x06\xe1A\xf2\xae\xd2\xad\xd9\x9f\x9a\xe5A"ZP\xab\xe5b~\xe4\xd2\xb3=\xef\t3\xe6\xd2B\x07\xe8\xfa\xec\x1fD\x19d\xdd\x1a\xa5\x9fvo\xb6~?\x15\xd7*.$\x97\xa2\xe2\xff\xf9\xbc0pT\xf2\x80\xedunp\xcaO\xce}\xe5k\xfcd\xda\x9f_\xa1;\x0b?\x0e\x85\xab\xe4\x10\x9d/\x12\x18\\\xe8\xe0h\xec\x7fi&\x93\xa0\xc9Wn0\xc8\xa7\xc6\x1a\x1c5\xd1p<\xe7J\xca\x9a\xf1\xb2C>VK\xceP\xdf\x19?\xd8\xfa"=\xadX\xafI\xdaP\xdb=\xf7>4o\x93\xbd*6\x143l!\x80\x00\x8c"\xea\x13VX\x98=B[8\xc7\xc1c\xbe\xcd\xba^/\xbcWP\x94\xb0Y\xe7\x87\xff\x02u\xa8\xd7uRX\x8e\xf5\x05\xc8#\xa1\xcaF\x13W*\xb7\\\'\xfdS\xb30HljpC\x90%\xa5\x1c\xa4\xdc\xf5x\x1bt\xebE\xcct\x86\xcb\xeeqh\x1f\xf3\xc7_\x17N\xc6\x87%\xba\xc9\xa3\x06\x10%\x7f\x00o\xbf\x83\xca`\xf9\xe4X4`\x9f\xcaXo}GA\x9bc\xa5\x0f!\xd7\xf4\x83\xd55$\x92\xc8\x83\x8b\xa9\x00\xcbk]d\x11`Z\x1b\x11wS\x82\xdd\xd2o\x05L\xd3D\x88\\\x9b\xb8kIN\xc7\x0fM\xe1_\x91Fm&\xb5\x8e\xc8\xb9\xe0U\x89Ja,\xb4\xa6l\x7f\x1ew\xaa\xc3t\x9d\xf0\xc2k\xe0mB\xff\xa5\xd6\xf52\xd59\x15J\xab\xa8\xb4\x98\xab\x19w\xc7\xbb\xdaA\xf8-~\x91\x89F\xb4\xc8L\x06i\xf9\xb3u\xe4R\xd2\x13\xe8\x82\xb9\xba\x1dk\xf2\r:\x91H\xd2]\xd5eS\xffZ\xe5c>\xcf=~$0\x03\xc6\xedM\x90*\xfd\xdc\xdd\xb1\xde\xf4\th@\x92\x9d\x87\x02P2#\xed\x0f\x87\xab\xc4c\xc5u\x14\xb4\x10"H=\x8f3\x1f|%i\xf8\x90\xe5\xbd\xbcVG&\x93\x0e\xd6Y\xdf\xf2\xf9d\x1d\xda6\xa3\x9at\xe9\xabp[\xb4\xdb\x97A;p(\xe8D\xe8J+s|*D\x13\xab#\x9e}|\xc33\xdfyn\xa7\xca\xfd\xa5rn\x0e\x08!\x8e\x845\x9bd\xd8{m6Kr\xd0q\xf11NG\xa1\xa1\xb9M/kO\x9e=\xde[v\xfb\xe5\x90RC\xb7\xab\xa7\r\x01\xe9Y\x93H\xd9\xe8R\xa2x\xc3\xb8\xddT\x05\xe8]\x169#\xcd\xd23\x06\xf3\xc7\xebN\xa9r\xdeS\x92\xdd\'\xa1\xe4\x98X\xd7\rO\x15\xe7\x94}\x9a=\xc1\x88\xc9\xe2\xf8\x91\x0fU*\xc2\x12Y\xec"d%\xc80\xf3\\\x95i\x9ar\x90*\xba\x8d\xea\r\x07\xfd\x0e;3\xd4\xdb\xc2\xfc2\xbd\x9a\xd01[\x1f\x15~\xc5\xb4g<wD\xf8\x11\xf4\xe8P\xc2\x1abd;\x95\x07\x93\x02\x9c\x93RVXv\xa8.\xc8Z-b6\xe2\xd98\xae\x92yR\xa7m\x10\x12\xb5u\x15\x91\xae\xce\xe1l\xc6d]\x17*}U\xe1\xa2\x81U\x95$G\xc8\xe1\xddVz\xff\x93\xa1\x05\x84\xbe\xefvz,\xe0T\x95\x14"\xd1\xe0\x90ra\xf9\x00/\x9es\x1apD@\xd3]\xabi\x12\xe4\xd0`\xdf\x042\xf5\x8e\x80\x8bt\xc8}n\xc1u\xebho\xb4\x83\x8c2\xc4\xcd6\xc59\xe4:\xe7\x93E\t\x9a\xf0\xb7>\x03"\xea\xab\xa1_\xaeSY\x86\x96h\x8ak\x935\x90\xf7\xb4|\x8e\x9b\x93\x10\xd2\xc6\x9e\x9b4\x9c\x84\x8a\x9c\x15\xb7\xb9\xb4+\xf2\x0e\xd8\x987(\x19\x91\xf6\xfa\xf9\x9di\x966Y\xda,\x8f\x00\xb2\x8a*\xe2M"\xba=\xae0\x1dW\xf9@\t\x81\x17\t\xb6}*\xec,c\x068y\xd2o\r_\x80\xd8\x93\x9b\xc3\xa7m\xe5\xa3\xe1\xd8Z\x9c\xbc^\xcf\x08\x91\x1a\xe0\x90S{\t\x03Gl\xbd\xcf\xf1\xdc\xf4f\x81\x08\xdc\xfb&g\xc7\x8a\xe1\xf5\xb9B\xcb\x1a\x96\x816\x0e\x9dE\x1d\xa6\xf8\x0f8)V\x85d\xad\xef\xfd\xce\xb6\x9b\x02\xbb\x0cl\x1c\x94\xaa7\xf7\xbc\xba\x18}\x1d\x9c\xa1\xf4\x83`\xc1\xebL\xf8\xa7\x8b\x94\x12\xc3\x14\xd6\t\x13\x17*\xda\x19\x94\xc5\xbbp\x05+\xe1\x02\xa9\xe3\xf5\x16\x0f\xd5\x19#\x8c\xb9c\xa7;\xd1\xc4t\xbe\xd3q\xf5I\x91\x16\x13\xcfqi"\xf6|\xa5\x19\x08\xaa2\xd9gc\x01\xd1D;\xbb\xb7\xf0\xc7)\x95U\xa1\xc4a\xf2\x7f\x84D\x1bS\xf5\xddS\x1d\xab8\xad5D\xf9\xd8~\x10\xc5\x80\xdfj\xa3r\xf9T\xd1!\x99T\xe9\xf8\xcf\xec\xe4\x18\xa8\x1cZ"\x9c\x10\x9fe\xb9\xc0\x7f\x80\xebt\xcb\xf2rx\xfa6\xf0\x06\xb0u\x0c\xfa\x85\x16\xca\x86\x82\xca\x1d\xa1\x93tg|\x14\xc4\xad4\xe4@\xb8\xed\xdf\xe7\x7f\xe7`\xd8\xd0\xb5\x93\xcb\xc9\xa3 \xf4F\x07j\xf8\xe8\\\x9a\x88C\x80\xcf\x01tQL\xef0$\xa3\xee,\x80\xf7\xfd.\xf6\x0fp\xe8\xb2\xdb\xd1\xaa\x9d"\xd1\x9b\xb5\xa3k9_C\xec\xff\x0c\xca\xa0\xea\x07.\xeb\xdb\x1cg\xc7\xa2yw{\xdc6\x89\xe2\x9f3\xc1t\xc8\x00\x96\xe8\xe0kSP\xb22\xae\xab\xfcm\xad\xea[\xcdj\x0c\xd6\xeb\x95\xce\x86\xa2\x1d_\xcc\xf2\xb1N\x9d\xc1\xf5\x88He\xa1\x8c\x8c\xc0\xa1\xb4\xda\xfa\xc5\xf5\x83[&\xcc{\xab\n\x80|A2\x8eSV\xfb\x88\xa7$\xfe\x1a\x89-#-I\xa1y\x80\xe7*\xc9m\xd9\x1a\xe2\x97[[q\xa3\xb4}e\x19\r\x8e\xd5\x8c]\xb2\x8e\xb3\xb5\x13\xa11\xa6\x95\x94i\x95\xad\x14Z\xcb%|\xf0A\xd6\x971\xc30wO\x82\x1f\xd5\xd9\x11\x8bI|\x91+`t%0\x8esh$^\xae\xdbC\xe8\x0e\xd9\x0f\xdb\xd8dk\xc8&\x8dh\xc0p\x04u\xbf\x808\xb9 :\x01\xd5w\x10\'X\xbaF\x08\x91f\xfa\x13\xe7\xbf#IJ\x8b\xf6\x0b\x87\x99\x94|\xa1R\x0f8q\xfb\xb7sh\xbe\xda\xe55\xba\x1fh\x8f\xf6\xf6_|D\xa2\x88\xcc\xd1\xbc\xa5\xb3\x01d\x8a<i\xaeU\x8c\x00*\xac\x00\xba\xed\xd31\x1f1\x86\x16\x89#\r\xf3\xba\xd6\xb4\xca6&_p\xa4\xfc$\x93\x95\xbbVQ\xfe<69\xd8F\x81\x0f\xe5\x8d\xa3\xbb\xa9r\x90\xcf\x07\x05\xd1jD\x9d#\xbbh\x92\x15\x88\x9d\xa5\xb0/)g@I\x15AFj-h\x07\xebB%h$G\x82\xe5\xbc\x11\x9dJ\xd8\xd3\x93$J>\x8a\x9eu\xfe^\x14+w\xf2s\xcd\xb6\xf6\xf0\xa7\x08\x94\xfe2\x03\xb1\x9de\xd7\xa1Qbp\xf1\xf9\xa2\x12\x1fQZ\x96%\x99\x8c\x91\x82-\x06\xcb.Y\t\xc4<i\xa7k\x9b\xe6\xec\x8c%\xf3ryg\xaf\xadfv\xf1QGde\xf1\x86\xd0~\x9cP\x1f@\x1d\x9f\x97)\xb7\x92\xa3\xff\xbf\xb4T\xc8\x06Y\xe3\x93\xe1F\x01.Y\x86}\xb8\x0c\x1aR\xbbA\xce\xad\x93\xc8\xde\x90\xc2\x7f\xf2\xb1\xabgD\xab%&\xb2#/O\xfc/ZK\x99\x91W\x9b_\xb7\xf6\xc3K3\xd7\xe7A!M\x9b\xfa\xfe\x91\x9c(\xf9B\xd6x\xa6\x88\xfe\x878\x10r\x01\xee\x8cm\x99c\x08\x93J\x0b\xbad\xd7~\x84xd\xfd\xf1\x8fP#^\xef\xa7\x0b6\xa9c\xf0\x1b\xc3F\xaagi\x955\xa8\x0f\xab\xe5\xf2\x97\x80\xd4\x7f\xffj\\\x94\x04\x17B\xb4\xdf\xe7\xfa\xc6\xc7\xc4=\x16\x0bp\x9a\x0ca\x16b\xa2k\x8b\x8e\xd9\xdakal\x9f\x840\tc>\xbd\x97\xd3\x9d\xea\x14U\xb4$\x0c7\x9f9X\xed4\xc0\xb6\xb0\x99\xea\x1b\x86Y\xec\xdbPW\x0b\xe41\xb3\xa60\xdb\\\xb3\x1b50\xd2\x15\xfa\x92K\xe7\x13xCk\xb6\x0b/hi\x05\x0ec\xa5\xb0\xf2n\x957&\xb0\x9b\x81h\xc1\xa3\xedwd\xb0\xb6\x94\x82\x17\xde\x81Tr\x0b\xe2\x95\x9c0=cR~iY\xd98\xb5bGI\x01\x13\x19Ho\x8a\xdf\x99\rG\xc3\xa9mEL^\xbe\xd1\x9b\xe2\nL\xd1\xb0i\xd9\xdb\x9a\xdb^c\xdc\x06\xdea\x984\xb1\xe5I\xd3\xeb}8\x90!j\x95\x8c\x1d\x1ce\xbc\r\xc9\xbb\xdb\xdcT\xed\xf8ki5\x14WS\xc3\x06\x00\x1e\x9a\x1f\x18iXy\xa8\xe3\xbf\x8e67\x9d%\xd7<\xe05\xdb\xca\x11Z!k\xda\xbdx\x86\xc2\xe4\xd9\xc1Z\'+\xb0aSM\x8d\xaek@W\xd1\xc9\xcb\xed\xf0Tx\x1c\xaf\x84\xc6DG\x0b3\x03\x10\xbf\xe3 \x1enb\x0f$\xcbh\x9c\xfdI\xd0F\x18\x96\xfdV\xa2\x18\xa0\xbbk\xd3x\x83\xa7\x11`a\xb2/\x03\xcf\x06-\x92}\xd8\xaa\xe7\'\x8f=\xa7\xd8\x8e\x88Z\x19\x10\xbc\x14"\xa5/\xa3zE\x92J\x86\xf3RC\x1e\xb5h\x1c\xf8\\HPRTF\x1a\xbfV\xb8+}aix\xac\xba\xa2=\xa2\xd1 \xa4\xdbQQ[,\xb7\x9b\x04!\xaaX\xa9\xe4P\xc2"\x9dS\xc7\xa1~E\x96\x91\x16N\xc3\x0eC\xd0TD\xac\\\x99\x14k\x90\xec\x0e?*j\xa6\xd6\x15u6ZP\xf8k\xe4/#YT\x0e*\xdf\xd5\xc1\xd4[5\xaf\xc8\x15r\xb0\xeb\x88:\x13\xa9\xb7\xc6\x95\x1fE\xc4\x0e\xb4\x10\x187L\xe5\xb6_\x9d40\x98t\xa4\x98\xado\xb7\xf8\xa5@J\x97\x17,\x9f\x11\xab$+\x8f*\x91zh\xbb\xd4B\x85\xcf0\x15o\x8e\xcb\x8c\xe8dA\x8d\xcf\xcf\xb4.\xb9\xd2v\xfe\x12E\xd9\xec\xbf9{@\xe3\xb9R\xec\x93\x1fh\xef\xad8\xe4$\x0e"dZZ\xa5\x99\xa0\x81\xdf5\xd3!\xb8r\x96\xc8IKB\x9d\x05\xc2\x15 B\xe0\xfd\xeb4\xcfS\xbe\xb2 \x05\xde\x94l\x08C\xe5\xd1\xc2eW\xb0^3\xfeT\x0bW\xa6\xeb.\x1c\xb2\xb81\xca\xe1\xb0\x02]a\xe5\rp\x1bZ3R\xf6.B^%\xa8\xff\xcd\x89\xec\xb6\xdf5\xa2b\xff\xa5\xbb&\xdd0x\xd19\xa74%\xaa\xa28cI\xca\x1a\x12V\x1b$e\xac\xf0*\xe0j \xea\xe9\xba\xe0\xc0\xfe0\xeel\xdbS\xc8\xf4\x9f\xe0"1\xfco\x8f\xc9\xf0W\xb8\xa1\xbet\x91\x05*\x87\x8b\x95\xfc%\xc6L\x9bc\xb8\xb4\x91M\xfe\x92@\xe5\x1fU\tl\xed\xbf!\xc4\x18.\x8eM\xe66r\x9f%\xa0\xaa\x90\x1a\xbf\x1dL@\x10a;\x9b\x8e\xef\xf7\x19]5\x8d\xa0?\xa9\xdc\x91.;\xc2\xde\xb8\xc5|\x18\x0b\x1f\xa9\x14s+,\xc4\xc2\x04x&\x1e\xac\x9a\xf6\xff\xde\xc6&\xbc\x08?!o\xf6\xf2H\x97\xa1\xf6\t\xc0\xa6\xec\x03P\x03\xddH\xb3\x85\xcd\xf5S\xa1\x95\x82\x0bq\x99~f3\xf1\xadB\x1d\xb7Hd\x9b?\xd8Y\x8f\x8b\x02\xd1O\x89\\\x9b\xcc\xd77)e\xcdv\x04\x93\xa4>\xa2Q\xbb\xff~9\x05\xa2\xd9\x12HcD7wb\xb0\x82J\xb6\xc9\'3\xb5Zp\x0f\xdfw\xe4\x83\x07 T\\\x99I\xc4\x14X\xca\xc7\x19\x85\x0e\xbf\x8e\x83\\\xef\x9f\xabE\xfe>\x15\xda\xc8\xd1\x85h\x80X[I\xc9\xc9Y\xc6\xe2\x15\x19\x02\x18\x84z\x13D\x05c\xb7\\\xc1\xdb\x06\xac\xb4V\xf6\xca\xd1\'\x9e\x92@b`\x8f\xc2\xce\x979%\xa9w\x1c\xaaQ\x93\xbcf\x9d\xa3J\xa6\xbajy*\xb0\xe1\xca\xc8X/\xd1\x1fd\xa7\xcbs\xbe\xd5\xc9|O\x8a\xdbK\xb1\x0b\x81\xb9\xc9v<\x83i\x8a\x99\xa2\xd7r\xd1\xeeH\xcamB\xe9\x97\xd1\x92\xc79\xfb\x1bK\xf24\x97_\xf8\x8e\xf4\xc1 &\x96\xa9\x11J\x08\x04\xe4\x86\x12\xc3\xc8\xc8\x06`l4G!\xc4\x94\xc2c\x8c\x81\x18\xf3\xed\x91\xd3U_\xa3\xff\xa1\x84\x99\xe2\xdbf/\xdat]\xa6\xea,<\x94\xa8\\\xc5\xdf\xdc\xae\xb1)3N\x00\xee>\xa5$~~\xbfN\xb6\xce\x0f\xe1\xf1\xa9Q\xc4\xe7r\xa4\\\xb6|\xc7\x9e.\x83\x9f\xd6\x8a\x9a\xa68b\xcaw\x8b3\x18\xec\tV\x95\x06N\x16\xf8\x06k\x81y^\xbfc\x04\xa9\xd4\xc1\xde\xb6T\xc7\xc0EN\xdc\xf6!\x91\x83\xf7\x9cY[\xc0\xd4\xab\xb8\x03\\,O\x14\x820t\xbaZ%_\x04\x18\xe0*=kZ\x95\x9d\x87\xb0\x9a\xdb\x8e\x01\xfa\x12XQ\x94\x02\x85\xc7L\xd6\x147\x0e\xfc:P\xa1\x8d\x95\x7f\x85[\xcc\xcb\xad\x15\xca\xb4\xd6\x0b\x90\x94\x95\xc2\xd9\x03/^qA:\xdbf\xbcB=\xd9;T8\xe1c\xaaI\x00\xccN\x1bb\x94\x17e\x15-m\xb4\x92\xbd2\x83P\xcc-\xd2r\xcdS\x9cV\xdbh\x12\x1c:3\x9e\x8f\xb3\xc9\xea=p\x8b\xac\x7f)\x9eB\xf38\xd2\x12\xd0\xd3\xa7\x96\x96Et\x8aJ\'Nw;N\xe5\xfa#\xbcPT\x9d\xce^S\x0c\n\xe3\xa3\x83\x19\xfb\xfd\x16\x18\x17\r\x14\xad\xce\xbaB\xcfRr&A\xb5\xcb\x9c\xd0\xd5\x9a\xc3\xf9\t\xaa%i>A\x92\xd0H[\xa4\x83\xf0fO\xed3\x9d\x19\xe6M\\\'\x14\xcb\t\xc6\xbd\x90\xce\x07\xec\xdcH\xe4\x08\x13\x82\x85\x0b\xa9\x1b\x92\xe2\xc6x@v~h"\xa5\xdb\x01%\x95\x99\x91-\xe3\xd9\xa9\x8c\x8b\xe9Z\xb5\xea\x9e\xcf\xcd\xc2\x0cW\xb3+o\x9bW\x83GK[1\xedls\xa2\xd4\xa0\xc4\\\x8d\x06\xe0g4K\x1by\x18\x00]\x0e\xdc\x98\xed\xdb\xbd\xe1\x0b\x85]\xf9\xc8g\x80=\xc4\x13\xee\x93\xd5\xa9\x97\xfe\x07\x01P^\xdd\xa0\x80\xaf\x97aI\xf5\xe6\xa7NyeYO\n\x04\xaaP\xc4\xeaC\xd4\x90\x9f-\xe4EH\xa7\x9b\xf3\xb8\x01\x00\xf8.Z\xe2.\xe0^\xcb\xec\x05\x0f\xe9\xee\r\xb0q)\x1f\xbb\xdb\x11\xcd\xb8,\xdeU\x87\xe0\xcb\xdeTd\xc9\x1bc\x04\xc9\xc9\xea\xdf?\xf5/#\x19\xaa#\x1e\x98i\x99=\x03\xe7\x06\x06d\x9e\x12\xad\x87\xeb\xef B\x16#dg.\xc6\x97\xb3O\x15!\x02\x1f\x05rDz\xef<\x91E\\\xe0a\x1d\xaf\xb5\x07\x92j\xba\xe4\x91eD\xe4\xcb<\x854\xb0\x1d\x13\xf0E\x908$;q\xc2\xad\xb5_\xfe\x8c\xce\n\xe4_\x10\xcf\xb2\x01\xb7\x99r\xb3\xda\xb8\x04\x1b>\x97\x92\t\xab\x968SJ\x1a2\xdb\x19G\xb7Aw1l3H:\xf1\xcb\xf6\xf3=\x19s4\xfc\xe7\xc0V\xa7\xc9\x13\x00M\xd1LoNIuS\xfb\xc65R\xa8\x13\xa4\n\x96\xf2|\x88\xceO\x91\x16\xf6~t\x9a\xb5\xac\xa8z*\x1aR\x181\x00\xf9\xfc\x85`\x84\xa2\xe3\xd8M\xd04,27<\x04\xb5\xd4\xda9,3A\x0e\xdd\xd3\xbe\xa5\xc5\xe7S5\x9fR\x97\x1e\x94TK\xd7\x95\xa4\xc6\xa3\xda\xbc\xea\xdd\x8e\xa2\xc1\xfa3\xa5\xb54\xba\x90\xdb\r\xc8\x06\x95K\xbc"\x9aA\xcaw9\xa4\x12I\n\x1fo\xd9\xcf\xb5\x9b\x91S\xe6c\xc9\xe0{d]\xbb\xb9\x8dx\xac\x19\x0b\xd4\xe30 6\xb2\xd1\xbe\xa7X\xfa\xd7\x0f\x1b\x9e!Q\x0edx\x90\x9a\x8f\xa3\x86\x7f\x07n\x07\xe2\xf4\xa8^c\x18\x1e6\xf0\x0c\xcd\x10\x04\x05\xdbbb\xa0\xc7H\r\xd0K\xe1\xbf\x81\xa0\xf0>\x11\x01\xee\xcf\xc7\xdc\x0c\xdd6\xa8\x98\x82"U\xd1*Nu\xf9\x07\xbe\x88\xbb\xfbhk\x13x\x9c\xd2\x9b8\x0bK\xa1\xfc\xfc\r\xff9\xad\x13\xdf\xed\xd7\xc8zl\xb4$\x0c\x92\xc1/\xf4\x1cx\x96\x1a\x95XI\xf3\x99b\xa4\x04s\x032\x0e\xdd\'m;\xb6\x1bs9+\xea\xe1L\x99I\\\x97\xb0\x98\xc7\x97\x90Z0y\xe3|\x83\x8c\xb1\xfa\xe1\xd7\xaeH.\x0f\x9b\'\xaf\x16\xd2\x83\x16P\x18\x8fI\xd1\x1ap\x99z<\x01%\xc2\xda\xe0 \n\x1d\xf6\xd2\x01\xd4\x9f2\xe1\x11\x10*\x94\xcb\\5\x06\xe9\xf6\xb9\xf8\x89\x8e\xc4G\xe1BY\xf8\xf8\x12\xe9\x0f\xb2\x9bU,s4D\xeb\x0c\xfa65\x0c\x1c\xd0\xf2\xc8\x0b\xdf`\xbaj\xa4\xb0\xc3\xfa\xf8\x983\xd4\xc1\x81\xec\xb92\x92\x93\xed\xdf\x11p\xa8\x0c\xbd\xda\x8a\x1b\nXq\xdc@\xee\xe6\x1a\xbe.(\x85VT\x8e\xaf$^\xb1\xbf\xdc\x00ea\xbcvU<\xc7\xc4ytUO\xba\x1e\xcb\xfe\xab\x82\x8b\xdbYC\xbag\xd4\x9a:9\xf6H\xe5\xd5\xa4\x00\x15\xc2(v\xf2Qa\x13\xc8X\x17\\\xde\x82Nq\xd5\x9a\x85\xa5\xcc\x8f\xc8\x02c\xa61;\rxX,\x91z\xa2\x98\xc59\xba\xd2H\xad_DJlE\xe9\xb5\x8d\xe2\xfa\x18\xe2\xa0\xc2E\xb0\x92^)\xe33H\x10t\x86\xdf\x8fz\xd3\x85ITt{\xa9\x03\xb9\x0f\\\x91\xcc& \x81Z\xf88w\xfb\xe0\xb4KvI6]\x0c\xc7\xc1\xc5\xdaHG7\t\xe5\x96\x95\x9d\xea\tJ\xd5\x9c\xc6\xa7\x83\x92\xc1\xd6\xd3$^\xb6\x81.\xa1E\xc6\xe8\xda\xfbt\xae\xef\xf0G\x87 \x8a1\xa2\x1ab\xce\x0b6\xb0\x1b\x18\xc5\xa8\xdd\xdads\xa9J\xa6\x16\xea\xd9\xd0!\xbc\xee\xb1\xc0L\x03h\x8f\x95\xfc\xe5\x82\xf0\x86\xd1\x1e\x8d\xb1\x1eP\xb5\x87=\x8fq\xc5\xee\x0f<{\xbd\x06\xec\x1b\xb1j\xb3n]\xaf\xfa\x18\xe6-\x85,\x1e"q\x12\xee!p\xeb!\xb0\x99\xaa\xdd[x\xb2Z\x06\xce\x14\x98)\xa4\xb2\xd5q\x03-\xb2\xc7\x9f\xac;c\x17\x82\xdc\x04\x1e\x8en\xca\x0e\xb3\x9a7\x9d\xba\xfc}\xfe0\xa5.\x127-\xefT-\xd6\xa2\xfa\x95\xe0P,_\xef#\x1b\xe1\x99\xa9-j\xf0<&e?\xcay\xd8m\x8a\xd3\x13K(\xd3\x99c\xfb\xf7\xe0-\x07\xfe\x10\xeb\x04T\xa8Y\xef\x89\x05\xad/+E\xa1<K\xcez\xbb\xd3al44\x88\xd1\xe0\x8a+\x06\x12\x9a\x80C\xb2\x06s\xba\x19mw\nu_\xc3\x15N(3\x17\xac^\xd5\xff\xd6T\xf8.\xadG.\x1d\xbd\xb6[1\x1e\x9b*\x9b\x91?`\xc6\xfa\x0f\xafH\xecv\x1e\xf5\xfd\xd0\xdf\x85\\A\xcd\xb1i\xb4\xc4\xb0.\xb3&\x14\xc6\x8fK\xf7\xe8\xef\x16\x1c\x15\x8c1I\xdd\x8d\xde"|\xd7G\xd91\x82\x91U\x8d\xed\xd1\xa9\xcf\x9cK.R^\xbc\xb8\xdf\x06\xe6\xe1\x97\x812\xdeM)\xfcG_Qy\x891\x9aQ\x00(\x0e\x1f\xa2\x96\xdc\xfa\\\xa8}\x06%\xdf\xde\xfb\xfe/IL\xb99\x1a=\xa6\x0e\x83\xe9\xaciv1\xf9~\xb0s\x92\xa9qB\xef\x9eS\x17kmX\xff\xfa\xed\xf1\x90&\xa8\x08\x98\x89!\x96\x9a\x1d\x14^(Y\x17\x0c\xb2\xbe\xcf,"\xb6d\x08\x93\xcd\xc7\xdf\xa4tly\xa7\xafrlD\xfd\xdd\x1e\x0f\xa7\xd2\x9c\xb9f\xfd)\'\x9a\x04\xbb9|:\xd8\xf8\xe8Za\x02\xa5\xf6\x9f \nK\xbfx2\xcf\x80\xd8\x0eX\x7f\xa6~\xdbz1!\x13\xca\x0e\xd4ziEu\xf4#\xaa08e\xe8\xfe=\xf3(\xbaP\x80\x15\xac\xfa\xcc\x9b\xfb\x92Y\xf6\xff=\x1f\xef\x99I\xe2*1\xc2b\xe5\xd1\xf1\\\x1b\x13\xf1\x9d\x1c\xd9ph\x0f\x83\xec\xf3\xcc\x11!\xf6\x89\xc0\xe2\x9d8\xa3X\x1d\xa3OJs\x83;\xf0\x84$\xfe\xe2s\x85\x86S\xc9\t\xa0\x89\x96c|{\xd2\xd3\x94 `"\x8e\xee\x8b\xe7g\xf8\xb42\xfb2"\xfb\x96\xfa\xf7;\xe5l*5NKP\xb6\xf5?\xa0\xb7f\x8a&\xa7V\xec\x0c\xd3\xf8A\xa2\x08\xf0"\x9c\x8esc:\x94\x9e\n\xa2\xd9A\xec?>\xe9\x14zZ!\xa3\xd1p\xe9IZ26\x0b\xc7\xfa\xae\x97\t\x86\xf9\x93Lc[^e\xa3`*~\xed\x03\x8bA\xa7\xb0=\xd0pZ\xfeL\xac\r\xe8\xb5\xfa \xda\xeaT\xbd~\xb8O,\'\xfay\xc0\xa49x\x03n\xbf\xe0R\xf1\xdc\x17b\xf6{d<\xeb\xb3\x0f\x0e\x1e\xb7\xb1\xcc\'G\xc3tn\x95\xde\xf5\x11"R\x12E\xc0<\xcc\xfc x[m\xef\x1ar[\xe44\xd9\xf0n\x93a?Uj\xad_S4\xe6Z2\xf5\xbe\xea2Zc\xc7`$I\xf7X\xc1\x9f[<B\x19\xfa\x16<KPW\xffP\x1c\xe6\xa5\xb6\x1fG\xaa\xfck\xfe\xec\x12x\x95\xc2l\xc8\xd4UT\x95"\xa82=v\xd9\xb5wwt?\x0e\x0fL\xa1W\xfd\x15O\xdc~\xbc\xe2\x84\xac\xb8?\xbf\x8f\\\t\x1a\x9f\x8c\xc7C\xf15-\xdd\xcb\xbb\xe8`\xb5a\xb2\xa7\x13\xf3\x83\xa0\ti\xf8(\x9c\xe8\xf7\xe3\x0f\x0f/%\x1c%\xa7$\x1487U5q2^\xa5\xe1\xa9\x95\xc3\x8f\x8en]n\xbdz\xe4n\x11\x1eaV\x83^\x80\x18\x9b\x08P5\xef~\xc5\xa1\xce\xc6>\n\x92\xaf\xa3\xa2\xc1\xff\xc4\x991\xe2\xe8\xa3\xce\x8fb\xb0q\x8c\x8f\x83\x9f\x7f\x0b\x12$q\x90\x0c\xde\xeb\xa2w\xc6E@;?\xbf\x0b\x06>\xdcg\x83tZh\x90\xba,g\x7f\x08\x00\xc9\xa6\x90"\xd2YC\x1eZ{\xccf\xba\x7f5#l\x80\'\xc7\xd0"\x8aO\xe1i\xeb\x91\x92\x9e\x0b~\xb4C\xcd\xad\xcd\x16B\x9e+\x91\xc6\x9a\x9aN\xf9\xb3\xdc\xdd\x9d}\x9d\xf2\xc6av\x8d\xd3OJ\x05\xf1\x0bU\xb1\xb80\x01\xc9\xa8\xb5\x9c\xdd\xc0O\xe8N\x94\x8b\xaaW(\x1e\xbf\x8f~\xf7\xd7\x7f\xd4\x19J\xc6\x88\x048[\xa3\x9a%\x18\x8c\xfd3\x13\xea3A\x7f\x0c\xdd\xbf\x9a\xf1V\x87\xaae\xabB\xcf\x88#T0"\xffR\x86S\xf37\xed\xf7OV$\x1ak\xab\xfd\\\xa4\xe8\xdb\xb5\xa9\xa5!\xb3\x0b\xcd \xc2\xf6\xa3Ol \xaeD\x95?\xb0{K\x9b?\xe72([oKj\x00\xc2\xcb,mA\nt\'\xd1yG\xb8\xed\xfb\xc0\x8e\x8d\xb5\x05\xf7s\xbf\xa4\xdf\xbb\x04Wu\xc2\x04\xae\xa7\xbd7\xda$\xa8\xceB\xc4O\xa5\x17\xf8\xf4\x88\xdeb|\x0b\n ;p`\x9c,y^;\x0e\x03\x82\x93\x8c\xe6\x91\xa7\x07s\xa7\xd6\x15\xec\xbby\xdd\xf4HX\x9ey\x17\xffC \x17\x10p\xe6\xceT,:nbS\xb6\xb7\xcf\xa5uKI\x87\xd4X7\x82\x8d\xf0\xc5\x84\x08n\xc9\x9a\xbd\x11\xac~\x9a\x18\x04\xf7\xbc\x18\xf1\x88\xd0\x81\xd5yL\xba\xe9\xa5\x88\xea]h9\x93IsKU8\x81Z\xe8\xefE\xdc\x1f\xf3\xff\xb0-\xc5:7Z\x03\xefVy\x86\x86\x11\xd7\xc6\xe2\xc2\xf3\x15\x9d\x08\x03M\x98$8}\xbd\xd7\xa5\xf9\xe3KimO\xbe\xa8\xc3\xc1YZf\x03(A\xae\xe1\xf2\xdbz\x9b\xf7\x14\xa5 \x95"\xfcp\xd0\xe43\xcb\xba\xbaqI\x1d\x80\x885\xde\x9c\xff$sBC]\x9e\n\xcc\xebd\xf9\xcf\x06nF\x9b\x1c+\x1c\xc4^\xab\xe2k5.\x9f2\xd5D\xb3=\x8e\x9f\xf4)/\x83.\x1eaj\x93\xe1\x8da\x05\xc0a\x92\xa4\x1c.\x07\xac\xd1N\x0f\x1a\xea\xfc\xf2\x86f\x06\x86\x07\xa4\xad>\x05\xc3\xffG\x9dK\xd1\xca\xf9\xb62\xb0\x0f\x9f \xfba\xe4\x16\xbeC\x80\x13\xa7\xdd\xd6\xdc0j\xc3\x15\x89*\xc8\x9b\xdc\xa8C@\x83J\x04\x08[:\xe9\x14\x80\x84,\xae\xa0Yc\xb4\xb1\xd9\x81\xe2\x1b\x9b.\xa7\x185p\xda\x82\x16\xaaWe\xfe\x8cs\xd6>^\xf7~\x0f;\xeefj\x12\xc5.\x1c\x14\xabg\x11&wMmNp\x0f#\x1fDK\x07\xa4\xacE|\x7fq{\x1d\xba\xaaF)\x95\xa5\xdff[\xcd\'\xba\xe3\x9a\xee5\xce\xb6\x02\n\xb1\x998\xe1=`\xf7\x85\xc5\xb2\xbc\'\xe6-+\xe0\xeb8\xfdP\xabC\xc2\xc8\x18\x02\xda\xa2\xa9\x0e\xb7\xa9\x95\x02\x921\xe6\xd5M\x11\xe5\xc7*\x9b@\xaa\xcdM\xd5\xb2\xd4\xe7^\xf2\xab\xe4\xf3\xb6\x8e\xc5\xb9\xae\xac_y\x15v#=WI\xbe\x96\np\x97\xeb7\x8co\x9d\xc3\x10\x9e\xf7p\x80\x9a\x18\xf1\xbb$\xbc\xe7(\x9d;\x04\xa6\x13\x00E\x7fcd7\xdb\x00\x7f\x19\xa9\xd0\x02\x0b\xa1\x860\x84\xb7\x81\xadp\xd8~\xca\xcb/H\xbes\xce\xe6\xf5\x13\xc7\x17\xe2\xbb\x83#\xa0\x11\x0b\x0fG\xce}qw\xc0\xc6\xf4\xbc\xce\x92\x13\xef\xdcX\x8f\x0e]\xdb\xb1R{\x8bmX\xf1C\xe8}\xaa;\xf6\x19V\xe1\t3B\xc6\x15\x96\xee\x92aO\xf5\x07\xd9W\x87t\x98\xbb\xd7Q\xf0\xba\xd4\xc9\xed^A\xfa\xb4\xc1\x93\xd8R\x8f\x00\xbf\xe9\xc4\x93k\x8f\xdb\x87\x98Hr\xa4NV)\xafR\xf3\xa3?\\&\xe3\xa1\xb6 @\x9d\x04\xfb\xf2\xdb\xbd\x83\x15\xae\x9fk_Z\x82:5,\xcas\xe66\xd1y\x867\xf6\x93|EPH\xf6\xce\x07\x1aC\xa7\x11m\xb2gt\xd8\xc5\xd2\xb1\xeey\x1b\x172\xb1f\xaf5\xc5\x8cV\x98ly\x9c\xb3]a~\xd3\xff\xa3\xdb\xa9\x85\xecD\x8f\xc8\xa1\xc0T\xafI\xf4\xb6k5X\xbc\x05\xcd\xbd\xb1\xea\xde$sv\xe82C\x84DQ\xef,\xecf\xb65\xc5\r\x1a\x19\xf8\xeb\x8e\xd9\xfb\xdfp\x19\xfaS?s\xedOg\xa2^<\x98\xaeP\x86\x0b\x89z\xc4\xda\xd6\xbd)\x1d1\x980_4m\xa0@\xdc\x18\x8e\xacT\x0b\xc9\xf80\x19W\t\xa6"\xbaB\xa1eM\xc4\xe5\x88Ce\xedL\xd2[\x8e\x14\x8f\xae\x84\x1ab\xd9t\x81\xf7\x90R\x0b\xe8S\x92\xd86\xbd\xe40\xd9Qsi-(\x94N\xf2\xed\x8e\x19\xf5T\xfa\xd8>\x14\x12\xc4\x1e{\x8b\xf7\xa8\x1d\xa7\x82xr)d\xe2[4\x8c\x10f\x11\xfa\xdd\xbc\x88\x10\xc9\x11\xa1x\xa4\x8d\x08tI4\x17\xc1\xc9\xd7\x0f\xc7\xf1G\xcd\'\xd3\xa1F\xaf\x8a\xb7\x89\x9bt\x17\xa7\xec\x08X\x9d\xfc\x17\xea\xbfp\x8e\xe6\x87\xfe\xd74+O\xf8\xb4\x1b\xe0\xc346\xd6!\xd2I]\x00\x92\xfeu\xc7WOnU\x14\x1e3\xed\xce\xd2\x08\xa9qk\xd9*\x8c\x1cf\xf7\xfc\xcc\xc6h\xce,\xb4=d\x1d\xa9lpWl\xc6\xc2\xb4\xff\x0eXV\x06\x8a\xb2\xd2X^\xc3\xea\xef\nZ\xbb\xbfT\x80&\\uz\x9a\xe5\xb6BG\xc3\xc1\xf1\xb5\x94\xe66E\xe5\xdbS\xf2\x15\x08\x93\x95oM\x17+\xf3V\xf8g\xe4gx\x8f_\xe4\xbc\xe4\x81J\x15\xf3\xe9S\xed\xac_\x9f\x96\x07\x92\x8f\x03\x8dv\x81\x10L_\xd2Q\xc0\xc6_\xd6\x0f@\x19\xf3\xb2\xa0[,\x92\xe5\x94*\xfe\x19>\xd5U5D]\xa7W?\xb8\xfd\xc2\xaf&\n\xdaR\x175:\xd9O\xa0\xe4\xday\x92~C\x14\xa6\xfdAt\xa2\xdd\xba\xe9\x8a\x12\xe1\xd1\x8b`\x87m\xbb2\xfa\xceB\xd7\xeb\x93S\x05\x16\xe2 \xab@\x06\xe7s\xcf\xbd\xf1\xe0\xc3\x0c\x16\x05\x14\xae\x137\x94e*:?\xaf\x05&\xd8\xf7\x82C\xf8\xd3\xd3L\xe7D\xc7\x1a\xae\x96\x95\x0b\x07\x9d\xb6\x87\xeaG\xde\xabT,\x9e\x98A/v\n\x85\xca#H\x91m\xb1b\x13\xcf\'\x97iQ\rH\xd4?=\xcd}\x14G+\x85C\x920m\x85\x82t\xd2\xa5\x90\xdd\xd9\xf3\xfa\xf7Y\xbd\xcd:|\x17J\x9e\x85\xb3Z\xb5\xed\x8aHW\xd7[\xe81O\xcc\xd5J{T\xca\xeb\xf8\x0c\xa2\xab\x82\xeb\xfe\xacd\x08EY\x93\x93\xd6\xa1\x93\xc9\xec\xf1\xbd\xb5\xa2X:\xca\xfe\xff\xb4\x99\xb5]u+D\xd5\xd3\x07VzXp\xf1\xebo\xed9r|\xa5\x8a\xae\x10\xabl\xcad\x9d\xad\xe3YJs\x13(\xf3\x8b\xc7#\x86\xfe\x05\xe0\xe4\x19\x8a\x1dT\x95]n=*T?m\x92\xaa\x85^\x8b\xee\x11\xb5\xa1E\xd4\xc5\xe5\xe6\xc0\x98\xce\xbe\xf7\xe1\xae\x1c\xddq% \xf06{peQ\xad>.Q\xc5\xba\xd4}\x0bb0\x86\xcd\xaa\xf2\x8c\xa7!\xc1r\xdb~46mK\x87\'M\xc5\xe2\x19J\x17\xc5\x82\xb7b\x8a\xa8\x1bj\xde\xd1\xe8\xc10\xd5\x18\xa2\x06i,\xe8{T\xb5\xc5Y\xb4B\x05a\xdb\xb7\x9bA\x1bmf\x05N:;-?\xb9\xa7\xd2\xeb\xd6\xc5\x01\xc3(\xe9\xbc=\xc5\x8d\xdbh\xd5\x85G\x1e\xf6\x11\xf0\x0e\r-\xa4\xe9~\x85/$t\r/ \x866`W\x0f\xcdt\x16\x9cv\xb8h\xa9V/\xf9\\\xd2\x7f\x8de.\xaeq&\x98/{k}|\x8cW\xf0*"q\xe8\x0f\x0b\xdb[G\xa1\xd7<\xc6iDe\xba\xaa\x84cv\xd4\xd5\xb4\xb8\xb7\xb2c\xb3\\a\t\x0e:\xa2\xdd\x91aFc\xfc\\\x1e\x88\xf1\x8d\x1e\xe0!\xf7\xe1\xf5+ \x8ah\xbcc\xb8~B\xb4\xf1sZ\x99C\x97\x8d\x7fN\x17w\xed/+\xc8\xb3\x18\xa3\x0b\x17H\x88/Kx*TS\x0b\xf3\xea\xc6d\x93O\xdat\xf6\xe7\xed\xf9\xe8f\xd7wok}\xfft\x16\xe8/\xca\xeb`\xf0\x04\x9e\x82\x8a\xe3\x909|\xbc\xf4\x943\xddX\xb5\xf2\x7f\x81z\xdaLQ\x87\x1b\xcbt\\Q\xf9\xe0^\xf4\x95\xf0\xe2\xa9m\xdd\xf9\x03\xfaD\x8f/e<\xf8#aN\xdf\xf1E\xf3R\x07\x9d]\xb9\xfa\x1a\xd7<\x1ei\x8fU\xc7)\xd9j\x1e\xcc\x14\x00\xc9\x8e<IuC\x94\xd1\xc2\x80@JT\xeb0Y-\x87hhd\xa5\x99\r\xad\xc5@\x8a"x\x99\x9a\x93>\xd0\x05\xd9\x16\xe6\x11\xdb\x9e\x1d7F\x08\xea\x10\xbc\xc6q\xca\xb3j\xb0\x03M\xca\x0cQ\x9d%#\xd1s ^\x10\xabV\x86\x81\x8dG\x0e\x11o\x90\x1a\xba\xcc[N\xd6w\x8d:\xb8\xf8\xfa5\xd1\x99k\x10\x8c9Z\x8dQ^Z\x121\x1f\xf7P\x7f\xd7\xc2l\x93#\xf02\x95\xec\xe4\x90\x8f\x95\x07VV\x1c\xa2\xb4\xfbU\xea\xcd\xa0\x80\x00\xafr\xec\x16\xe7\x9f\x8f\x83\xcdqh\xbc2\x86\xd5\xb6}\xa9\xf5J\xf1\x92<\xc4\x01\xea\x98:^\x8d\xd8\xce[\r~\x93\x18\x825\xaf\xbcW9D\xe1,^\x8eD\x01\x07pc\xba\xd4W\xd6EH\x0b\x0b1\xe04\xb4\xf9\x0ba\x13\xb4w\x93L\x90\xb9w\xd9](d\xfc\x90\xbe\x01\t\xbf\xb9#\xd7\xe69}/\xfb\xe8\xa3\x16\x06\x81h\x00br\'\x12\xed\x1a-:\x1e-\xf2\xa4N\x07\xa1Dm+V\x89\x1c\xd8\xf7\x1b\x0b\xbc\xc4\x1eW\x9c!"t\xe3T\xc4U\xb8\xb5}\xe0\xc5\xf3\xa2\xf2\xf4\xae\xb3-\xc9Y\x947\x13\x97\x0bp\x85\x00\x19\x83Fv\xad\xa0\x1d\xa4u?\x00\xdc`QU\x19\xce$r\xa3>\xc4\xea\xb8n\x16\x15\xba\t\xb6d4\x0ex\xc6+P\xdf\xdd~\xf39\x0c\x03\xe1j\x05\xd2\xc5\x98\xc2\x03\x81\xf5\xcb\x10\xd3$x!\x1f%o\x96\xd4\x08\x8b\x9f|\xbc_d_\x80k\x15\xd9+p\xb9\x90\xb0\xa3z\xd8\xaea\x97\xa9\xff~8\xf5\x1f\xbay\x1b\xf0J9P2\xb5\xc9u"YE\x8cX\xc9\x84\x99\x1d\xf1\x083\x9b\x00k\xfe\xc5\xca\xa0\xbb\x02\xbem(\xd6\xeb\x812\x01k\xa68G@\xceze\x8e\xa3jO\xace\x94\xf39\x96\x0e\x945w\x7f,\xa4@\x89\x8c\x11\x1d\xc4"P\xc7\xac\xac\x9e\xdf\xf9\xed\x9e\x07\x9b\xa2\xfbW\xd4\xba\x02\xd6\xb3R\xa4\xc0\x12\xfe\xd8\xee\t\xa8\xd2D\xf2\xb73o*\x8a\x08\xeb\x9ew\xad\x98\x84G@b\x04~U\xcb#\x97\xb22M\xdb\xd8\x9ecj\x19\xf8\xac\xbe\xebB\xcez_\xe3\x9fT7S\x07fH=\xd7c\xb8\x0f\x80\x894\xbf\xf0\xe5w\xc8\xdfd\x9b\xc3\x99I\xa3\x95L\x88d\xf4ODL\xf2\xdd\xea"-\x97\xa9\x16^\xce\x1a\x1cxo\xd9\x87D\x17\x8f6\x9a\x95\xac\xf66\xa49\xbf\xf1\x18\x9dQ\x83\x93\x94\x88T\xd2\x03\xed\xc2b\x1c\xc3\x00\xb8\x1d\x83\xbc\x81p)\xbd\xcbF\x80\xc8\x1d\xb0\x07z\xe0\xb9d\xe8a\xbeN\xdcD\xcf\x8d\x0eH\xaeWFF\xc4\xa8A\xfa\xdaO\xa4x\xa7R\x19\x1c\x87C\x98}\xdb\xba \x82X\x07\x0e\x14w\xdb\x03Du\x9bX\x04>\x0e\xffc\xa4F\xeaEG\xf54\x1d\xd8\xf58\x06;\xc2\x1e\xa3\xbbW\xf7-\xf8\x9d\xe9\x04\x94\xcd\xa4\xfei\xea&\xa4~\xe46/"\x02{\x050\x9aK@t\xae\x9aN\x11\x1c"\xb3\x9b&e/\x13\xf9\xe4\xf6!\x99\x8c\xb4\t\x9e0\xf9\xf9p\x8fT\xdc\xd6\xec\x90\x8e/\xddi\xa4*\xde\xa6V\xf2\xc9j\x8f\x88\xab\xe7y\xb6\xd3<\x1b\xcfo\xf6hA\x04ka\xf7IG#\x02\xb7`C\xc6\xa5K_\xb4ySd\xa7\xdb*b\x82\xa1U\xc1\xca\xf2\xef^6\x8b"}u\xa2\xd5\x80\x90\x95\xc6\x86\x9ac\xec\xed\x80\x99\xd5\x1b\x93\xd6S7lL%\x817r\xc27K\x17FH^\xbb.1\xd1m\xa0/F\'I\x01\x1e+\x85~\x97\xae&\xd6\xed\xc0<\xa2\xe0\x06\xd2\xdcom\xb1\x87\xcf\xca\x1c\xf2\x8aH\r\x9b] \x94O6\xe5\x14\xf3>\x07\x8b\xfc@\x92J\xcd\xfeK\x07\xc7b;\x86N\xe3\xa3\x01Pe\xed\xc5,\x99\x89\xc9\x84-\xaa\x9ch\xe5R\xebR\x88\xf19\x97Y\xff\x15\x9e\xbcE\xa4`/]i\xd7eV\x93\xf6W\n\xd8,J1SMM\x8f\xe9Y\xbb(#\xbd\xe0:\xc0\xd5\xbd,*\x9a\x0bR\xee\x8d>\xfeJZ\x06KK\xb3\x89]\x12\x1a"\x18t;\x05;\xd0\xc15N\x10w(8A\xa4\x89\xf40\x1d\xef\xb7G\tw\xfev\r\'j\x88ng\x92K$\x14j\xa6\x15\xa2\x8a\xa5#\t][\xeb\xa7X\xfeD\r\xcb\x84\x11%\xc3\t\xcf!\t\xe6\x8f\xd1\xeaLk\x0f\x8c\xc4`g26\xa4\xf3\xa5_\xb5m\xdcv\x81\xbe\'\x9e^\xa3\xe1\x1ey*0<\xc6\xd8YL>y\xdd\xd6\xd1\xfb@:\xd1\x17\x8a\xcd\x8f\xb2}\x19\x15F\xea{\x98(\x91\x80\xef\xad\xee\xbb\xa5#\x07\x9c|\xcf\xef|\xab\x04\xad\x06\x10/\x03R7\xae\'!ES\x83I\xe7Z\x1c\xb3`g\\\xd3\x89\x05\xd9f\x1c\xb6\xd0\xf2\x15W*\xf5LR\xef\xfc\x1b\x93\x0c\xe6Y\x18<\xc7\x8e8\xaa*\x7f;\x06\x10R\xb1\x13\xadn\\\xe6-\x82Z4d\xd9pW*(\x99\xd3J\xac\x82MJ\r~\x18\xa6\xba\x81\x19\xd8k\x90Mj\xdb\x86\xdfSZ{y\xe3h\xc8USE\xcaV\xc7\xc8\xaa}(C\xb7\rv\xa6\xd4\x1f\xe55q\xdf\xf6\xd63\xb1\xb9\xf4a\xa0\x9f\x18\x0e\x8aK0\x89(\xe2u\xa6\xc1Ov \x02\xe6\xa0\xb0v\x1e\n\xe2\xdd\r\xc9\xe3pi\xeb\xc0\x93\xfd\x0b\xe2\xc7\xc5\'\xbe\x9e9\x7f/\xef\xea#\xfe\xe6x6-;7\xbe\xb0\xe8&_x`B\x97\x88Qf\x9f?\x9b\x93\x0bvb\x91C\xb0\x8e\xef\xa6-\\\x19O\x7f_\x00\x9a\xc4c\xed\x10\x00SVZE\x9bY\x04m\x84\xb8K\xf4o\xf7\xb8\xa7\xac\x87\x05\x94\xe4\xb6\xe0\xa56\x15-\xa5\xf3\\\xf7\xf1{\x1c\x94\x15\x14\n\xb9[F\x06\xd2\x0c\xdd&;\x8fG\x1bUg\x13\xc5\x9c\xcf#\x07\x9ad\xf1\xc3\xf7\x12\x8a0\x0f\xcb\x0e\x10\x96a\x8f\xb1N\xa3\xbf\xdc-%6!\\\xac:s8&\xa3.J\xe4\xceY\xb1\xf4\xb7\xd50\xd5\x1f\xa5\x87\x8e\x02PH\xd0;\x92\x1f&\xa8\t\xddf\xf2\xe9\x14\xce\xb5\x89]\xb1B\xc3\xcd{\xfd\x99\xc0\x9f\x96\xc7\xe1\x84q\xf4:\x18\x05\x1cjh\xc6\x98\xc3\xb4[\xf8\x91\xcb\xb0+:\xc2"\xa4\x8f\xc0*%y~ne2!8k@\x95\xce \x18L\x91vB\x1fG\x91\x90in\xc4\xf5t\xcb\'\xb7\x8e\x1a\xb2g\xe0\xc5\xb5\xd1\x82\xebd\x00Ly\xc4}+\xd42\xf5\xd7\x90r\n\xe6\x84I39\xeei\xf7H\xe2\x9d\xce3\xda.O7\xe7:3,\xb1\x98\x83\xc9l\x87\xd8\xfb\x94\xf2\xd6d\xab>\xe9\xac\x08\xb1\xf6\xd1\xfe+\xec\x06\xa0\xf6W\x12^\x18nV\xe9\x12\xedl\xd6\t\x7f\x89\xb7\x10\xcc\xf5\xee\xa86\xf7&{\xd7\x8c\xdd\xa6\xd3E>f\xf7@4\xc0S\xbdwEc:#\x0e\xe7\xbcS\xd6\x18`\xaf5\xd3b\x9f\x8cU\xaf\xa9\xb7\x90X\xbd@b\xabG\xb1;\xe9\x9c\x04x`\xfe\x10\x1c\x9bDB\xf6\x1f\xf4=\x9e\xde\xb5gXL\xbbRweP\xca\xba<\xe6\x02\x01-cIpQl\x1e\xe0\x80y:S}S\x16\x11\xaaF\xed\xb8\xa5\xfd\xa0\xd0K\xb7\xe5:\xe1A\x07\x91\n\xc48\xac\x1fkM]Y\xaa\x0e\xc9\xc6qV\x8csa\xbeD\x16\x8cx\xabR\xae\x8a\x89as`\x86C\x17\xb3L\xa3\x9a\t\xc7#\xe0O\xb9)\xc7ys\xf8I\xf0\x18\xdaDY\xe9s\x02\xae\xca\xf7\x1e?\xaa`\x17{\x1a\x8ef-\x97\x19\xda\xdb\x95op\x9f\x7f/e\xf2dE\xb8\xa4{\x82m\x88\'Y\x1dv\x90\x96d\x07AyB\x9bv\xb1\xb4\xfd\xf7p\x1fW\\\xe0\x89\xd5A$\xe0\xafJ`g!\x9d\xc8q\x8dB\x08K\x16K\xcdTnpp\xba\xc0\x9f,y\x08\x98\xdeH\xbc\xc5\xdd\x9b\x1c\x8f\x14v\xf3\x17\xe3\xe4r\xa4<\xfc8\x1d)X\xb0\xa9\xe5\x1c\x1d_\xf1b3\x8d\xb5\xc6\x9bcq@\x95\xbfl\xe0b\xf9\xe6\x01\xf1tu\xb7c\xa7&Ra\xb4p\xebz|\xfeb\x07\xf8r\xcb\xbe\xad\x0b<\xae\xe9\x7fhjN\xdfM\xe0\xff\xeax\x0f\xea\x181\xea\xccv}\x8a\x02\x1a\x97\x08PZy\xfa:#p\xd5\x19\xb4\xdb\xe2}V\xed\x7f\x1e\x07\xfezb\xd3\xef\xcb\xf6\xcc\x8f\x12XON\xde\xca\xc8\x1bz\xd2\xd4\xbf\xb2\x1b\x8e\x89\x1d\xe6:\x89\xf9\xef\xa8*n\xe7\xd2`\x08(\x03!\x89\xe0eS\xcdEK\x8aI\xc3\x82\x0c\x84\xac\x99\r\xd6\xf21\xfe\x15`\xa6\xbbs\xe2\xbc\xb3l`\xb8\n8\xad,\x93|\xc5\x87\xcd7\xbd\xb3m\x87h\x1e\xb2\x80!\xa5E\xe3<)C\xd3\x99\xc8\x81T\x83\xed\xd8\xc9\x9e\xf7yEd\xee\xdc\xa8o+\xd0\xd3Z\x13\xde\xa77\xc2\x8c\x0e\x16\t:=\x1b\xfdr\x9eE\xd3#\xe13_\xeca\\\x1d\xf0\x04(+\xfb\xe8\xf4Z\xa4\x82\x01\x82\xf4\xfec\xfa\xb4Al\x12\xab\x81l\x93\x9d\xfa\xb8\x87\x14D\xf9g\xb84\xa7\xb3\x9cy\xc9\x18\xa6=\x15\x14N\xc3M\xdc\x1d:\xe9\xf5\x16\xef)\xcc\xd6g\x18\x14J]n\x02\xb9\xb9"\x12~\x1dr-\x90\x87\xc41\xae/\xed;\xd8\x02\x1e\x87\x15G\xf4\xf1_yEQsJ\xfe\x84K\xa0\x08\x9f&\x9e\x0b\xb6\xf7&\xfb\xda}"Zc\xc1\x90\x1f\xbf\x7f\x9aJ\x13\xf6\xa1)Xbe{V\xea*\x0e\xf6/x\rH\xe6\x16,oZj\x97#_zyS7\xd6\xd9\x93\x05V\xf2Y\xb0C\x9b\xa0\x9c\x87>\x98\xbd2\xc1t\xb9`5\x98\xc4m\xea\xa5\xbf\xe7z\xd1w\xd1\t\xaef\xa9*\xa4U\xad\xc1\xee\xa6Yz\x88\xeb\xc7G\xcc\xf4\xd5\x8b$d+\xfd\xb1P\xba\xb7$\\\rM\xb9\x8fX\xccx\x80\xf3\xbc\xa0lU\x99\xea\xb6\t\x15\x1b\t;m7\x81^\xd0+\x94e\xaa\xcc\x98;~[\x95\xd8\xa9\xe1\xdb3\xad\xd4\x06<\xff\xb50p\xa8\xa4\xdb\xc5F"\xb6s\xf0\xb0\xb2X\n\x17\x86l\xb3\x05\xc4\xa0\xfb!\xe2\x80/\xf1\xee%[X\xf7\x80\xc0\x8a\xb5,\xe9b\xa3\xb3\xedd\xb3./\xa4\xaa\xdd<5\xf2a\xf4\xf2\x80\xd7\xa6\xbf\\\xc2\x92\xc2\xd0\x95\xff\xca\xde\x9a\xb8\x91\x05\x07J\xd6\x92w\x95j\xd9\x16CR\xf2OA\xfb\xf7w\xa6\x8a\x08\xd5\xb4\xc4\x12\xbd\xf93\xfa\xa7\x9c\x1e\x0cY\xf3\xbeQ\xa8\x0eX\x0e\x97\x0e&\x80u.jq\xcb(\xb06\xf6/\x0cEM4\xd7(\xa4\xc9\xd4\xa7\'vH,]Z[\xd1\x83U.o\xf9#\x11U\x05xi\xd1\xe6\xda\xa6\x7fw\x81^\x0e*\xf6\xb0\x0ccdn\xb4\xa9\xe2\x8e4\xb8\x83z\xc0\x8b\x15\x08\x84\xcf\xb5in&\xa8Y\xcb\xfb\xe6M>\xbc]h9\xa6-\xb0V0\xa8\xd5\xa2\xe8S\x9b1\xad\xd1+a\x1f\xed~w\xf46\xa2\xccC5\xb8\xa6M\xfcrF\xcd\xd6\xa5]\xa8A\x86Dx\x12\x99n\x82\xc0Ag\x065\xd3\xb5l\xb2\xd9\x18\x91\xddb\xdd\x16i\xacS\x07\xb6\x95\xfb\x8a$n)\x10\xfa<\xda\x11\x1fmt\x90o\xebe\xd6\x0e\x16L\xcc\xa9aI\xc0\xf0F\x1bqITn\x82\xf3n\xbeW\x1cy\xf4\xcf\x81\xe1\x11\x7f v\xf3\x15\xebc|R\xb7\xd1I\xa6Yf\xeb{P\xbf1y=6\x96>\xf3\x87\xc3\x7f\xae\xb6d\x1e\xc3\xdf/\xe4\xf2X\xff{\x9a\xdd\xabr!7\xaa\x9f\xef\t\xed|2\xf8z\x08\x86\x83r\xfa$\x96\xb2\x07\x9d\t\x04\xc0F\xe4\xa3\x95\xc2\xae2\xc2\x85\xe8\x83\xe5\xa2\xc4\xb8\xea\xc6\xcf\x9b\xc7\xf0\xb0\x13\xc2H\x8e`\x1a\t\xa1\xb9\xf3}\x15\'\x8e\xef\xc1\x80b\xc3\x0fY(\x14%4e\xb8D\x1eQ\xb9\xc8\xa9F\xae\x87o\x1a\xf7\x1b\x9c>\xa8i\xd5\xfa\xa7E\xaf\xef\x11iY\x1b\x16\xbe\x14jW`\xdb\x1d\x87\xf5\xbbsM\xc3\xff0w\xa35\xee\x16\xa3k\xcd\xb9=\xbcM\xac[\xf9p \x91\xef\xd2n\xfa\xb8\xa7\x92_jJ\x86l\xc3\xf1?,_(u\xe9byV\x99\x83[9\x94;\xd0}\x14\x00\xd8\x96\x08\x12`z\x1b\xf8K\xbbJ_TGw\x10\x10o\xebY5\xa4\xe5(*3\x14\xb6q\x1aJ\x14\xf89\xe1\xf8\xf4\x18\xb7(\xc8\x08\xe4\x9d\xf7\xbe\x8a\x9fp\xc5\x88\xf2\xbf\x1fd\x15F:[\xed%\xa4\xb4\x03-\x07U\xa1F\xc5 .\x89-\xa6\xb51B\xd0V7~\x07vo\x94\xd6\xc0\xae\xc5\xdb\x95p\xa2^n\xf7\x1a\xe0J4\xed\xc2G\xb7X\x18\x01Xqi\xfe\r\xb2\x9c\xbbF,\xc5v\xc7\xf0\xbf:\xdf#w\x0eze\x97!\xb6\xe7\xc5\xab>\xfb\x1e\x87\\\r4\xf4\x87\xa61\xf7\x10\xef\xab\x89\xe3\x10\x85d\xe7D\x16B\xc9\xd1\xb8yCM\x17u]\x94\xb9\x1a\xbbc\xcd\xbbQ7\xa4Q\xb7\xf3\xe0\xeb\xb7\xfd\xa1\xef,\x13\x896\xb3\xf8\x0e\x16\xe0\x84\x8d\xe37QG\x03N10\x94]\x13$\x04\xb8@\x8f\xfb\r\xde\x83\xffa\xb2\xcb\x80\xddf\xba\xdd\x90\xfd\xea0\xa5{G\x7fZ\xc6@e\xc8\x9b\x81\xf7T,\x94\xec\x03a-\xd0\xcf\x9a\xba\xd9\x9d_*=Q\x97n\xa4\xe6\x05Rt7N\x12\xe6\xfc?T\xed\x00*9q\xf4\x8c\xd1y-\xbe\xcf\xba\x06\x82V\xb4\'\xd2e\xe5"\xad\xac\xff`e\xa3\xda\xceX\xa9\xa3{\x82Hg\x00\xc8L\xb7\x8b\xe5\x04&\n\xfbZ\x07#\xd8(\x1b\xa8\xb2k\xce\xab,\xf6\x87\xf6\xc4/\xa2\xa7J\x82s\x9f\x97\xca\xa3\xba\x0eo\x13\x7f\xb1\x97\x9cP2v\xfc\xc0|\xa0>\xeb\xf2\xe1C\x88C\x8d\xb3\xb0#\x98\x98\x07\xb5\xb0\xfal.B\x9f\x97\x99&\xf1\xc7g\x8db\xa2p\xf1\x02\xd7\xe6\xa6\x9d&s=aH<K\xc6\x80\xe5$Vx\xba\xdb\x9a\xfe2\x08O\xa9p\'\xbf\xad\xae\xfd\xe5\xe1\x1e\xc8\xa9\xf8\xd3\xa7K2\x9c\xf69\xf6\xfeZ\\Qx\xef\x18\xed$\xae\xd4\x92\xf6\xc7\x1c\xd6\xe1\xf9\xef\xc2\xaas\x9e,\x917\x1b\xbd\x01\xdf\xc2\x18\x83,Ns\xc9\x13\x91Z\x92\xe7t3\x0bt1R\x9b\xa2Q\xad\xc5\x15\xda\xde\xbf\x81\xc8\x9c\x1fV\x13\xa6\xb2\x17M=8m\xc2\xee\xf9\x86F;\xb9\xc9<\\\x02\xaaA\xd0\xb9\x80\x17\xf8S\xe1\xc4\xc2\x8e\xd0\xdbL\xeb\xd6h\x07K\x0c\xfdh6?\x93}\xae&X\x88U\x89\xabW\x11\x97(\xa6^>5\x13\x84\x0fL\xdbh};\xbf\xf8\x95\xc9\x89\x13\xd2\xf2+7\xd6\xca\x84\xf7\x81\xffG\xca\xea\r\x8b:X"Pu\xa5\tR\x87Mk\xb5\x1f\xdb\x18*=A\xcb\x96\xdb;\xfc\xf7\x0b\xbar|3G=.J\x18!\xbd\xee<\xf5\x83\x1d\xf0/\xc9m+ \xe9Q\xb3M\x88j\x84\x96D\xdc7m^\x98\xc7hv\xff4U\x94\xd0\x14\xd3s\xf4r\x14\xb7um\xd4\xb5\x12\\\x1f\x19\x80Ab\xdd\x0e\xe2\xe4\xbe}B\x810\x8b\x93\xb9\x94\xb2z1\x04\x1b\xc3\xce\x9cq\xd4\n4] \xe3s\x16\xaf\x00\xe8A\x16G\xdc\x88^\xa1\x10\xbc\x85\x89"\xec\xb1\xd4Z~T.u9\x89\xd5\xd3<kke:9\xfa\x14\xefSu\xe8@H\x17\xb5[\x13\x83\xa7\xebO\x8c3\xdf\x8b\xc9\x18zZ\xc8\x92y\xcfE\x90*@\xb1\x17\x8e\xd2\xce\xf1/H\x13\xdd\x83@Q\xde\xc3\x90Q\xda\x89\xeb\xf0\xfe\xa6c\x88t\xa7\xa3r6\xc5<\xcf\x0b\xbb\xd7WNY9\x08b\xaf?\xe3\xec\xabJ\xcc"\xcd\xca\xe3\x87;2K\xcf\xbc+\xfc\x89\xb2\xe2\x93:\xc2\xa3\xc7\x0e\xbf\xda\\\xba\x84\xf7\x96\xc5\xd4\xf2\xe0\x11\xc4\xc9\x84\x87qZ9y\xe2g\xdc\xf6\xda\xdc\x86:\x8a[1^\x06b\xd4\xd3\x1c\x9a\xe0fs\xe5]wPGYv\\\x16\xfd\x14\x1a\x14%\x92\x06\xb9|\xf2\xe3\x99\x98\x86\xfbcr\xe8y\x11\n\xd4a(\xd7\xbb\x04\xa2\xa6\x88\x9c\xf5\xe4S\x7f\xd9\x81\x9f\x15\xf2\xf6\xa4\x01\x1f\x9ex\x19W\xfc71\xdc\xef+\x90\xf4\x8fa\xf4t\xd0y#\x94yw\x02\x8e\xad\xdf\xde\xed\x17~\x9e\x07\x1fc\x98\xa2\xe5pnx\x1d\xb2U^-\x92nek4{\x0c\xb1\x96glD\xff3o\xc7\x18\xb3\xb5}\xe6_\x11\xf6uT\x00\xf3?U@^-\xec\xb4\xa8\xb8\x13\xee\x1c74$\xc0^\xda\x9a\xc1F\xd7 \xa4\x9a\xd5\xc7-\xc09;\xf8{U\xd8\x0eOm\xa8\xdc\x1b\xf8!\xb8\xc1+zH1G<\xb9\xb4I7W?\x7fw\x106\xea,\x04 \x14\x9a\x8a\xe1I\x98\xf4\xb8D\x89_\xc9\xcfD\xcf\xa1\x14\xc4p\xd0[\x81z{e-\xb6\x8az\x01\x06\xaf#\x97\xd00\xec#\xddj\x84\xc1\x865\xd8\xb3\x93\x19\xe7\xe2b\x0e\xd84\xf0~\xcf\xa6\xbd\xa5\xc7\x8fK\xc5a\xd7\x98\x06\xf8\tq\xa1\xba\x01\x93f\xe6\x81I\xb9\x86z\x93\xb5z\x12\xa5*\x04\xaa.\xc7\x11\x94uJqxb\xc1\x19\x90*5$\x14n\x98\x01Irgq\x0c\x84T\xcft\x86\xf7}hl\nN\x8e\xe8_R\xccQ\xce\xe6\xed\x00\x037B\xec\x88{+\x0bZ\xfd\xf1\xf3yH\xd0\xfcGu\xd45\xcfG\xa5\xd5\x0f\x91\xc0v\x99\x180I]\x88\xf9_\x1f|\x9b\xa6\xdf)\x8a\xef\xce\xb2\x9e\xd3\xcf\xfc8\xa8\x94\x0b\xa54i\xbc\xe0\xaaa\xa3\x9b\x15\xc1\x16\xf3\x9c\x8f-\xa5\xc3\xf8\x8b\xf7(\x08\xac&\xe9^\x14eN\xe6\x11!\xa5\xca\xe8f4\x95\x0b6dE\xb7p\x1a\x1f\xbf&\xc9\xd2\xf1\xff\xbf\x0b\xd1\x06\x082R\xdf\x8f\x05\\\xf8RP\x97\xa5G\xe1:\xded\x15`\x0b\xf6zST&\x90\x83E\x93\x93\xe9)\xb2\xcc\xc6\xcb=\x1e\x81\x92\xc5)\x06\x896\xaf\x0b\xd4k\x85\xd3\x11\x82\xe4\xb7;\xfd\x1bL\xc1UYh\xac0mH\xd2%\x90\xf1"\xe0Tv\xfbW\xb5\xe5\xa0p\xe8.!gF\xfd\xfe\xf60\xf6S\x99l\xd3\x15\x0b\xef\xad\xcb\x18\x94P\x9ei1\xba\\y\xf3\xc5v\n"2\x88\xbe&`\xbbr\t\xde\x95\xc4\x0b\xac\xe1\x92Y\x16\xec:d\xd2y\x9d\x1a]\xd9@\xd0\xab\xa1/\x86.\x110i\xbf%H[W\xec\xb2\x0f\xfd\x14\x1d\xad\x1a0\xf0%l\xc5\xa5q\xb9\xee\xcdY\x9d)0\x02\xb7\x98W\'p\xb0\xe0\xd1"\xb4\x07HZ\xb1\xfc\x1bl\xd8[\xfe\xd7\x0f\xd0yb\xc4\xa9\xf9A\xa5\x99\xfb\xb8\x94\x88i@\xca\xe4Rr\xee\xe4\xf2\xce\xd4\x15\x98\xec\xe2<\xbd\xd5\x98z\xc2Y,\x01\xc2\xb2J\xd3\xf1\x10\x94D\x1c\x98j"\xb2\xaaC\xb9p4EC\xca\xf4[S`\xe5\x8e\x0c\x87\x92L\x9a\xe8\x82\x98\xfa\xe5T\xd75\x18Xc\xce\xf4&.t2\xe8\xc5`\xc7!\x07\x96\x9f<\xe3]\xc9\x9bD\xba;\xa1\x01\xda6%\xbf\x91\xe0A\xfb\xb5\xd7fg\xaap\n\x82\x9d\xd6n\x8e\xf5\x82\x97\xc4\xeb\xd2\x10\x08\xe6\x8a\xec\xbf\xbf\xf6\'\x7fv\t\x04\xaa\xa3\xda\x13w\x94\xd5\xf9\xfd*\x12 \x0f\t\xb8b\xf1\xaf|\xa2\xc9C\x0c\x91\xbe\x01Tf\xb2o\xa1\xf9-\xca\xbae\xac\xe0[{\x95P\x02\xfa\xfb\xf7\x93*Z\x9e\x97\xf8;\xaaE\x02\x95-i\xd7Rny\x84\xdd\xa4wN\x026\xd8Y\xdc\xef\xf5\xd8/r7\xc7}Z\xec\xfc\x0fL^\xbd\x80f\xf1\xdc\xa7\xb3\xb4\xc6\x01\n\xbf\xab\'0\x10@jq\x12D^\x9d\xd8x\x99&\xe1\\;\x98_)S\x7f\x19\xf1\xa7\x14Sh6r\x8aG\xf8\xf5#d\xe6:[4Q=\xc9h\x15\x92{)tS\x97M\xa1\x7f2\x92\xf3\xe0I.\x91Tm\xf7\x82\xbc\xd0\x81\xd3\xb1\xc9/\x82\x96\xbay6\xca\x02\xdd(\xce?1\xb4j.)D,\x0e\xdd\x15]\xa25&\xef\xb1\xfa\xd2\x1e\xc5\x98\x0c\\\xd3\x0c\xf0\xbf\xbby\x9bh\x08\x1d+~\xbd\x92\xf5B\xec.\xcb\x87\x93\x97\xd3\xb5\xd7:\xa0\x83m_\x8f7\xd2\xb4\x16\xbdy\xe4t\xd4sa\xf1\x9e\x93l\xfa\xb4V\xaf+qL\xee\xc8\xb3KAYC\x1b7\x02K5\xa1\xe3\x89\xae\xe2\xd5(O\x96Ih\xc2\xea_!fq\xdfl\x96)\x8e\x87\xd6\x80\xde\xd0\r\xdfF\x1cI\xf0\x1a\xcf\x14\xfaFp\x032\x15%^\xb8\xe7XQ\xde\xfb\xd6r\xf95O\xb4\x15_&\xff\xd2\xca\x8f\xae\n\x81E\xd3\x06\xedM\x8d\xc2j\x07\xees\xdcv\x10|\xe0\x1d\xa2\x00\xda"\x8be\t\xe0\xb6\xab\xa1>oI\xbb\x99\x9c?`\x0b\xf4S\xc6\xb5Zo\xe6\xf0\xcb\x84L`\x83\xc3\xdb\xbd\x8bJ"\xa1\x82\x1c\xc8\x82\x19N@mZ=0_9\x0c#\xed\x1aP=\x04`F\xd3\xff\x1a#\x81c\xa5\x8d{\x03\x1b\xee\x08BgH\xbc\xe6ziLz1\xef<\x80\x02\x01R/\xff,;\x15\xecN\xec \xbd\xe8&\xf7>}\x915\x00\x1a\xe0\x94!\x08\xd8z\x8d\xe5\xd3\x075\xbb\xcd\xb6\xa0\x02~\x90\xdf\xc5\x1f\xe3\xe6\xf8BK\x83V\xb1\xf0\x1a\x10\x19\xcaZ\xa8\x02\xf9\xe1\x01\x01x\x1c\xc1\xd1\xe5\x00\xbd\xf9y\xcf\xfak\x01\x04\xc8\xbf\xe2\x8f\x99 \x07\xa3E\xe8\xa5#g\x02w\xa5O\xd0,\xc0\x86 \x9c\xdf\x89\x04\t\xbb\x0b6\x854\xe9"j\xe8\xa5]\xa8\x9en\x10\x87\xbaE\xf5\r\xcbc\xbd\x1f\xfb/\x19\xc7\xcda$\xb75\xee\x83t#\xb0\x9d\xa1\x97\x0eO5\x80\xa7l\xfaZ\x0bY\xaf\x1d\x98r\x0c\xf2\x11g\xebO<\xfbFT^\x16\x86\xc5\x80\x04\xdc\xd3\xff)\xe7!n\xf3\xa6\xca\x17V\x19\\\x9d\x8d\xa8\xf8\xb8\xbd:\t\xb4\x8au[\xa8t\xecd[\xc6\x85\xe8G)\x13\x85\xc0\xb8\xf6\x1c;\xc0\x16\x9f&\xcb\xbe\x179\x16\xf9\xc0\xfb\xb5\x94\x92\xc3\xd6\xdc2\xb6\xa9~\x96\x17\xb1k9{k[\xae\xa4\xda\x96\xa9\x80\x80\x9b\xa9v\xdd@>\x84\x8aM\xac\xdc\xc9\xa4I\'>\x9b\x83\x96\xcf0\xfe%\xd9I\xca\x88\xd7\xa8\xe8$\x0b\x82/`<\xc0\x83\x7f\x11\xae\xe8\x13rg_\xa4\x07\x1eb\x88(\x88.\x07X5\xfa;\xb0\xdc\xdf,jPT\xee\xca\xbd\x96\xb0C\x91\xa5\xb4\x04;+O\xff8\xf9\xf1\x9e}g4\\\xb1\x02\xcd\x18d=\x11\xc9\xab\xe5\xeeNcX\x9a\x9d\xfb \xbd\xa6\x94?\x99\x10\x0e\x00a\xe7\xd6\xea\xa2\x068\x0f\xc9\xbb\xdc\x01\xe7\xdf\x06\x9c\x80%\xd1C6\xbd\xfd\xe5eDp\xf6\x13\x8e>\xe3\xd0Nr\xbf\xf5\xa9\xf3\x06?\n\xf4\x87\xc9\xa0M\xea\xec\x17\x05\xfcQ\xf2\x01\xeb\xe20l,\xfd\xf1P\xdc\xe5\xa7N\xc2\x08\xeft\xd2\rS\xf6\x85G\x1a`\xf0\xf9\t\x0b\x03\xdf5\xdf\xe0\x8e\xa7\xc7\xbc\xcfdGg\x84\x04k\xbaL\xeb\xfay\x1b\xca\xd3\xcc\xeaT;\xa1n^\x84c\xb6\x0b\xcc\\\xb9-\t%\xd2\x1e\xc0d[uN\x8d`\x1d\xe1_\xcf\xda\xa7\xc3\xad\x1d\xd1F\x8d\xfc\xd6\xc8\xfa\xa8<\xefz,\x12\xf2\xba|\x8b\x8d&\\\xba"|\xb7\xb8\x13\xd7\xe2\x18D\xa2@\xc5\x1b\xc2kR\xefu\xd9\xa0\xd5.C\xbe\xe3\x84j+\xee\xb8\xf6\x91\x1bA\xac79\xce\x8aWiu\xb2\'\xca\x83\x96\xb3*\xb4\xd8\xa3\xe3\xefC3v\xea\xd0\x01\x93$\xea\xc2\x8emg\xfe\xf9\xc7,\xcf\xd2\x05-\xf0\x00\x0b\xf8bU7K\xbd\x86\x10D4ME{\xc7\xbd1~\xec\xc6K\xb0\xfaL\xeb5\x0b\x19\xe4\xbeJ\xc1\x165\xc5\xeb\xc6BA3p\x07\x7f\'\xd5\xad$\x8fu\x9f0\xce\x1b\x1e\x9e{o\x1d\x12\xc0n_\xadG\xfa\xc3\x8e\xbd\xbe\x16\x17,s\xcb\xb8^{\xee\xc4\x14\x1b\xa4\xcd\xe7\x17\x85\xf5\xc9c2\xde\x89 d2\xa3\xd1\xf6{\xabv|\xba\x06\xdb\xc7\x0c\xa9<\xb1j-q\x86(\xa1\x01\xde\x98\xf5\xb1\x83\xf2X\x04\xb7\xb4\xef\x1f\xd9\xaf+b\xc9\xa1&\x93\xba^\xc5\xca\xa2\xe7}+\xa5N\xecu\xaf\xb9E;\xe5|e\x8b\x17\xde\x0cW e\x87u\xd6\x03\x9f\x88\xd5R\xd1\x01\xae{\xec]u\x15\xe2\x1e\xf4\xe7+\xbe?\xde\xc9\x0b\x96l\x9dc\xc6\xe5\xae\xa5\x13*\xc9B\xf2\xa1\x07\xb0\xda\x1ef\xd3\x0e\xfc\x11b\x01\xc2ha\xf0\xb9\x88\xec2p\x83\xc3\x07\xe0\x19\x80qFR\x03\x98m\xff#H\xfe\x14\xc2c\xd1\xd4\xd1=\xc8m\xb0I\xb7\xc3\xd5g\xdbF\xf6\x80\xec\xaf\xcc\t\x94\xc9\xee\xc5\x8b1\x176f\xa2-~(\xaam\xfc\xc1i\xff\xea\xaap\xbd#4V\x16\x9f\x8e\xb4\xb8\x1en\xa4\xc7\x1bl\x13\xd5G\x8f\xa8\xd1\xbc$\x8b\x9fA\xfb1\x1e%\xc2\xeba\xafS\n\xf9{\x1a\xde\x18 \xac\xd3e\x88\x0e\xcc\xadq=V\xd6co\x00\x0e\xc4\xa3\x88\xd3\x9f\xdc\x9cqJ[\xa6\x05U\x19r\x96WXX+\xcc\x14\xce\xd2\xf3;\xd4\xc0\r\xbf\x97C\x00O"\xcaf\x1b\x1b\xa6\x16m\x9f\xf0\x88\x08\x12\xf5#\x0e\xff\x01H\x17\x9d\x8f\xf1\x0f\r\x1d\x11\xfcN.\xe2\x1e\x7f\x16\x92t\xd2\xd2S\xe4y\xe9\x16_K\x1dI\xb4\xc7\xbf\xa6YA\x7f\x18\xce%\x9bQ\t6\xb6\xda\xa3<\xcd\xa9\' \x93\xac\x10e\n\xd2\x8eM\xc8\r\xdf5\x9a2\x8c(}Qt\xf884\xca\xcd\x94\xd4\x16[\xc9nnZR\xbf\x01\x814\x80\x86\xfe\xb6-\xca\xa6\x80\xb5x\x11{\x1b\xdf\xbc\x1f\xac@\x85)\xe3\xc1w\'#\xfdP\xef\xa1\xa3\xf1)$\xc2=y@\xce\xf2\xa9\xbcz\x0c\x15uB\xff?\x83\x82\xab\xca\x7f\xf7^\x91\x9b#o\xd5\xc5\xaf;0\xbf\xb5\x8c@\xd4\xff\x92\xbb\xc6M\xf2\xc2}\xee\xa8\\\x0fa\x9f\xef\x80\xa3\xbcm\x03\xceA\x0c\xb8\xa5\x94\x9f\xcc\xb1\xdb\xe3!Ze\xa1?\x8b\x13\xb2}-u\xbe\xde\x7f\x18\xcbG\x1a\xabk\xac6\x90X/\xb8fT\xadP"\x9b\xab&\xd9a\xa816\xca\xf9.\x06,\xbczV\x06\x87\xed3\xc3P\xf4\xec\xef\x82\xed\x08\xad\xfb\xdc\x90\xc1\xe3[\x8c\xd3h\x15\x07\x8d@\xa0\xa0`;\'\xc1\x84\xadj\xd4\x0f\x99\x8d\x96\x06\x99|Z\r\xa5Ga\xdbLT\xdd\xac\xfc\xd6t\xf0\xa3)\x82\x1f\x8a=*\xa3]\xc0$\x84nFyK\xf2\x92\t\r\x9b\x8a\\\xce\xc5A\x14\x1b\xa7v\x9e\xf1\xf3\xcc\x92y\x14\xffI\x1b\xaf\xc5u\xdaA\xaf\xe1\xd0c$\x06\x14%\xf7a\x11$\xe0\x1e\x84\x10{J5yg\x94\x12\xdb\x7f\xf0\xdcG\xcb.\xb1\xa4\x0c\x9f\xa7#__-q\xd6\xcd\x0c\x8c\xe2\xbc\x0c\x94z\xf5A\xff\xf7\x0ct\x1a\x97\xb9\xd2\xc6\xbaB\x81\xbf\xa7j\x14uUx\x9b(\x85\xd1\xfds\xc6\xbd\x00>v\x10\xa54kHEb\xe8\'{\x18\'V6\xf2\x9ew:F\xf7\x8f\xbd\xaar!\xf6\x83\xb3\x05\xf9Q\xa2\xe7-\xbd\x17\xbf&\xe2\xf0,@\xa2\xf4\x1f\xcfn+]\xd7\xa2\xe8.\xac\x83\xb8\x01O0\xedJ\xb0\x9c\xbf\xe05|\x04\x9d\xf3p\x9bWq\x8cY\xf4\xa7p\xf5|\x9d4\x90\x1f"\xc0,\xf0Pw\xc1\x8b\xec\x17\xf5\x96\x1b\x18\x98r7\\s\x10\x07\xc4A\xf6\xebh]\x1aJ\x99\xb0\xf7\xbd\x0b9u)k2\xa0\xbc\xda\x08T%\x80\xb5\x15\xfe\xbbd\xc1\xb2\xf4\x84Cfq\x94\x900\x85X\xd7\xb9\xa7\xd3\x002\xf3\xe1\xa3\x97\xfdZ\xbbb\x85\xd6\xac\xd9u\xba{\x03i\x0e\x82$ 8\x98T|C1C/\x0eK\xcf\xf2\x87 \xa1\x96\xea\xaa\xda\xc4g\x7f\x99P\xf2\xeeD\xc0R\xea\x84\xef\x9a\x08`\xf8<\xbb\xads\xe8K\x02Lz\xea\x9f\x7fH]H\x9fN\x8c\x8d\x90\x94?\x8bOF\x1b\xf8\xf7=\x0e\x0c\x06$\r\x13\xd2\x1d!\xf2q\x0b\xf9\xdc{5\x1dW\r\xa5\xceLH\xac\xcc\x99\xb4eQ\x97j\x90\x99\xe7=8\xc3\xf1~e7\xac\x8f \x04 ,\xb7\x9ck\xb6q\xa6\x18+\xab\xe2Xy\xbd\x9dr\xa6\xfe\x9c\xebP\xfb|\xea\xb8\'\tD>6\xe2\xcd\xecS\x1fC\xa9\xe2\x01ph\x92>+\x927\x08Ey$\xd3\x13\xee\x03\xc3\x0f\xb98\x8f\xfc\x0b}bB\xa8$t<\xe0\xa9$\x80\x87\xff\xb2\xaf\x1c\x04t\x82Q\xba\x96>D\x19\xca\xbc\xc6/\x84x\xca[D\x96\x8d\x81\xb5\x19\x99h\xea\xd6\x95\x9a\x91\xb8Q\xfb8\xe9\xc9\xead\x87\xd7\xcb\xb6>\xeao\xf7\xb9*\t\xee>\xa6\xaa.\xe2\x892\xe9\xe7\xf9\x1e: \x84d=\x9aE|\xcc\xbb\xcc\xc7\xa1g\x9c\xc8\xa8\xef\xbf\x0e\xdf\xda\xe9\x03\xddAy|\xe4\x88B\xb5SA\xe5\xae\xb8\xdd\x07VF\x93\xadn\xdc\xdf\x86\x13N\x1d\xe5\x92F\xc0\x0e\x13M\x08?\xb1x\x13o\x9duSp\x8c/}\x90h\xe4s\x03\x19\x1c\xf0\xf8\xdc\x8d6\xf8Z\xfd\xd3t\xc6#\x92\x0c0\tv\xbc\xe1\xe0\xfa\r\x9a}\x0e\xbf\xd9\xe8\x12@h\xcb\x131\xec\xd7\xf8/\xd3\xf1\xfb\x93\xe1\xe8Q\xb7\xa4\x00\x19\xccZ\xae&:Z\x8e-\x8f\x9f\x1e\xf0\xbd\x10:\x0fJ\xf7\xb63\xf8\xec\xc9\x00u\x00t[\x1f_\x19\xe4\xea\xa0v\x12\xac\xd1\xa2\x81\xf5\x13\xff\xef\xbd\xc3\x10\xb9\x11a\xea\xd73\xd9\x7f\x8d/\x01\xbaz\x87\xb8\xf6\x93\x92\x180\xfa\x02\xb2$\xc5\xc2\xb4rV\xf5\xb6\x94\xa9\x14\xaf\xf419$k=g^\xa8\x10\xe8X\x1e\x81I\t\xa7X$h\xda\xdf\xe2\xd9J\xa3P\x16\xd0a\xbd\xe2\xc6Ka*\x8b\xd6\xdc\xab\x90\x97\x00\xf2\xd4\x87\x00Q8 \xd1\xd5\xf99\x9d\x10\xd6I\xba)\xf4\xf7R\xc5\xb6r\xfa\xf9\xa9\xab\xc1\x86\x96oU\x9e\xbb,I\xad\xbfG\xe4\xae\x1b\x15j|\xa1\xe0!\x16j\xed8qPeE\xeb\xf5\x14$\xf3q\xd2:.\xef\x96\x1be\xa4xi\xe5%\x15\x83\x89G\x84tN\x06\x98\xd376\x1e\xbbz\xff\xe4\xd1\xd8\x1e\x92\xeeT\x95A\x11\x89sT\xb7\xfc$5\xe73\xa5\xd2\x92\xc7\x19#\xac\xcf\x04\x88\x9b\x18\xdd\xe4\xf0I^x\x9e\x81\x11\x87\x93\xc9J\xb0-!\xd4\xab\xa6\xa4\x98\x8d;\x89\xd1\x9f\x86\x1bSD\xa7\x0f\x0bG\xbcr\x8f\xde\xd7\xd2,\x0c/\x98\xd5\x85\x19\xb1T\x18\xd1\x06\xe84\x0e\xcc\xe2\x7f\xd5\x8c\x81\x82\xf9\x8b6Q\x9f<\xa3\xee\x93\x9c,\xc9+\xb1\xdb\xd2\xb8\xee\x85M\xa6\xe6\xfd\xf7H`\x03\xc4\x99\xac^\xf5\xa7\x12\x01\xd2\x02\t\xd9A\xff\xd4B\xfa0\xf9\x926H\x0e<\xf3\xb9\x0b\xea\xed \xa8e.\r\x8c\xb8\xdeu\'\x93\x9fy\xb6&\xab\xbb{\xcd\xc5.^A\xd52,c\xa8\xd8\xf71;\xfb\x80\xdc{\x9d\xe8\x1c\xce\xf08%\xec\x1e\xc9O\x9d\xf6{&\xadc>\xe6}+\xe6\xc4\xfc\x18\r/qZ^\xf7\xe5}\xeen\x97\xb2Y7\xa8\x82_\x7f\xd9H\xd2\xd3\x19\xdb\xcb)\x0c\x17\xe5\xf5\xc6v\x0f\x9c\xe0]38\xda\x03\\B{\xbb\xfdH\xa7C\t3\x8a\xa4p\xc3\xa0\xe4[\xd5\x82K\x88\x96\xe8\xbb\xc7k\xdbC\x15\xdb\x9f\xb7>\xd3\x94\xed.\xa1\xde\x04\x0b\xef\xd9\xa6\x11w\x0b\xc9I\x88\x0b\xd4"s/YQC\x18M\xf9:\x8d\xed0\x92\xc9\xc0\x9a\xfc\xc4\xa9\xbf\xf9\x19.\x88Z\x0e\xfb\x83\x94Q\xce;\xca\xec\xdf\x8a1D\xe0\x84\x7f\x10\xa0\xd8\x93\x8dZ\xc5\xaa$\x8d\xff\x84+\xca\xaf\x10\xa53E:\x7f\x92}\\\xc04g\x86_\x12\xaa\xc32\xa5\xfc\x97\xf0\x1fr\xbc\xb6Q\xc10\x8a\xbf\xe6\x93\x01\x0c$\x8a\xf0\xca\xf4\xe7\x1f>1\x7f\x05\x8a<O\xfc\r\x08/\xee\xd4#c\xe5>\x87&Bg\x8c\xc3\xeb\x8c\x0by\xa8\x88\x8d\xa9\xdf\x99\xcd^\x95\xdfr[JW\xf8\x9b\xf8\x10\x14i\xfc8?\x1f\xefhN\x10\xdaE@\x19\xaapo\xdaI\xdckA;\xfe\x18\xed\x96.\xc5H4\xf2\xa5\xfd\x94\x9e\xfa\xa1\xe8\x8f)8.\x99\xd8\xbd\xd0\xd1N\x9eM8Yp\xbc3\x05/9\xd7\xc8\xdb\x02\xf5\xf6/S\xe5g\xba\xd5o\xa7\xc2\x9e\xae\xfd\x04}x\xa9\xf0\x87\x9dI\xc7\xcd\x9ca\x9c\x8e\xd1\xe2\x0e\xecX\xe4\xe9\x9f\xa1\x1c\xd9\xc9\xd8\xa4\xa4\x95\x05g\x8bv\xbb\xb6Hr\xcd\x1e`2\x8b\x80\x0f\xa5W6\xcb#\xe0\x82j\x11A\xe9^\rW\xbb\xf2\xb1\xe2\xde\x91\x89\xb9\x0c\x91\xc3\x0fN0:\xb9\xe2[\xbc\x89\xcd\xaa\xf2\xa4p\xed\x0eI\r.\xd4\x99.\xae\xb4S%\xadq5\t)\x02\x85\x02(w%\x92\x08\xbc\xe1\xba\xab(\xdc\x94\xd7XD\xab\xe4\xc6 \xa1\xd94\x08\xc7\xe1\x14tQ\x06wEaH\x11\xd7N\xef\xf0\x12*\x85\x03\x95c\xc0\xa0p\xbc\x9f[\xf0\x05@U\x0b\rQq\x16$\xda\x9ck\xf7\x15x\xb0\x8e\xf5X+^\x17\x83\x97}\xefd\xf8C\xab\xb3(\xab\'}bX\xde,\xfb\xda\xaddFv\x03\xaa\xee\xb2ix\x0b\x8b\x13\x0b\xdd\x9f\xd4\xfb\xf34\xb9\xa2H\xfa\xba\x86i\x8c/z\x9d\x9d\x063se\xbe\xcdD\x16C^C \xbf\x1bS\xc7\n\x9a\xb3\x1b\xe1N!\xa6\x06c}F\x94\xc9c\x94J\xf9x\xa9\xf6\xf7\xde4[\xdf\x98P\xc7\n\xda\x1a\xebO\xd0\x8e\x9a\x0ecS\xb5\xa1\xeeNN}\xaa\r\x0b\xdf\xc8\x02\x9d\x84\xb0\x83\xae\x8f\xf0!dU\x82\x1bZ\xe5U\xdcPYR\xd6\xab\xe9\xfc\x05\xc1e\x7f\x8f\x8a;\xe20\xd9\xdf\x16\xc2\xe9\'\xf58\xec\'\xc2q\xaev\xf4h}Y\xd8\xff\\\x9ag\xbf\x1c\xe1t\xad\xa3\xb5\x93\x81\xbd\xc5\xadK\xb5\xc0\xcbu\xe1\xac-\xc3|\xb3pZ~n)w\xa5\x9c*\xf7STt\\\xfd\xc9a\x16Ge\xcf\xedn/\x7fUDl\x98\x07d\x9c\xdb\r\xd5\xff\xe3#\xd6s\xa1\x0cTZ\x95\x9f\x01XZmLw,\xcfM\xf6\xb6\xceg\x84=\xb1\xf5#\r%\x93X\xee[B\xf2Z\xfb\x82\xb1z\x0c\x99\x01y|\xbc\x8a\xef\x15\xff\xd3\x16\xdcrs\xfe\x9d{R\xe0\xb3fbZ\x98\x00\xd8*\x1a\x8cg7EI\x93\xc6~\x18\x8b@\xdf\x00\x8f\xa0\xe9\xc7\xa4\xe1\x9b\xb0\x18\x04u\x1a\xae\xa0XV\xa8P\xff\xe3\xeb\xa7M\xfd\xf14N\xe4\xf2t\x98d\xc4%\x89X\x1fl\xdd\tl\x9f\x17\xfc[\xa4L\xee\xd2\x84v/\xf9@\xaf\xec\xe5\x85\xb3\xd2eE\xbaJ\xdd\xd5\xad\x82\'\xb0\xfb\xbd(\xbbg\x06r\xef\xd0\xeb\xd6\x00HS\'\x03\xe2\x9ea%P\xc1\x0f\x9c\xc6\xe3\xf33\xf5m\xf3\xe77\x13\xdfe\xb4\x8e\xc5Z\x06\x9cJ\x86\xb8\x81\x99`\xdd\xf4\xaa\x13\x84\xcfw\xae\x8d\xc6\xd1\xb3O\xbf\xf68T16 \x910\x88b\x1c\xe0\x9a\x99j+y\xd0<\xa8hA\xe1m\xed\x02\xa1\xbc\xa0\xb0\x9a\xdb\xc8\xb1\xde\xd2e\xe1Jq>%\xa7\xcaY0\xbcP\xd4\x93=\xd6\x98k\xca\r~\x07#\xe9\x1c\xf2{\xa7PC"\xe2\x94\'\xb5%\x92`Bm\xf5\xb7r\rpg\xbd+\xb0\xb6\x1c\x8a4\x0f\xa9\xe5\xfdn\x86\x96\x98\xb2\xfaB#\x1422\xff\xacz\x8e3\xb7\xca\xbaW\x97P\x9e\xd3\xe7O\xd6\xda\xec\x8f\x00Xdm\x1e\x8e\x86F6r\x94k91\xb5A\xa48\xa6\xc3\x1b\xeb\x9e\xf5\xaa\xf9\xd6\\\xcc2K\x8f\xfc\xa7xvWg\x18\xa7\xfd\x00\xe05h\x080\xbaI\xd8\xba\xc0\xcfU\xe8\xac\x8bd\xf6\x95xf \x02a@\xc9\xc2\xd9\xacx\x87Y\xb7 \x98D\x94\xc9\x1b0+\xaeR\x17\xee\x14Z\xf2y5\x87\\\x83K\xa6\xe9\x03_\xb6=\x83\xd4%\x14\x8ev\xff\xccX\x91]\xe6YH|$\xf1\xf2\x84\xb4\x7f\xf7\x02\xa8\x10!\xb0\x04\x1d\xef\xb6R\xc9ma\x81\x10\xb4z\xe7\xc0\'\xe84\x80\xd5\xb4\xfeH\xa0\xcb\x15\xe8\xde)|9A\x88V\x1e \x0fL\x14\xca\xb9\x85[\xd8`j\x0c\x967\xc9[\x8c\xf9\xa2\xe5\xac\xb8n'
    assert kp.verify(b'a', sig)
    assert kp.sign(b'a') == sig
    kp = KeyPair.from_digest(bytes.fromhex("e3d6a70c91d8fb8d01a1485793c81cf0836b47aa1d4650d29165f4cbe4691b7fb32073f1e41a90ab0307db1d0e78a0f6643b4615eb1899c34907deb8e3e0c368e3d6a70c91d8fb8d01a1485793c81cf0836b47aa1d4650d29165f4cbe4691b7f"), shake_128f)
    sig = b']\x8fm\x84G\x8bY\xea\xd5\xdf\xaf9"1\xe1\xa2\x82\xc4\x84\x93\x9a\x0c\xfe\x1e\x90J\xa9\xdac\n\xa7\xde.LD\xf9\xd2CAj\xa6\x81\x9a\x91\x1f\xdfO\xaaPP\xd6z\x81\x1d\nB\xe4YlYB\x83\x1b\xee\xe7\x0f8\xca\x89t\xa0\xa6\xe5q\x8e.4>\xbf\x88^\xa0\xc9\x87\xddD=\xe5!\x1a\n\xc7\x01\x18Y\xef_\xe8\xb6\x89\xach\xd6\xdd\xc2\x9aP?\x1d\x9a\xd4\xb2\x11\xd6\x85\x85\'Z\x07f\x06p\x8a\x1e^\x8a\x00:A]\xe8\x07\xb0q\xeb\xed\x91\xc3\xaf\xd6\xe8bXd\xf3\x10qi1\xc9\xd6\n\x9a\xef@\x18b\xff\x12}\xfe\'\x17\xa1S\xf2\xb9\xd9\x1c\xdd\xfc\xa8H\xb2SCt\xee\x9b\x13\xb6`\x13g\x00"\\\xa6\x01\xed\xa0u\x8c\xa2[\xc0b\xa6\xb8\xe9a\xb3?\x08\xfa[\\\t\x13\xce\xf4\xed@\xf9"\xd0\x16\xbakM\xaf0m@\xfe\xa7tDn\xf6bks\r"\x1c\xa8\xca\xcb\x97\xe8\xe8j\xbcg\xccW\x18\xc5\xaa\xcb\x07\x98r\x17\xb6`\xa2\x91\xfc!&N\xa2cPh8\xe3\xfc\x04\xab\xf2\x03\\r\x88\x0f\xaci\xff\xea\xafL\x85\x18\xa0\x90n78\xbc\xa1\xc8\xbd\xc2A:,s\xc4@=^\xcc\xf9\xf4\\\xfb\xe5\x80/\xff{\xc5\xa9\x19\x84r\xa5\xe1\xf0\xf0\xa5Pkrr\xd7\xb5\xe1S\xbb\xe3\x9f\xaf\xcc\xc6\'\x00\x8d?V\xdd\xf5\x9d\xf5i\xe2\xd2\xbeRi~\xe4Yd\xe7\xae7\x98\xdc\xd9\x00\x9e\xd7\r\xc4eV|=\x91\xe0\xf1\xef_\xcf\x97\xb8\xda\xe2X\\m\xfd\x8e\xce\xc7Y!\x87\xb8\x1f\x0c3\xd8\x181ZH\xd8\xec\x83\xca\nn6e*kC}Q\xf7\x9dZ\x99J\xe7R&\xb1\x18]\x9a\xa72\xf9Og\xd4\xcdn\xce\x80T\xde\xcc\x1e\xa8\x07WA\xc4\xa8S\xe5\x9a\xd3=wco\xf3\x1a\x84\x1d\x95\x8dEUP\x84kSO\x9do"\x1f\x82\x17\xba\xbc7\x06 \xc2G_\xeb\x19.\x88\xa9\xb2\xaf\x10>{\xc6\xb4\xedq\x94\x01\rI!\xed\x8a\x1fH\xf2\x9c|\xdf]U\xb8\xb7\xe4\xa6\xc1\xef\ri\x00]\xbf\xb8\xc5\xe2SL\xec>1a)HF\xbd\x8f\x81oo\xc6Y^\x07V]\x07\x17@(\xa5\xb5:\xf1\xf0\xa1v\x8eX\x96\xf5\xef\xd7\x8cO\xb6^\xb3q\x0f\xa6\x0eA\x93\xac\x0f\xa0\x047N\x1a\xe8x\xbe)}\xe3\xa1p\nx\xfb%\xa6\xf2RI\xbc<+R\r\x97/\x84\x8a{\xe0v<\xa0U\x95\xf84%|]\xc1W\xb6\xf2\x8f\xef\x86;H\xa4\xc2\xc3H \xa2\x1d\x04\xbf@\x08\xe0\x1d\xec\xe8I\xac\xd5\x9f.\x83\x9a\xf0\x12\xad0\x9ckJG&iD\xd2\xa9bF\x0e\xa7\xb6\x14\x8f-f\x82y\x91p{\x01-^\xd3_\x86-\xde9\xfb\x15\xe1\'\x9a\xf9^#\x97\xa4\x16\x92\'N\xed\xbe,\x0e0\xbbv\xce3\xb1\x1b\xd2h>ux\x83\xe2\xc5g\xc6\xdd\xa7\x84JV\xdf\xee\xde\x84\xa1\x1e\x15\x1fE\x89}\xf2\xd8ZfGh\xfc\xe3[\xb7\x9cfL\xbb\x1a\xdd\xbd\xe98gK\x034\xf4\xed\x03>\xf3FC\x93\x04}\xd8Nx\x8f\x8c\x7f\xdb5\xb4\x0b{\xfap\xc8Y[\xd8d\xd2\\\x0b\x87_\'\x10\xf3:\x8a\xef\xfeiK\xa8\x99\xf9\xa50\xb7\xfc\x8b$1\xc0\xb3\xbc]e\xf4T1\x0e\xcaad6\x01\x8b\xe3GwK\x1f\xb7\xf7t@a\xba\xeb\tm\xf2\xa7\xa0\x05\xea\xe2\x08L\xab\xb0)t\xe9\xe8\x05\xf8\xef\xa6\xb6\xb6\xe9\xf9\x86\xb4\xa5\x9b\xaf\x99\xf4\xde\xd9w\x9f\x87ZB\xd1HG\x9dn\xc7x\xdb\xb9\xdatf\xb8\xe290\x066\xad\x96\x96\xc1EN\x06gMA0\xc7\xc9\xeb\xd8V.\x98\x03*\x0e8Iz6\xb6@-!\x82z\xdb|\'\xb69\xf9\x1e\x19\xf3\xefT\x8d\x02\xbb|\x1a\xac\x126I\xe8\x02\xd4K\xcdqi\x95\xd5\x7f\x92\x99Z\x04\xb2\xb4M\xbbi\xf9\xaa\xc2\xae^M\xb9A\x9bf\x8eS\xe0\x10\x00\xee\xa1\x02\xdd\xd9\x1b\x1b\xf4\x89h6e\x15\xbe\x9d\xba\xb6\xa7\xeaPF\x8b\x08\t\x88\xbe\x9dAOj\x0f\xfc\xa8\xf0s0?\x99\xe7~\x8ck\xc0\xf2\xeb\xac\xf9\xcfL\xf9ocY\xaad\xa6q\x9c\x06Yk\xd2b\\\x16\x06\x8fB\xd0E&C\x1f\x96<@J\xed\tu/\x95\xdb\x14\x90\x07\xe6\n\xb7`\xba\xcb\xc8\x07\xa8d\xd4J6\xc3yUh?\xe8 \xad\xfeN\x00\xcb\x82\xe5w\xed\xf1\xeb\x04\xfcr\x9d{\x1c\xfe\xd1=\xc8\xcf>b5\x0e\xa5C\xee\xd6\x8f&\xbe\x91\xe9\x92i\xe4!qM\xdc\xb3\xb4\xa5\xc7\xcc\x0bj\x0fB5r\x18\x01\xe1\x8dp\x96\xfeh\xbae;\xc4\x17<\xca`\xfdg\x14km\xf1\xbc\xfbH\xb0\xc6\xadf\xf8\xbd\xdd\xef\xf6!\x81T\xa6\xa4n \x89\xaf\xf4\x9f9MS\x12a\x9beM\xd7W\xdf\xeb\x96v\xcb\xfa\x04\xa8{\xdd \xb7\xd9-\x15rx\xe7\x11\xfc\x18N\x1b$s\x1f$V\xc6\xa8\xa1\x8a\x80^q\xdfj\xea\xb3;\x9e\xcf{D\xc6`j`\xf0Gc\x08P\x1aW\x86\xb0=6q\xf2\x97%\xde\xa6\x003\xf2\xfc\x8e\xdf\xb2\x8e\x81a\x10\xfb\x11#\xeeU!\x97\xcc\xe6\xe1\x115\xea\xe1\x12\x84\x9d\x16\x85B\xd5]`\xe13\x05\xf9\x1c\xe36}]S+\n*\xfd\x10\xa6\x1a\x1b\x82\xaf\x86\x85\xd9.\x06\xdd\xb2\x06S\xbc\xec\xf4\xc6\xca\xe2o&\xe5\xf6\xf5hES\xde\t^\xa5\x9c\xa9J~s\xe1c\xcf0+m)\x05!\xc5\x15G6[K\xa5\x01B/UR\xb5\xfb\xc7\x1e\xd8.\x02\xd6S\xbfgb\xe9N\xb2F}\xd39[\x898=O7\xc1\x91Z\xef\xech\x9fR\xccmy\x80|m\xb5\xc3t\xa8\xeb\xc5\xbc\x91\xa6\xa0\x8d\xc9\xae+v\xb7\x8b6\xb5\x16C\xee\x17\x8d\xa7ej\xb8\x9aP\xd7A\xad\xeb#\x7f\xf1\xd3\xe3\xc3y\xed-\x1f\x9bo-\x9c%\x91\x9f\x0c\xfd\xdd\x14\xc0\x02\x02\xbd\xc1\x98q\x1e\xd3\xc8;\xebU\xe4\xd0\xffo\x95x2\x1a\xd0\x13|\x17\xbc\x81\xe6{z0\x8b\xad\xb3\xe4d!\xbe8\x9f\xb05P\xfcM\x80\x88\xe3\xe7\x8d\xb3\x8b\xa3\x90Q\xe8\xe9\xb1X\xfaN\x1f\\\x1c\xb9X\x1b;\x82\xc3\x12\xe5-I\xf6:\xdb\'"*E \xb3\r\xc9Z:\x06\x1b\xbf\xbez\x95\xb6\xae\xa3\xd0T\xc3m\x02\xb3p:\xd9wi\x9aR\x14\xb8o\x14\xc6\x9a7V\xe9\xd7\x87V\x88s\x1bR5\xa8\xad\x9a\x94\xc7\xcd \xc9(\xea\x06!QB\xdc\xca\x1ctRn\xb7m\xddU\x0e\xc2%\x99\x15 MX\xcc\x7f\x08*\xb0i\xf8V\x8d\xf6\xaf {\x91_Z"\xa0\xf5v\xc4?Su\xa1\xe6@#\xbft\x08\xe8\xca]\x0bRp\xdc1\xbb\x12\x9aW\xd9\x0f\xe4\x01:\xb8\xb8U\xc8\xbc\xe9\x0e\x8c>\xbe\x8a\xaf)\xaa\x15~\x8d\xda\x92\xf8\x13S@\xe0Ya>D%\xdc\xac\x94BQ\xcb\x8e]\x02\xf7\xa6B\xa5\xa4H\r\xfc\x13\x83\x83\xf8\x12_(t\xd5\xe0\xf8hl-\xde\x88a{\xcc\xd5\xcbcUn\x7f\x1a\xbe\x94\xd8\xdc\\\xa6\xf6\xdb\x88vq\xb3\xf3\xe3=\x19H\xb8+\xd8\x7f\xd4p\x12\'\x18<%3\xf9\xf6\xb9$^\xb2\x0b\x9ag\x8bL\xb2\xce\xb6\xf4\xbf\xe5\xe36\xf1~g.\x8con\xae\n"~B\x1d\xc5\x84\xa5\x19\xe0;\x98#d@O\x92\xc1\xe2\xcd\x0f(c*hq\xbd\x98\xd1>vV\xaf\xed\t\xefBUh\x8f\x17\x8b\xc9\x93QP~\xe5\xfbF\xd4\xf0\xeeD\xda\xc4X\xd3Sp\no\xc5\tb\xb4\x9f\xcesP\xfb\xd7\x98C\x0f!\x7f\x02nI\x83\r\x8e?\xfd\xc7\xb0\xce\xbc\xc2\xd2\xb8!\x84\x9fD.:\x03%:\xb8!\xf0\xa4\x11\x10\xa6\xbf\xcd\x08\x90\xc6\xc6\xdd\xa2\x92V\xa1D<\x8d\xd0g">\x95-\xa5\xf7\xa2N\tYA\xde\x1f\x89\x11\xcaPZ\xb8bT\xfd\xa5\x18\xcd\x8c\x00\xae\xdeki\xf1\x13\x02\xb8Qxe\x01\xcc\x82C\x999\xe8\xcau\xcb\x96\xac\xb32tR\xc0\x0c\x08N\xec\x9a\xb6\x9f%7\xe2s9 n\x19\xc1\x94T]\xaem\xc9v\x12\xc7 \t\xd0\xf6\xbb\'\xf57\x11\xc5\x86\xca\xe0\xdb$\xfd\x8b\x1c=\xd3tP\xb1C<v\x10\xa0ZqZ~\x8b\xf5\xf5\xba\xe02\xbdA1\xf9\x14\xfd\xc8\xb3\xd7\xcc\xdeJ\x89\x19\x860z\xb1\xd1\x08\xb0\x9cy-\xa2\x81@\x19\xc5\\\xfd\n\xcc#\x8e\xdaE\xc2r\xe9\xa2\r]\xc6#,"\xf2\xc9\xe3j\x8a\xc0!L\x1e\xf8\x12;\xba(p\x0e\xc0\xdc{\xac\x86\xabI\x17\xf3W\xcc\x98\xfc\xdc/\x88\xb0\xbe\xcb\x8dQ\x1a\xa7\xefyM\x00\x83U\x00\xf4\xf4wX\x1a\x16\xcen;\x8c\xc3\\\xf2\x1c\xcc\x00\xe1[\xb9xS\xfb\xd9\xd6\x14\x9d\xb2\x9d\xc1\xaf\x19\xb5x\x864%\xd0R\xe1\xed\x10K#\xf2\xe9\xc3E\xdb\xe0\xae\xec^Dl\x8f\xd14\xf2\xe3\x9c \tL1\xc4\xc3\t\x86n\xa2\xe2GSg\xff\x06"\xdf\x85\xfa\xa6\x94t(\x8c\xd0\xc4\xfc\xf9,2\x12/T=\x9e\xea\xe5\xa0\x9a\xe8\x7f\xf9\xbd\xa9t\xd5\xea\xa0|+$\xad\xfbM\x1f\xe0\x91\xcf\xa1\xc0\x1cI\x86S8,\xb9!\x17\xb2&Q<\xd6\xe2\xbd)K\x16.\xc7\xbc*\x81\xe13\x80\xe8q\\\xfd\xfd\xfa\xc0\x9bR\xd9\xea\xab\x00\xa8\xac\x9e\xe3W[9\xcc]O\xe0j`\xda\x9c\xb1R\x9a\x98\x9efY\xce\x9a\x12\xab1\x1bm&\x98cJ}\xc6\xdb\xae\x9d\xaf6m\xb4iNE\xb5J[$P\xb7\xf6\xdb\x1f\x9f(a?\x16\xe2A\x9f\xdev\x9c\xfbG\x86\xee\x9eO\x1f\xean\xf2J\x1d\xa3u\x92"\xa3 "iL\xce\xc0\x8e\xe5\xb3\\\'\xf1`$\xcf\xde<\xe9\x96\xa4\xe8\xc3\x06\xcc\xed\x90\xf8\x89\x14\x83&\xb2\xe2\xb8\xfc.\xa6\x9a\xaf?\xdeE\xcc\xf4Td1\xd8\xdb\x88P\x04\xee\xc2xA\xc2J\x8f{\x8c\xa5!UQ\x9b\x16^\x05\xdcI\x05\x8f~]_m\xdf\x12\x10\x00\xec\x14\x8b\xed\xddo1S\x15*8\\\xe1\xb4\xa7\xaay\x12\xa9%\xac\xd9\x81s\xfd\x18\xee\xda\x0b\xf8\x03\x0bQ\x8f\x82\xda_(\x12\x03\x17\x12`\xa8\x12\x8e\x0bk\xcdo\x9c+\xf50\x19}\xcf\xc2\xf1\xc8`\xb0\xfc,\xb5\xf8\x88^J!]\xc4W\xa6z\xb1\\[\xfc[\xfc\xd5\xaf=\xcf\x0b\x85\xa7\xac\xc0?Cc\xf5\x87g[\xf5\xb3\xe0\x18p\\=X\xaa\x10\xc0\x8b\x88W\x1d\xeaZ\x92\x94mZJ\x933%\xcd\x97\xb7\x87\xfdG\x17\xfa\xb9\xbcp\x059:\'\xda\x18\x06\x94\xd9\x1c\xe8\xb8bL\x03\xben\x06\xc2w\xd3\xe3\xf9\xf2%sJ!\x12\x02.Z\x14F\n\x11\x8e\xe4\x99:\x1fN\xba-\xd3\x0c\xaaK(\xbbn\x8e^n\x1fo\xdck@\x0e\xbc{\xb4\xee\xabT\xbaCEZk\xad%e>1\x84#\xa40U:\x85\xb4\xf8v]\x00C>\xc3\xb7\x87\x05\x8c\xf8\xb9\xb0\x9f\xe5\xbas}\x1aN\x9d\xc5\xf6\xf74\x14\xb5\x84\xabK\x8ay\xe1~dg\xdc3\xd6\n:\x8fG\xd9\xd6\xa2!Eu.\x11\xd2>\x0c\xae(\xeb\xf3\xb9)\xeb[\xf8\xf8\x84\x14\x024\xf7\xb5\xc5us6\xeaKg\x01\xd9\x84\xd9\x06J\xcf\xa3N\xf1%\x87lr\xd2\xbc\xd0!\xdc\x84\taM\xe0\x1eW\x1e\tV\xc4\x8b\x93\xb7\x89\xcf\xb9\xee\x81w\xc6\xe3\x9f\x82\x88\xa4\xb8\x0e\xf1V\x1b@)\xac\x07\x814y\x92\x1e\x04WX\xfa\x19\r\xd6v?L\x93\xb6\xcf\xb2j\'AQ\xe0\xe2\xdc\x8b\x93\xe91\x9f^\xd9\x1b\xaa\x8b>\xcd0\x93\xd3\x01 \xc76MI\xbe\xafQ\xd7\xa5\xf8[\x95\x1c\x81<\x00\xd8\x87f\xa0\xf8j\xf3\xa0\x92\x807\xf0\xdf\xf5\xe5\x19\x984D?\xfb\t\x0fjW\xf34\x0f\x13\x87\xf6.\x06K\x88\xf2P_\x9f\xbc\x8cVe\x03\xae\xa9n\x16f\xc8\x97\xe0#\xf6\xcc\x93\x0e\\\xf1\xa0\xd2\x7f\x1ds\x10R \x14\x97D\x10\xd3s\x89W\xc9\xa3\x9e\xdb5*\xb9\x1d1\xab\xaa.\xe6\xe8\xf8\x0f\x82qU9\xfb!\x9d\x9et\x11X\x1dH\x9e\x1c<K_\x08\x07D `*\xc2\xeb\xfc\x0fj\xb0\xc6\xb6%\x14Im|;\x11Z\xbb\xfe=j4\x1ay\xa9In\x03\xaa=!\xbf!\r\xa5\xf8[K\xad\xd1\x8e?vg\x8b\xc0\xcb\xbe\'\xa1\xebw\xb4\\\xb9\xaf\\_k\xaa&o\x97\xf1\x03Z>|\x0cV[\xae\x05\xc2\xd2\xe5\x1c:\xb8\x15\x9b\xf74s\n)x\xa1\xf4\x859\xe27\x998\xf8\xd6\xfd\xdbOr\x12FT/\x92/n\xef\x05\xf9\x7f\n \xc0\x99\x19\xf5\x83P\xe3\x99\xd1\xa4\x1c\xfe\x13\x0f\r \x1b\xf0K\x80\xbc\xa3N\xe4\x85\xbe\xcf[\x82\x08-e\xd2\xa6u\xd4\xc9\xd22\x0el\xdd\xc8\xacf\xaa\x16\x9d\xde\x86G}\x12\xf9\x87O\xce\xe3\x13\x0f\x96\xc3}7\xc1\xe1\xdd\xf5\xb0\x07\xaf\xeb\x14}\xcdsl\xdb\xab)\xf1w\x970+8|x\xbecl\x12\x8c\xbfT\x8eo3\x8c\xd6\xef\x1c\xad"\xc3Z\x01\xe2.\xf4y\xe5\xb9\xc1(d\xed)@\xf1\xafQ\xf2\xb4t\x19\xbf\xb6\xc5\xa0|\x8eb\x85\x1b\x14\xf7\xb4\x00\x0e$\xe9\x94l\xc2\xc1\xffY\xc6\x1ak\xe0\x826\x15{\x168d\x89\x86T\xa6@v\x04j\\\xf0\xa67\xac3\xdf\xa1X\x07k9\xf7\x9ay\xf6l\x14\xb28\x10\xecL_\xf0\xbc\x9cDz\'J1\xfb\x19\x7f\xa8\xcc\xd3\xaf\xe8\xbbH\xf2\xe5\xa7z\xcd\xf4#\xb7\xbe!8\x90\xbe\x02\\.N\x90\xbfV\xff\x0f\xccu\xe5\x08\xe1\x04a\x08\x1f\x91\xd3\x8b\x9a\x9d\x01w\x80\x88kG\xe6\xb5\xf0h*\x17YJ\xf08\xba\x9a$p\xc4\xaa\x023/\xe1\xccx\x819S\xf2\xf2\xc6Mk\x18\xca+\xceO\xf9\x90\x12\x13\x11|T[\xb1\ri\x80\xea>\xc5\xfe\xb2$\x82\xb4R\t\x12\xc8\xac \xa8\xaaQ\xe4\x8e\x81s\xbb\xfd\x12Z\xae\xadH\x1d2}.\xff\x8d\xdf"_~\xae\x84\x87\xd1C\xc1\xec\xc7q\x87HB\xf7Y\xf9Be\xd4\xe5\xbe\xa8u\x8bI|v\xf0\x00\xe1\xec\x07\xd0\x14,M;z\x07^Dn\xfe\xb6u\x87_\x03\xc8+\x8f\xeb\x9b\xb3\xb6hM)*E\xf1\x19\xec\x16\xb1\x00C\xcbo\xbdXn\xfbF\xb1\xd8EI5\xfd\xa7\xa0m\x8a\xc4\xc9R\x80[\xeb\xdc,8\xc2:\x03\xb5n\x1fs@\x8a\xfaq\x15\xf9\x16\xe4\x82\xab\x85\x929\xe9v\x81\xe2\xee\x0b\xca\xa6\xc7!\x18\xf0\x8d\xaf@\\\xf2\xea\x1f\x8eP\xf6\xef\rv\x10\xd8\xe4E\x95p\xc2`\xd8.\x96lh\xb6-\x1d\xb4\xdf\xd0\xbb\xd4\x963\xe1\xc0\xf4sT\x01j\xd7\xbb\xdaWv\x96K\x11\x1c\x0cPq\xf1\xcc,\xccJ\x84\x02\xec \xdc\xf5\xb4<\xfa\xbe\xfe\x9e\x90#%\xf0\x9a\x0f\t\xb6\x0f\xbe\xf73\xe1\xe7\x8d^}4\x0c\x9ez\xe4z\x8d8\xec:\x05\xbf~\x86rl\x02\xd3OZH\x87T\xf2\xdf\x88IJ\xa5\x9eg[%\x89p\xe8\xc7\x16\xee\x05\xe6y\xfb\x15\xe15\\\x17\x8a\xce\xbbA\x96\xeb\xf2\xff\xe5\xca\xaa\x9a\xf6\xcb\xae\x8d\rd\x14\x97\n\xa1\x94\xd3\xfc\xd6\xdb\xfa\xb6)\xc2\xe4rj\xdbw@\xdeL\xa4\x00\xb6G\xf1\xdb\xd7*\x80\x925\xc1\x14\xa7\xf4\xe6<\x85+\xbd\x1f\x80\x10\xdc4\xabie\xe0\r\xca\xcaM/\xc8c\xe1\xbfq\xe9\xda\x1dQ\xeej\xf0\x95{\x88#\xcd\x03\x19\x07g\x0e?\xf6Dh\x02\xa6\xdeM)*\x0c\xca{\x99_+\xa3jo@\xdf\xedr\x04\x98\x8c#\xa1\xcd\x96%\x18\x1d\x07\\z\xfc7\xa6m\x9e\x87xm\xaa\xfdE\xa7\x18\xdc\xd2o\x8eD_t\x16\tbj\xdb\xcf\x02\xa5\x7f}g\xbe\xc6\xfa\xf0\x85\xa9\xd4\xbf\x83s\x05\xbb\x95\xd6\xb4#\x08\xe1\xd6\x02\xc8!\xc5\x869\xa2\xc8\x8f\x99\x92$\x18&\x19_\xdf\xc5D\xb6\xabq\x9e\x95:\xc8$\x9d\xa1\x9c\x19\xfbeQy\x8d\x88y\xbd\xa2W\x9c\x9e^x\xf0\xbc@\xa4\xfd\xd6\x7f>\x9d\xdf\xd4\x8e8\xc6\x98xS8\x19\xbe\x05\xa1z\xc7\x00/\x1c\xc3\x17\xdc\xe2\xe4\xbe\xbb\x80s4\xe5\x8c\t\x83*Ef&\x8a\xef\xc3\x07v\xfe\x07\xdf\xf1\xcaw\xa4\x1d\x17\xec;t\x15\xc0_B\'\x1e\xa52\xccm\x9d:\x14\xda=\r\xa3r\t\x9bM\xe5B\x89\xab\xe2\xec_U\xa3\x99\xa7\x05\x1b\x8aV\x9f\x918F|\x92\x92\xed\xc6\xda\xd6\x105H\x08H_\xa2\x82F\x1dx\x92Z`\x88\xa4\x93\x93\x92h\xd7\xee\xbb\x81q\xecv>^oV,D\xc7K\\"\x012\x13\x93f\xf2\x075"&\xd4\xdcS\xdf\x8a/\xc0\x8a\xeaW\xe2\xae=RM\xd4\xf4\xbd$\xf9\xeb\xd0`\xea\xa9()\x87z\x10\xd7\xcc\xd2\x00\xed\xa6\x1d\xf0\xf8\xef\xfe\xdf \xa4\x8c\x99\xd1\xb5\xe1\xd0r\x8a\x85U-\x03\xf1\x87Cc\xe8\xb0"}\xee\xee\x8f\xabQB~N\x07\xc4\xaai~\x87}T"\x12\x85;!`0\x0b-\x83\x14\xa1\xcb\xf9y\xcd\x19\x06\xd0\xb8\xaftY\xa4\xbc\x9cb\x95VV\xd7]-\xaa\x81\xe6\xb39\x17\x9d\x98#\x8a\xfd\x1ae2\xf9t\x0c;\xf4ml1>N\xed\x05\xfc\x85\xa9Q~\x9f\xc8\xd9u\xa8\x16&\xff\xbdR\xd1\xbb\xb3)\xe1\xef:\x9f\xab\xa6\xa1\x16\x1e\xa4\x1b\xdf3]\x0eAYR\x05\xaf\xc0\xd9\xfam\x88km\xe9\xb4\xcb\x0fTL)\x8ea c=l\xe6\x9c\\\xe8v\xb7\xcd\xd3?\xf4\x1d\xca\xdaf\x031\x05\x85\xf6\xf9\xa0\x97L\xda\x0b;\x80d\x87\x10p0\xb9\xd2-\x1c\xfc$\xdaE\xb3\xb6\x97@\xe0z\xb4\xacK#X\xadb\xea\x81Q\x18\x84\xa3\x02\xa81\xed\xe9\xba\xb4\xa2\x99\x93\xf5\x90mQ\x1b\xb7\xb7j\xc9\x0b\xa9\xb0\xa3\xc7"\x87\x97&\x8a\x0b]\xed\x9fv.\xbb\x05o0\x8d\xf0\x97\xc2\x86\x0b\x1c\x91\xe5m\xbav\x1e\x83\xaf\x83wlj59Y\xb2,8\x12qi\xb0k\xd3P\x8bT\xbetX\x1f/\xcf\x85q\xfd\x1e\xa4H\xc8\xd82#\x11lj_\x18\xcf\xc2\xf8^\x1cBO\'+\xaa\xba\xa0\xcd\x8f~\xed\x02{}\xb38\x18\xe0\x8d\xb6r|\xed\xe6GX\xc61\xd0\xd3\xb54i\x84qE)g\xb0\x9f_\x82\x1a\xc4\xa5C\xd0H\xe2^;\xa83N|\xdan\xd6\x87\xae\xb2\x84\xbe\xe7Q \xb5\xf2=\xa6\xfe2\xc6\x08"\xf9Pt\xc2\xd5\r\xd1B\xe9\x10\x90P01\xe8\xcf \x14\xcd\x18\x9c+"\xef\xa8}\x80V\xbe\xe6\xfb\xe6\xec\xa3>\x01\xe1\xacD\x1d\xed\x94\rd\xbcu\xfd\x86`\x8bB\x80\x86\x8bW\xd3{{\x8e\x1e[\x05\x87\x8a^\xc0MX.s\xa0d\xb4\xbe\x1ar\xfb\x99\xcd%?\x11EXVYO\x03e\xa2\r\xaa\x13e\xdb\x1e\xddb\x9fd\x9fp\x95T\x84hE\xc5TS\x9a\x88\x10U\xd2-3\xfeRW\x9cj^\x89k\xa5\x8cnR\xe2\\\xac\xb5~S%\x86g5A7\xc37\xf2Y\xe4\xe1?\xe0\xe5`\xf2\x01\x19C[\x81,a\x96\xfe\xc5\xa3\n_n\x10\x8f\xcf\x98\x9b\xba\xcb\x1c\x1f\x8e\xa6\x858f\xd5\xddp\xa9s\xca\x0e\x15iN\'\xedN\t&=\x8e\xfc1<-\xe5`\xa4\xd4`\xfd\xe2\x9ed,\xc2D\x81\xc6\xdd\x0b1\x84\xed\xbc\xd5\x85Av\xc2\xaa8U\x05. \xa1>\xd5\xf4v6\x17\x03\xa6^\xef\xe2\xcf\xd5\xca)D\x10DF%\x11\x14\x17\xa59\x8c\xa6<\xe84t42K\xe6#\xf8\x93\xac\x1bq\x0c\xd5mK\xd5\x90\xf3\xc4\x9c\x9a[\xd5\x82\x04`\x85\x83,\x0c\xb1\xacbw\x86C\t\xc7q2\x9b*\x80\x14\x03\x03zU\x08\xd5\xd2\x98\x0e\xa4O\xd7\x12\xaa\xa6\x19p\x16\xe7\x90\xa0-\x14\xf1\x95\xbfav\x8f\xb1\x83\x1d\xea4|\xc2\x80\x7f\xef*3#:H!\xc4\x03}y\x07c\xe7\x91\x92\x0cA\xcb,\x11;\x83X\x98\x86Usi<\xa2\x05\xbfk\xc3-;D\xaf["\xac\x14\xc3)\x82O\xed\xf2\xb6\x11"`%\x0e|C\xe5y\xa74\xa1({\x13\xc3)\x96\xdc&\x0b\xf4\xf86\xc7=\x17\xc5h\xba\xca\xe7\xb8\t4\xdf\xeffs\x96\xf6\x0e\xed1\x9a_V\xc4\x8a\xf0N*B\xa1\x8a:vQ\xf2\x7f\\\x85I\x8c\\)\x14&\xc2Y\xf4\xda\xe9O\x9f\xd0\xdc\xdf\x81\xa3\xb60\x02\xa7 \x18I\xc0C\xd1r\\\xf0\xb7W\xb6\r\xa9\xe1\x86\n\x8c\x95\x90\x904\xea\x9b\xc3\xfat\xfb6}J\xa1\x07o|1\x93\xc9\xf6\xc5\x87\xc1\x9cf\x07c\x9bK\xb2\xcc\x06=\xbe\xeb\xdd\xe7&j\xf23\xa3Y\x18~uW\xb3\xa6\x03\xcd\rn\xc9\xc2\x11\xe0"\xebE\x1b\xd6\xcf\x88\x12\xad\x1d\x93\x9c\x98\x0e?\x86\x84\x93P\xba\xc8\x0f\xfe\xc1^\xb1\tZ\x90~6\x8a/\xd0v$b@\xb4\\VW\xa2\xa1\x0f\xd5\x81\x82](u\xe8\xdez\xfak\xf1\xce\x1e&\xc4\xf7\xf7\x05\x91\t%\xa5\x06\xa1\x83\x14f\x91e0tI\xc1N}L\xa6\xc3\xd2g\x10m\xfao\xc8\xa5][\x95/\x873\xa5\xda>\xe3\x97\x08;\xd0\xe30zhB\x16\x87\xa8\xfav\x03^\x8d\xbb5\xb2\xbb\n\t\x8d\xcd\x95\xa9\x93\x81\xb7\xdf7\xbcNydb\x02;.\xba\x92\xd0\n{\xa7\x08c-\x91\x12y.\x07\xaa\xcd\xc5f\xb5\xc0\x1b\xd2\x99\x93ZC\x880?Oy\x8f \xdfO\xc8r\xbe\xd9wR\xe8\\\x9a\xe74)\x04pr\x80\r\xe5\x9c\x80\xd0d\x93\xaa*\xe9\x0e"\x06W\xf4O\xfb\x04]9\xf6\xd5C\xe7\xc2o\xc3\x16\xe2\ti]\x0c\x8dHCLz\x81\x90U=\x98n\x14w\x9cO\xc88?\xc3\xb4\x9aP\xa0\xa3\xf7!\x08\xeeE\xd5\xf2\n\x1a X+:a\xf6Dj\xc4\xcfS\xe9A\xe9\xea]U*\x96\xe1\xfd\x8dO\xd0,O\x81\x8a\xb8\xfe(\xd7W*"-\xa3\xea\x93N~"#\xcd\x03A\xd5z\xbd\x0f\rF\xea\x83\xb6\xbf\xb4\xa9\xc2a\x9e\x0e\x80aNP\x04\xbf\x9f\x9e\x94\x17g\x8f\xde5"\xf0\xfd\n\n\x00P\xa2\xee?\x84=c\x00N]\r\x7f\xd8\xfb\xa9\xbb\x8c\xe471\xdd\xf8&DH\xd1\xf9k$w\xb5\xaa\xdav1\xcc \xd9p\xad;i\xc75\x08\xf7\xf8{\x83\xacn\xdd\xbaE\x92\x18\xa5)\xa2\xa3\xc8g\xfd\xefD\xfc\xfe\xf5\'\xed\x01\xad\xfb\xdaS\xa1W\xfd\x04/i\x15v\x1e\xc4+ \xe8Hs\x87\xf8X?\x91\x89\x18\xcb]\x0b\x1f\'\xc0eb/\xc4\xba#T\x9d"\xde\xd69\x1c\x9cO\xc3\x92n\xe5\x96]\xfa\x1e\xc9W\xe4\x9d\x00XcEu\xad}\x03N\x10z\xa1\x00q\x85\xe2\x13}\x9dM\xffn\x1c\xc9\x8cD\x0b\r\x1d\xa0\x11/\x1c\xaaj\xae3\xe4\x1b\x933f8\x00\xa8\x80\xc2y\xed\x05\x1c\x14\xed\xad"N"\xa8F\x82M\xa4\xd6\x15\xda\xb2L\x9acH3\xda\xbd%)\x85p\xd2\x1f\xae\xd2#\x1bkr\xa7W\x80\xcftS\xe2\xcbF\xe7\xdfX\xe7\xe2L\'v=\xe8\x99\x989NWy\x0eR\xb8FyD\xb2\xec\t\xf2Z\xe0\xd6\tB\x14\xde\xfet\xc8\x95oQ\x19%:\xb8+\x82\xba]\x81\xa0@\x92M\x96\x84\x88\xb8\xd4\xe6\xb0\x97x\xbayu\xfaE\xf7\xc2\x03\xf6\xec\x05d\x08\x98lq!)\xad6\x00\x12\xf5\xcc\xb9P\xbcf\x16\xb3\x88Q\xea\xd7\xfb\x84&\x83<\xb1O\xe6\x0e\xb9j%M\x8c\xa4q}\xf87>\xb6\x05\xf0\xab\x84O\xdf\xdf^:\xb7\xd8!R1\x9a}0\x1e\xa4\x0e\xc0\xf6\xfe\xd4\xb3e\x9et*\x1f\xb7A\x9a05}\xbc\xd90\xe61q\xb91\xcf}m\n3\x04\xbcj\xc0\xacn\xa8\xec\xd2{\x9c\x141H\x19\xc8}\x92\xd4\xc4\x0e\x198f\x92\x91\xed\xa2\xac\xcb\xc4q_\x9e\'lS}\xf7\xbf\x19\x94\x0eH\x82\x8c\xbe\x8d\x0c\x0c\xef\x93F\xa1\xe0R\x9aP\x818\x01vw\xb4]\xdcn\xe7\xac]3\xe5\x06\x0b\x9b\xf3~\xdf\x0c/\x90\xff\xe9Z\xc7\x8a7\x17\xad\\l\x9c\xb0Dw\x0exxvRj \x8b\xc4Rx\xa0<\xc5\x15\xe0To\xf9I\x91\xfdD\xcc\n\xf4"\xe0rq\xdb\x8c>\xea\xec\xc0)\x90\xa7\x8e\xd5\xf7\xe0\xb0q\xd8N\x1d\x86\xdd/\x19\xc6\xdc\xdam\x19ul\xe2\xb97\x93b\xa5\xd7\x013\x00\xd5\x8e\xe8&\x04W\x9d\x11\x89;,\xab\xe1U\xb9\xfa\x0b\xa08 \xba\x85\xcb{%\xb45.\x81\xc8\xfa\x1f\xf6;\xd0+\xff\xad\x14\x9cl\xd0\x08\xa7\x9b/\x07L\xc7\xd2\xaeS{\xfa\xd9V\xc2\r[\x834~\x07%_\xb18\x9d\x9a\x9c\xad\xf5^\xe1\x1cp\xa4\xc2\xef\x82)\x15\x17y\xce\x95\x84"6\x9ea\xc0\xac#\xd7\xcd\xf5\x8c\xcc\x13c\x02s\xff]>\x95\xee\xf6\x10\xc5\xb5Y\xf6\x86\x05\x05\x00H\xa2\x8b\xc5UdQ\xaa\xe7\xc8\\m.Jt\xa4|\xe4RR9j\xa0\nxDh\xd5\xaffAY\x84\x87\x078,zG\n:\x0b(-\xf7\xbe\xad\xf3\xcd8\xf4N?Ba\xecE8~\\\xac\xcb[ni_\xc3^K#\x0c\xbbM\xe0{\x9cIukw\x8e\xa9\xe1PZ\x17"\xc2=2p*\x17d\xa0\xa7\x1de\xac#\x01\xd0\xd4\x0c\x86\xa8\x1a\x16\x0bG\xd8\x19\xee\xa3\x1as\x14\x81`\xa1\xae2y\xa8\x1c\xdc\x96\xba\x9f\xa2\t\xa8;)\xeeF\xde\x8cI\xd5{v\xc00\xf5\xdf\xde\xa2n\xcc|\xb2\xb7\xafDk\xac\xc2n\x04\xb8\x00\xc2F;\xfb\xf8\x9e*\xe8\x938\xbc\x9d\x14\xab\xe6\xd2}\xd9\x93\xb3\xca\xa0\x066g\xe3\xf0.\x1f\x00C\xa2\tL\x82\xdd\x84\xe7\xc5{,s1\x87<7\xbd\xce7kE\x06\xafkn6\x1b)7\xe3\xb5G\x04\xa7\xe1\x0e~\x1e\xcdm\xab\xad\xb6P\xd9\xcb5\x02\xdbI%\xeb\xd6\xc8\xe9\xfe\xb6\xba)\x8d\xa4\xa4\xa7|\x1a\xf3l-\x01\xe4\xbe\xabz{s\xf7\x01\xae\x98\x15N\xe6\xdbq\xc3\xc04#M\xb7\x8b4\xbc\xb7\xbe\x05A\x84{\x91\xe1~%!\x8dN\xc9\xe0v\xee\x12\x971\x0f\x0b\x07Z\x8a\xf3RE7\xfe\xf9j\xf5\xf8\xb2\xa2p\xd1\x84\x1e`DD(x\xcaH\xa0\xa2\xf9\x91\t]i\x9a\xfb\xd44\xe6\xf3\x00Z\x97#\xc4\x83\x9e\x9cO\xa4Z\xa0|\xcc\x1b\x99\xde\xeb\xa6\xaa\x89^\x882\x89k:a\x97\x9d\x1f\xec+\x01\xd2;r \x97\xbf+\xda\xd5\xf8\xadrg(r\x99i&\x17p\x12\xb7\xb3i\x8b\x80\xd0\xf3\x13\xee\x92\n\xb8e?\xd3e\xe5K\xec+\x98\xc1\x10\xf9\xca_\xf5[\x83-\xae\x1f\xf7\x00\x0f9\x0b\xdc\xd7\xee\xe2i\x98\x88x[\xc5\xa0\x1b\x9de\xb3"\xee1#\x8b\xaaW\xcc\xa6\xb9\x06 \xd3w\xcaP{\xb8\x94W\x84\xde4\xc6Z-\x9bD)\xd2;R<\xdc\xd70a<\xfd\xfa^]}\x1d4\x90\xfd\xf5\xdb\x93\x9c\xfc\xca\xdd\xe4\x7fa\x00\x18`\xe7#\xc5\xc8<P&\xe4^9\xe9\x98{\xc1\xbaOYF6\x14\x9b\xce\xd2\xe3\xd2\x85\x1c\xed\xb0\xbe\x9c\xf5\xb4\x95>-\xfc\xdc_.\xc9\x11dHkD\x8c\xeb\xaa\r\xac)\xea\xb7\x87g\xa7\xa4\x9f!\xf1\x05\xd5 4>\x1fL\xf9Z\x1cd\x0e\xe7Ch\x06\x02s\xe8p\xb6\xe2\xd2\xd4\xff\xa9cC\x120\x9d\xa5_\x06|=\x8f\xd6/\xe3[\xe9\xf2\xd8\x90&\xd1U\xcb\xc0\xa1\xea\x04S\xa1Cp\x14uZs\xdas\xb3\t\xf9*I\xbe\xf3\r\x8a\xb0\x10\n\xdf\xfa(\x88\x1e\x0b5\xcdhRE\x9bg\xd5\x0ca\xaf\x8f\xb0b\xdau\x9c/\xab\xaa\xe8\xe7\xd1\xc0j\x89q\xfe@\xa4+\xd1\xda=\xa3\x9e\xd5p\x9e\x84\x9fU\'\xa7nz,\x80}\xd0\xe8<\xc1\x85\x8f\xf1\x8f\xb4[HM\xbf\xcb!\x99_\xd9\xb0\x1b\x1dy\x8eb\x10\x1d\xd6\xa2\x1c\x7f_\xd9/\xe8\x1d\xacl, ]pI+\x8d\xc04\xc7\x17_i6%\x90\xe96\xb6\xe6\xd4\xdf@\xcd\xc0\xe8\xe9\x84\x92{\xc9)\xd0}\x98!\xd2\x89\xc1\xef\xe4\xadJ\xf1\x03\t\x85\x9c\xafwd1\xb0\xe1g\xf9\r\x98\xe3\xb7\xad\xa2\x11fD\xb7\r%(@{S}\xb7\xf8*\xd9_\xae \xe2t\xc8g5^ti>\xe6X\x17\x1e`S\xad\n\xddf";>\xf3\xfco\x97\xbd]\x8ej\xf4-k\xcf\xc6\xe2%\xdcM\xe2\x9bVb\xa7\x1f\x07Zw\xfej$\xaf\xd7\x801\xca\x18\xc1b\x16\xd0\xd6(|\xcc~WC\x825i\xcf6j\x13\xa3\xd3\xc3"\xeaL\x07x\x9f\xd0\x17(1?\x15\nf\xc0m\xb2Z\xdc\x17\x06}\rj\xf9\xaa\\s+\xc5*\xd6h\xf1\xcc\x17\xd9\xec\xb0 \x9a\x97\xd2nKsJ+~PS\x06\xf2\xdd\x1f\x1f9\x01\x94\x03-\x8dI\x1awD\xa2\xc3\xed9\xa3?\x80\xb5\xf1A\xf9v\x96t\'\x11\x8f\x84\x06\x91\x91\x8b\x8e^\x10\xc1@g\xce`\x04\x0c\x7f\xab\\H\xeaY\xec\x97\xb0\x19\xcc\xf9N\xc81\x9ea\xf1\xbf\x84b\xd8Q\xea\xfb\xc5\xfd\x87{\xbf{\xd1\xe1\x9c\x01"\xb08\xe1\xab\xc2\x91\xe43j<\xdd\xe9(\xaaN\x98\x9a\xf3Bp\x16m$N\xcf\xbe\r\x08x\x03\xda\xaeu14b\xc8\x81\x06\xd1\xb9\x1bx\xdd\xef\xf89\xb1\xad\x1c\xae\x80\x8e\xe8\x05\x18\x85Q\x14\xb2~\x05\xab\x04X_\xca\xeewQ\xc6\xa7\xceM\xa7D\x90\x96\x9a\x0b\xfa\xf9\xca(\xb8j\td\x9b\xedVoJ\xc4-2~\xf7\xf4\x12\xa4\xdey\x9abr"\xfb|\x8c?\x98\t\xa9\xfc\x85\xcc\xe3\xe9\xffJ\xc7\xe3\xc53\x1fp\xc3\x19\xafj\xeb\xe5\x14\x0c\xccl}t\xe1\x90\xcf\xb9\xefL|\xeaU\x81\xc4\x87\t\x98o(\x08\xfe\x10\xb0\x02\x82\xbf\x0cA\x85\xa0r\xd2\xa9Y\xbb\xbd\xc5E\xf1\x16\xab\x17\x82?2\xa1\x01,\xba\xa3S"\xaap\xf1\xdb&z\x19!\xacI\x91\xf1\xe2\x11\xc9\xda=\xa4\r~\xe5\x1d\xe9b\xdf\x866;\xc6SR\x97\xf8\xf7\xe6\xc7,\x06\x0eQ\xf1Tx\x98\xac@V=t\xca>\x98ppM\t~P\xb3X\xf9Pv\\\xa03\xf3b"0@I\x10\xcc\xb2\x9bq\x83\xd7\xef\xd5\xdb\x7f\xb3\x9e\xad\x04!`\x1a\xe6\xa6\xf6\t\xcf\x10\xf0\x14Jm\x9a\xb8\xe6|\xac\x9e\xa1k@\x12\xffE\x8c\xb6\xe5\x00\xd2|\xe5\x13@\xab\xf9\xc7X\xafkd\x86C$qZ\x1e\x83\x1c\x1d$\x9f\x0f\xd4\x02\x04\x84\xf98\xb5\xd8\x19I\xea\xffY}\x1a4\xce\x80\xcb\xa2\x06\x9fqjt#\x16\xbd\x8f\x19\xe96\xb1L\xc5\xf51j\x9d\x0f\xbb\xff\x98&\xc6T\x03=\x85\x81\x90\xe19\x1b\xb3\xc6@\xf2\xe4\xfc\x04\xc8*\xb1Ue\xf8\xda\xc0\x94\xc4\x8b$\x04\x8a\xe5n\xb6\xe8\\%\xc2\x1bT/\xe69bZ\x02\xe2N\xc8\xc7\xf4\xbdK\x1f\xeb\x90\xc25\xb8f\x8f\x0b\xafZ\x98\xdd\x8e[\x9f%\xfa\xa8\x90K\x89t\x15\x1c\xd15\xdf+\xb3Vr\xd4\xdeBt\x94s\x8d\xf1\xff\x015\tp\x85\x1a\x91\x8aqy4R\x01\xb3\xd8\x0b\x9e\xc3J2C\xa7C\xe3\xbe9Jg]V\x82p\xd7R\x84\x07\xafE\xdc&\x1e\xa3\xdf\xe4\xc8u"\x07\xcfx\x84;\xe6>\x8bu\xa5y\xfa\xb7\xff\x9c\x9f\x8a\x0c\xc1\xbbp\x02\xe98\xbe\xf7\x9c\xd1\xd9\xe2\xaf~\x8b\xb2\xfc\x1fc\xcfH\x8b\x82B5*\xe8\x92\xf2\xccq"\xd8$$@\x0cE\xa9\xab(\x16\xef\x85$\xbb\x15\xe1b\'\x04\xdc"\xa6\x10!\\\xbe\xde\x84\x03\xeb\xc9^8\xdb\x9e\xa5\xdbI/\x8c\xf7\xd4\xd8\xa4En\x15\xa9G?a\x7f\xa4\x9c\xadXN\'\xa8\x18\xc0y\xc1\xbf\x9b\x861\x80\x9e\xe7\xdd\xd1~\xe2c#\x8e\'\xe8\x9a\xa6qKRb\xbf\\]\x98\x1bi,\xa82\x9f>bMb\xf8\x813!\x9c\xe2Y\x9dg\x89E\xf5\xfe\x00\xe6r\xdci\xd7\xce\xf6\xbbwa\x0f\xe1\xe8{&h\xa1\xdf\xf6\xa4\xd4\x83\x1eS\x13\xeb^l\xa6A\xe6g\xdb\xfe,\x8ekS/\xef\xf7cl\xa1\xea\xe8\x1b\xfc\xb6\x80\x84\x87(\xd7_\t\xb6\xefp7\x99\xd0|\xb5\xe4\x13\xb5\xe0h\xe0\xb3\x17\x88db\xc6\x9b9\xd1\x81n\xfc\xd2\xdb\x98\xe5\x8a\xcf\xc6tq\x80\x8a" 3\xb1\x9c\xe1\xef\xe4\xa4\x8by\xd5d8U\xa66"\xa8\xab\xf9i\xc1\xb1\xf8\xfa\x05\xd2\x80\xcf\x8e% \x8e^\xcd02\x95&\x07\xc1\xb0\xa2\xc8\xbd{\x15)#\xe4\xb99|\x0f \x91\x9ayC\xe3\x0e\xdfj\xbb\x97cV\xd5*>\xc8\xf1y\xc36f&u\xcb\xaf4$\\\xdc!;\x8e\x05sc\xb8\x98\n7\xfc3+\xcfe\\R\x18G\xec\xe4iuy\x80\x8a\xf1\x17\xce\xb9\xe0\xedr\x15,\xa0"\x0567\xe2zn@\xd0\xab\x95\xef\x8fk\x85(\xf8\x0c\x12\xe9\x94\x89\xe6\xc2\'\xf3\x99\xfc\xbf\xfc\xedR:\xe1\x98\x08U\xc6\x99\xa5 |\xb7f\xf8\xa4\xb8\x1b\xebm\xe2\xac\x82\x1b\x00GY\xc4\x0c\xdcp\x13\xcc\xc0E8N\x93\xc6\xfd\x01\xdf\x90D8~\x85\xf1\xc9z\xc2Y:<\x08\xbdDhD\xa9G\xf2Fx@\xe4\xfdi\xc6\xba\xf9\xd7,\x98\x1a\xac\xb7\xfcF\xc1\xfc%\\\xe0?\xc04a\xb6=D\x99[\x87\xc4s\x9c\xc4a\xbc\x9f\xec\xe1L\x1a\x89\x1d\xd1\x15\xcdF\'+\x86\x82\xa0\x9b\x84\x08MM\xa1u\xa8\xd5\x1d\x82J\xb2\x01!\xd2\xff6\xa3\xfcpC\x07\x8b$\xef\xee\'K\x87\xf1\xb9P\xd1\x93c\xa4\x8dy\xa5Z\xb4\x1fA\xb1\xe5\xd0\xa9\x17H\x18\xf1\'a=\x07\x16m=\x01\xe3l\xbe&\x86\xb5j{$\x14\xea@\xfc\x1f_v\xe8\xb9\x17Q\x93\x06J\x90U\xa3\xe9Ib\x9cKTc=\x18"\xa0\xc1[P\xbd\xf3\xf2;8\'\xa2\xf479\x02\xc2a\\>n\xeeFSS\xefa\xb9\x19\xed\'m\x1c\xe4\xe4\xfb\xe53\x86\xdf\xa4\x12\x1cx\xca\x93\xa0\x1aci\xa4\x16\xd2\\\xabtO\x14\x8d\x16\x11T\xf0\x8d\xf7\xa3f]\xf7\x89~\xfaHSd:\xde\xc8\x9d\x13=\x81v\x89U\xb752I\xe0\xe2\xe6U\xed\xbc/\x0eg\xa0\xf4\xe6\x8f`\xf5\xe8m+\xbb\xfd\'4\xadX\xa7\xed\xa2n\x94r\xeb\x83\xeb\x95\xdaW"i\xc1G/\x84yF"\xb4\x8b\x18\xaa\xdfj\x0b\xe2\x00\x03$Dv\x0f46A\xe9\xf1\xadu\xf9\xb7Z\x8b^Y\xf6\xba>G\x10k\xda\xde\xa6\x9e\xd5I\xcb\xa0\xc4\xd9\x1e\x0b3\xadr\x83\xa9\xd8\xc4>{\xe5]\xfe1%\xdeJrS\xd2\xb1v\x14\xc3_\xe8\x18\x18\xe4\x8dd\xd3\x8c\xc0\x96\x1b\x9c\x97]\xc8\x11\'\xd6\xae!\x8b\x82\xa4p\xc6\x17)\xa2\x87\x97\xb3\xee\xfa\xcf$\xfaP\x8a\x01\xc0[\x1c^R%\xf5*\\\x03l\x10\xe0\\\x85\xf9\x98\xa0*\x1c\xe3\x92\xf5^\xf2\\fGp6\x06\xd3\xc8\xd9MMt\x85\x1er\xc8\xd0\xd7\x00\xfc\xad\xec\xb4A\x11\xb3`)\x05\xef[i\x92^,\xa7\x96\x1b\x93\xfb\xd2n\xecs\x12\xde\xd2\xd6\x12\xa2\x19s\xf4Cc\x85;\xbf\x88O\xa3BN\xad\x90\x84\xb8\x96\xf8&\xfe\xec\xc8\xdcA\xe8\xe4\xaa\x81D\xbe\x05\x7f\xdd\x05,\xba\x85\xa1\xa4\xdd\xd9I\x9a\x0c\xf9g\x9c\xd8v4W\x94\xae\xc5\x03 =\xac{\x0f\xa2\x03\x04\xdb@\xc9\xbaUz\xae\xc6\x82\x9fW\xf8\xb1MO\xbbv?-\x83\xec\xa0%rmt\xb7r\x15\x89t\r\x8cNe\xe9\xe0WkA\x10\xc0<\xa5\xee\xb8x\xff\xfc\x87\x824\x93\xfc\xd3\x9d@\xd2\x96&\xec\x7f]l\xb5Q\x05\xe3\xfaQd\x9d\xa3Fs\xd2\xe0 \xcd|\xab\xab\xa59\xb1\xaf\xde\x90\xf8\xa9_\x88\xe5\x00\xdf\x01\x03:\x9b\x07z\xa3\x8b\xc1\xeaM\xd2%f\x8dZ\xb8]\xff\x89\x97ez\xb5\xd9P5H\x92\x0f\xd58\xf8i\xa1\xb1\xa4N\x9dz\x83\xa6L\xe34\xe3h\x96\x14\x19\x00\xa5\xff)\x14<0\xa7Y\x06\xef\xed\xac\xcb\xa7\xe1\tHO\\uG|\x19\xe9s\xa3K\x18]\xaa\xc05\x9d\x81\x08\xe4&8U\x0e-\x15\xfd\xe2\x13\x1f\xba\x99\t\xea\x0c!f2\xba\x91\xd6\xdbY\x8f\\\xd0V\x9d\xa1\xcb3\xe4\xd3\xab\xa0\x8a\xe51g\xf4\x0f\x0f\xa1@<d0\xc9\xe1{\x8cn\xe1\x1c\xc7(wy\x9f\xc7\xf7\x8c\xf5\x82r\xed1e\xef>s\xbbY(w\xc5\x19;\x80\xaf\xd5\xdd\xce\x9d\x0cuV\x87\xbd\xaar\xd8\x9ah\xb5\x90\x8f\xf8Ac\xd2v`\xe8\xed\x96\xe9\xa3\xa1,\x91\xb0\x84\xa5\x88\xb0\xf2\xbd\xb7\x9e\x83\xaeS\xd4\x1d\x9c\xed\x137D\t\x1a\xda\x03W\xdc\x02\xe1\x97\xd4\xb2\xe3u}\xd8\x0bx\xb3L\xd9\xe6\xc61X\x99\xb3\xe0\xf8\xa1\x06\xe0\x1b\xbd\xc3\xc8\r\xa7\xd2b\xe9B\x08,3Q\x90\x9f\xb9\xbe\'\xeb\xb0\xef\xf3\xd7\x1e\xc3\xe1\xb9\xd30\x10\xc6\xa7u\xf4~\xc2Af\xdc\x97\xd2\xc1\xfa\x03\xbfU,\xba\t\xb4\x1c\xb5W;\xb3\xee`\xe0\xf8\xdd~\x11\x88\xdb\x04\xe7\xa9\xc8\x18\xabv\x8bn\xa1\n;\xc5\xa9\x011\xb5"\xe8\xa0c\xabC\xdf\xcb\xf8\xfc@\t\xa2\x9b\xd3\x1a\x1e\xf2T\xdc\x8b\xf9\x9e\xfd\x178|\xa6\xce\x82p\xba\xfa7>v!v\xe0\x91\xb4\xb9\xb2\xdb\xa2\x08#a\xd6q\x7f\xe8\xdb\x07\xe8p\x01\x9d28\x16\xb3\x03J\x13\xbb\xa1E\x94TKR-\xce\xd8b\'\x92\xa3]C\xac\x92\x98\xf2\xf1r\x12[\x99L\xc9\x16\xad\x9c\xa2\xc4\xa8~\x88\xa8\x05qg\xbc\xc4R\xc7g\x0f^\x9b^\x81\xd8\xa1fp\xe0\x01+\xe4!\xef\x8a\xba\xba=\x8c4\x88oW\xd2\xd7\xd4\xa3d\xcaE\xb4\x16\x18\xce}D.\x11w\x03\xd3\xe4\x95 1\xf0r9\x9c\x95l\x05\xaeb\xdf\x94\xf7\x85\x0f\xc8\xd3\xf1\xb7 \x0e\xcc\x19\x9cm\xa1\xb34f\xb2\xbd\xb0sng\x89\x03\xa8S\x15yN\x0cz\x89\x1ev%\x1b%x\xf0ft\xcd\x15\xa0\xad\xf4\x0f\x87\xaap\x1e\x0e5\x08\x0e=)\x10\x92&\x84\xb9p^\xe1\xd1-\xae\x17B\xcb\xf7\x16\xe7H{R\xbe\xde\xc8\xd5\x08\x17\xbf>\xc6r\xf2\xac\xaa\xb0\xcb\xeb\xe3 \x91\xd0O\xa1\xbf\xe3\xc8\xcc\x80\x82x\xc6\xbe\x8c\x05i\x17\xa4\xffRW\x9c\x1dm\xc0\xf7\x96p\x14"K8\x8d\xf3\xd5\xeeE\xf3\x83\x90\x93\xaf\xaf\xbb\xd6.{\xa9v\x83\xc3];\xf8Uw\x9c\x9c\x96ruZ\xe5d\xcbi\x01\x82\xb2\r[\x88[T\x0c\x14\\\xf85#t\xd2\xf0x7\xc2\xbd\x99v\x10\xaad\xa93f\x9ez\x8e)\xda\x8d2\xf4\x05\x87F!j\xdc\x8es\xea^\xea\xe6_\t\x96\x0eM55\x85\x11[TX\xbc&\x96\xe3\xb0_\xa3w\xb7\x8c\xd5\xa8E,p/h[\x08\xecm\xba\xc4PW*\xf5u\x7f|\x00f\x84I\x9c\x06\xa4\x04P\xe3\xcf\xb4\xc2\xf7\xe3?\xc5\x94\xd25\xc8Of\xb9\xf3\xc3\xc4\t\xc5A\nhw\xaa\xc0\x92\xcd\xeaW\x0f#\xe2\x8fl\xc1JlBr]7\x0ca\xd8\x9f~\x1f\x19\x1d\xe5,;\xdd\xec\x03Q\'\x02\xce\xd4\x1e|\xb4\xe8\xe5\xba\x9cx\xea)6k\x9a\xa6fz\x02\x12\xdb\xfa#\xad\x1c\xf1Er\x07\xf5\xa6t\xd2I\xb7\x05\x0f\xda\xa4!|&)\x06\x8cl\x9e>\xe4\x91o\xe6\x08\xaa|,\xec=\xc0-R/>\x80/`_\xe5\x831vS\x0e\xf3+\xa5?\x02ci~\x01\x11\xe0L\xf6\x8e\xb1\xc3\x8dj\xcaI\xe0\x93\x12L!\xf0\x89A\xc8\xa47n\xb3\x91\xe5\xa3\xaa\x1c\xd4\x8f\x8eq\x08\x88U\t\xa2\xdd\x84#\xbc<U8t\xc3wF\xf3ZKDqRs7m\xd2\xe1d\x18u\xcb\xee_jg\xad\x17\xfa\xc8\x84\x16\xb8RjoK\xd5w\x8c*\xb3\xbcb\xde\xfd\xb8\xa2\xd2\x7fY\x03\xd4\xd3\xd3MI\xf1\x1eD\x18~\xbe\x02\xd7\xec#0c\xa2!\xaf\x1e\x84vMv\xe3f%\xb4\x12\xa6\xaf\x1e\x1f\\\x10\x87:}\x98\xa6\xe8X\xf9N\xdc\x85\xf4\x7f\'\x07J\xa9?l\x87\x8b\x05\x1b\xda\xeb\t%\xad\x94#%\xb2\x1e\xfe\x15\x8b\x0bX@-\x89\xf7~YdZ1\x9c]\x94\x1c\xc2\xd0TTB/\t}O\x8c\x0cg\x99V\xba\xafv\xafG\xee\xbbYS\xdc\nV01\xc7B\xe7&\'-\xa4\x9c^3\x90\xe1\x0bY\x91\x1cM\xd0\xef\xfco\xa5\xbf\xe5d\x07\xad\xff\xe8O\xa6\x93\xc1\x8bhTL9\xe6\xfd\x9c7\x14\xaa\x05\xcb3\xdb\x18\xc6n\x1ep\x93ruF\xbe\xe5\x9d\xad\x7fq\x86\xf0\x80E\'\xbe\xce>k&\xe7M\xde=\x8d\xb2f\xf34Et:\r\xed\xfd\xbaGt\xc8\xda\x10\x07\xc2\xa7S\xf3Z\xf0\xa2\xa3\xd7zRa\x8f\xe1l\xd4\xfd\xc0?$e\x9bG<\xe1:#\xffDN\xfe\xd9\x80\xe3HY\xc0\x8b\x16\x05\x92\x8a\xd3\xe2[\xc2\xd9/\x80\xcb\xa0\x02\xfbE\xe1\xe0\xfa]\xca\x0f\x98\x11\x1c\xa1\xa4[\xcb4X2\x92\xd0\xed\x88z\xff\xa2 \x1e\xcab\x84Kc`\x10\xe8\xbcY@\x13\xf1\x9b\xdb{\x89\xa4\xde+\xd5\xb0\x1f\x92S;\x92\x17>\n\x88W{\xf4\x03\x0cF\x89mM\x12LS\xe2$\xce~\xb3e\x926\xda\xba\xf5\xcag`\xf2\xe83$\xc8<\xc8\xb4\xc1\x12\xd3\'\xb3eLKjL\x9f\x13M\xaet\xe0Y@;=\xbf\x06g\xea\x9e\xbf\xf7\xaew\x94\xa4\xa9=\x16\xce%\x8e\xbbl\'Z\r\xd8\x86\xa6\xc7\xc81\xee\xd0\xf7\xe4\x19\x08\xcb\x0c\xa3o\xab\xed\xc5!\x86gY\x90k\\P-\xafTn\xd6\xa2\xa2\x96\xe7Y\x12\x07\x0f\xfe\xe3\x92\xb0;\xc1\x11Vp\xa5\xd2J\xa7\xc7\x14\xcc\xc1\x0c\x8c\x86\x8e\xe4 \xb2qT9<\x14w\xb4uT\x97\xd4\x8d\xf1x\xce\x97\xde\x93\xbcf"\x96\x9d\xfe\xea\xf5kMy\xe8\xfc\xe3\xccY\x19\x9d\x8d\x05\xac;\x9cA\xe7w}\x9eX\x9b\x9c\x8a\xd0\x90v\xe9~\x84\xc8\xfa*C\xbb\x8b\x93\xb5\xea\x13\xbcYu\xe8\x8d>\n\xae\x8e\xed\xd0\xcc\x13v\xbe\xd2\xc9Qh\x81\xda\xea\xa6\x93c\xe4O\x82\xf4\xbc-\xff\xa6\xde\xcc\xec0J@\xfe\x1d\x8b9\xac\x15g`\xefm}\xc2\xbe\xd3\x12~\xcdB\x9c\xdf\xc3\x9d\x9b\xafz\x89@\xf9\x8f\x02\xacg"\xc5\x96\xf4|\x93\xcf\xa5\xa2( $f\xf6H\xd5N\x14:\xcc\xa6\xc7Y\xeeE-\xfbS\xf4\xba\x8d|\xdf\xc9\xc32\x05\x1c\xffh\xdb\xdf\xe0\x9b\x99\x01?\xceLWPXA>\xff\xcd|J\x1f\x83C\xba\xe3yX\x1b\xe5\xe4I0*qTj\x99\xc4\x01\r\xdd\xa4\xa6\xf2\x07\x04\xf2<\n\xb3\xe9@BY\x05\x1b\xecl\x0c\xb7m5\xac\x04,:\xfcx\xa1\xb8M\xdab\xfd`\x1ax\x14(\x02\xd8\x13\x96\x1elyA\x94\xd3\xc6\x8c\xeeK\x1a\x19\x18~gC(\x99\x93N`a\x91\xda\x1a\x91\x1cV\x17\x90\x7f\x88?\x8a\x04\x83\xf6\x8c\xf3\x94\xdf \x03\xf0c\x8b^\x823\xc8\x95\xee\xb2\x16R\x90W\xb3}r\xc7\xb6\xc5W\x1f?Y\x9b\x87~\xb1\xa6\x92\xf2<\x13g\x0cLd8\xa7\xbbz\xe1\xeb9\xbe\x11\xe2\x1f\x9cw\xecx\x98p\x9d\xcf\x81*\xeb\xe1\xfa\xaf<\xf8\x7f\xa4T\xf8\xfe\xcd\'\x1e\x0f\xcf\x9e\\\xef/,\x18A\xe3\xa2s\xdd6\x94\xe6\x87\xcdf2\xf7\x13\x8e\x1c\x05?B^4\xad,\xd6!\x1a\x03\xd1U\xf2\x1d\x94U\n\xb2\xfa\xf50Vj\xb2\xc2\xd9\xb8\x9f\xf9J\xd1u]\x00\xa0J5\x07\xdf\xa9\xb5\'\x9d\xa1\xea\xc7p\xbe\x95\xaa\xf3\x14b\xa80\xab\xc55\x15\xb4\x87\xeb7\xa2\x93\x0c\xea\xdf\\\xc0\xb5\x98\xbd\xe8\x92\xe5\xc1*\'\xd9\x93R\xe3\xcd\xff\xe9\x9d\x80\x80\xfaY\x8b\x9dP\x87Im\xae\xb8\x05z\xd2\xc7\xfcA\xdfS1Tt\xea\r\x13\x1e\x87\xa4\x9e\xd9\xff\x85\xf6\xff\x9d\xef\xbbl|n\xa2_\xe72\x07S\x7f{$"(\xfd\x9d1\x9f\xf8\xc44\xfa/\xaf\xa7SN\xb4\xcad\xb9\x01\xfe\xbbf\xe6\xb4W9\x9a\x19\x88\xdb\x0e\x13X\x87\x00\xecr\x9cu\x02\xc3z\x12\xf9"\xe9\xa7\x81\x87\n\x11*\xa8\xd9K\x99\xeb\x99\xd8%\xab\x7fK\xba\xe4F]#\xbf\x12P\xfe\x9a\x9aK\x8f\x08\xb9r\x12+\x17\'%\x96\xe4\x12\x9f\xa1\x9e[\xac4@\\\xe7\xa1\xc2\x0c}\xa5\xa1T\x89$\xe5\xe3/A\xe18\x9f\xe2\xa3\xb3!\xf6G\x04\x94\xa5-\x9d\x8d=\xeb\xce\xe7\xd8)(\x89\xaf\xe5\xf1kb\xdc\xc6\xca\xff\xd2"\x8cSFhSD-\x15%i\xd1[D8P;0\x17\xe1\x9arT\xbc1\x1a\x8a-".V\xed\x9c\xe2:\xecF0\xa1 \x12\'\x84\x08P\xe2\x93\x8d\x80\xd0\xf3c\nD\xa3\xe2\xf1?aA+*f\x13n\x1e\\\xcb\xf0\n\xa70J;\xb3\xc9\x8daK\xb9\x1a\n\xa2\xd7\xf6\xfdI{\xab\x8a\xa1\x03\xb3\x99\x92\x86\x83\xf6\x94x\xd7\xadUW e\xe2\x92\xc9\x84"u\xe3\x11\xc6!\xd3\xeb\x00\xc7 \xb0\x9b\xb2`\xc5\xc7\xe8u\xe7\x98\xd1\xaa\xe0\xe0\x82\x87\x10W\x19M\xa6\x87Z\xfa\x87z=n\xdf1\x06\x07\x99b\xdc\xe5*\x187\xe8\xdfw\xe2C\x000wC\xd1\x08\xb5\x8c\x98\x82\t\xc9\x07\xd2`\x8f^\xabO\xbd\xf9\xe7R\xc8o\x83R\x98\x93\xea\xfdc\x14\x82"\xf9K\xd8\xcd<\xaa\x07\x08bO\xc3\x97\xa18N\xc0\xabH<\x80\xb4]\x88\xb7I\xfe\x08\xbb\xbf\x978wE\xa5\xd1\xb8mX\xef\x8b$\xf3\x91\xb6\x14^\x00\xc6\xde\xfe\xb0\x0cB\x00\xb1\xe2\xf4\xc2\x1c\x17\xfc!r\xf2N\xa1j\xda$\nV\xf6\x8d\x02\x15\xd1%\xeb\r\x0e=L.\x8b\x14\x05\xa5\xf6B\xad\xbe\xf9\xee\xf9;p\xb6\xb7\x83n\x8a\xaf\xc4\x1c\x96\x85^\x87E+g\x02\x02Yj\xf9\x02Y\x8dL\xe3\xfa\xe2\x1f\x11{\x9f\xf7\xe9\xcf\xa8f0v(\x9f\x99\x9c3\xb5\x9a\xb4\xea\x10\x82\x1f\xc0o4j\x11G\xdbR\xaf:~n\xcacg`\'.\xd0TA\xeb)k\xe0H\xed=\x9d\x90a\x9di\x9a-c\xb0\x99\x8a\xc3(\x83\xa3\x86;\xbd\xe3\x8bNZM\xfb\x9aU\x7fA\x01FfK\xe0=\x9b2\x1e\xba\xaa\xd9\xa2E>w]\xa0\x96\x15s\x80\x97\x98\x9e\xab\xeb\x93cO\xe1{\x9a}\x11ONeM\xd0`\x7f\xec-2\xe0\xb6\x8c9\xafD\xb8\xefH\xb5\xa8\xb3+5\xb7\xfb+\x04z\xea\xa41\xbdt\x08S(\x1e\xdadm[\xb1] \x0f\x91\xe0?o8\xa3R\x80\x9c\xb2~\xf0)P\xbf8\xf1"\xeeUI\x17\x92\x98\xd2cL\xb0p\xe0HY\x02L=\x92\x9f \xfd~\xc5z\xd7\'\x8e+\'1\x18Fa\xc2\xe9\x0f_+\xfdy\xdf\x19V\'\xbf\x08\x1b\x13\xecBE\x8a\xf0\x0co\x01\xfe\xfc=\xe0\x8e\xc4\x85\xb1Ro\xaa\x1f\xbf\x9e{\xd0=\xad\x01\xe0\x0fR\xa5\x18\x7f\xda\x16l\xd7\x13\x88M"\x01\xa1\xbeJ\xc4\xd1R!\xfd\xfe\x13%hrm\xd9\x0f\x9d\xbf\x02\xaf\x83\xc7=w>s%D\xf8\x01\xf3Q\xb0\xe5\xb6r\x02\x94p\xc0\xce\x1egk\xd6\xa6n\x8a\x8aciAK\x12\xad\xd0\\\xbf\xc7h\x95\xe6\x10\x0f7\x93\x18\x04\xfb~N\x15\xc3\x03\xe2\x8c\xe4e\x9f\xcc\xc6\x81\x1b{}\xc8\xe1\xce;\xfc\x11+\xcf\xdah\xcd\x95\x90\x02X\xb9VW\xf8\xcb\xc0\xda\x95\x14pj\x02vd\xcb\xf0\xcf\xbcLk\xd4`p\xfex\xfb\x9e\x8e_m\xdb\xfbXFI\x1fJ\xe8A/f\x81\xde\xcf\x13\xaf]Fm\x0bJ\xfa\xe5\x87(.\xc7n\x17\xc3\xc3\xaaN\x9a\xb2,\xf4\x1do\xd5\x1dA\xf2@\xcc-^\x86N]\x96\xe3\t\xa4\xf2\x10\x92\xef\xcb\x82\xeek\xfdq\x9cc@\xaa\xd7\x1b\x17@p\x93\xa1\xba\xcf\xffC\xd1\xbd4\xac\x8b\x91W\xc6Ze\xaa-\xe4\xf0ZSw\xf5\x0bi\xc2\x87\xf8\xdb5\x93\xc5\xc3\x85\xe65\xd5*+D\xcfZu\x1fU\xfeQ\xef4\x8b9*CP\x9a\x8cQ\xd6<D\xa8a\x8b~%\xa3\x01\x87\x87\x02\xbac\xf6]\xec\xe2\x9bCy\xd69\x8cQ\xe6_c"\x8d\xdf\x91\xec\xc7b\xc0\xa83\xa1\xab\xc4y\xd9\xfeQ\xff0m\xb3\x964p\xb6n\xabM\xc2\xda2,\xfd\xd6\xa7\x01}\xa0\x99\xdax\x1f\xa5E@\xb7U[\xe0\xcdL\xf8\xd6^\xf6(\xd7)\x9c\x94\x9f\xac9\xedr\xfa\x0f^\xe6\x13\xa4~-\x8c[cy\x08\x1bJ\xda\xc8\x90Z\xa6\xb9\xac\x16\xae\xa3\x1a\xac\xee\xef\x8d\xff<\x9b\x98\xf8?\xbe\xf0 m#\x97L\xabx/\x93\x17U\xd2O\xfd\xa7\xbb\x0f\xd0)\xafJ\x1a\xdc\x7f\xac\x11\x9c\xec\x0c\xbc\xc2)\xc2v\xae\x96\x07f1\x0ees\xccF\x8f\xa6\xbc\xd5n\xef\x8b\x14\xd6*\xf6 \xf3\x0fm\xe0\x1c\xcc\x99\x8bhR\rU\xa8\xb7\xb0>\xce&\xady\xf1\x9b\xca\x9f\xbd^\xedTw\xe9\x91\xec\x9b\xd1vI\xe8\xc1\xbe \xe7\xba\xff"@\xce\x1c\xf5\x9d\x95\x14]\x0eV\xf6w./@\xaaT$+\xb8\x93d\xda`\x92WTqav\xeb\x81\x969o\x89\xcc\xb7\x1bC\x94\xa8\xe2\\\x94\xd1\x1a>\xa4\xdc5\xf1\x02\xd5\xec{U\x87[\xe7B\xa3\xc48J\xa3B\r\x89V\x86M\xacv\xb7m\xfc\xf3\x12\x80F\xb2:\xa9x\xdbN\xc2$\xaa\xc8%\x93\x9f\x91\x0ex\x90\r\xea\xa3\xa8\xe7\xfe1\xfb\xd4*\xf6\x80\x07\xce@fJNG\xba\x0b\x88=&\x98\x85\xab\x90>2j!\xf7\xce\t\xa0\xfe\x88(\xc2\xca\x89\xae~\xdf\xfd\xeb:\xe1I\'{\x00F\xect^\n9B5\xbe\xf1\xb5\xeeu\x0b$\x96\x14^\xe3\x03\tm\xa4\x9e\xfeD\xbd\xb5\xfc\xe7\xfb\x06\xa9|\xf22\xaaZ\xe9O\x05\x95\x8a\xa7\x0c?\x85e\x02\xfee\xe5\xa3\xe0A\x9c\x1b\xcc\x1e\xd7:\xff\xb4\xf69n]\x0b\xda\xe2 \xb5[\x11G\x1d\xb5>\xcb\xc7\xfd\xb7\xad\xb6\xb2W\xb7\x11\x82G\x02T)O\xae\x9aw\xff\xa6\x06\xab\xbf=\xb8]N\xc1\nQ\xfb\x1d\\+\xd9\xfa\xce\xcc\xcbY\xb1\x9c)\xd8\xecb{D\x152?\xeaV\xdc\x0fS\x8fA\x05e\x1b\xff\x8a\xfd\x8d \x7f\xba\xe7y\xd2^\x1cXk\xdc`\x85\x9b\x13\x87\xbd\x80 \xb9\xe1r\x0e\xad?S\xeaY\xf7\x8f\xdd\x9a\xd5\x8a\xb3\xe1X\xed\xb9\x06\xbfw\xa9\xd4U\t\xf79\xc3X\x03\xfd\xe27m*\xea\x0e\xd1\xfe\x01\x14\xac\xf0\xae\xc6\xa0\xb3[)I\x83\xbc\xe4h\x03\xa9\xae0\xda\x91\xdbt|Gwa\x90\xd8\xbe!\x15\xdei\xbe^q\xf8\x01\xf3\x8f\x19S\xb4\x8e\x99\xf1\xae\xc2\x16\xbf\xd7|K\xd9Z\x8a\x89\xf2`\xb8R\xda\xae\x9b\x8fd\xbf\x90I^9\x9fMyf\xaf{\x9ar\xe3\xf3\xd7\xb8\xb0\xa9\xc0\xd3t\xcd\xdd\x91\xa2f,-\xc0#\x91h4<\xfb\xc2\xbb\xf1PGr\xce)\x10e\x9b\xefi\x01\x05M\x13\xe97\xb4\x80O-p\xb4w\xb7z\x9a\x1c\xcf\x1f\xf07\x95U\xda<\xc5!\x84|\xa8\xd2\xb9\x05\xc3\x83SK\x89\xd2\x16\xce#\xd2\xaf}W\xb8\xd4\xfb\x82\x82\xd3g\x0e\xfd~\xb8V\xe8\x99\xd2\xab\xeay\x86MzB\x86O\x8f\xd5Em\xc8\xa5\xcc\'\xbc\xb0k\x8e\xbf\xd6\n\xd3^\xa4MO\xa6\x96\xa2\x0fp\xa8\xba\\[\xf4>k\xe2\xdf\x8fh~(\xb8a\x88\xec\xc6w\xf0\xb5c\x10\xb8H\xeeI\x81\xfc\xb8{%\xa7\xf4\x98\xc1FN\xa4\x06\xba\xbf\xbb.\x07\xafB\xb1\xd8\xb4~\xb8\xa4\x80~a\xed\x1fC=Uy\xa6-\xab\x0b\xf9\x1d\xe4Hh\xb7\xaa\xca\x95L\xc6R\xd6\xf2\xab\xb2\x04L\xc8\xeb\xe3\x0eY\x00\xae\xa0\x98\xc4\x96\xack\xcd\x17\xb5}\xb1w\xc2\x1c[Z\xec\xca\xe8ShV\x11\\Ab+\x98\xb1\xff\x8f\xd1\xc25\xad\x97(U\x8a*\x85\xff\x13\xf7\xa5\x8e\xb7F\xa4\xa8bu\x1bwy\xf1\xd0zk\xe7\xac7\xb0\x1e\x82\x89\xc0\xa1\\\x1f\x9f\rQ\xce\x93)\x7fbY\x18\x93^\x15%\xb9?\xfb\xa8Kg\xa5\x19\xa1\x90)\xc1n7\x9d\xf4\xf4\x0fb\x7fb\x7fJ\xba\x8e=aW\x8asnm\xea\xec\xd7\xfe\xd6\xdf*\x96\xd2D=s\xf1\x05\\\xff\\\x99\x08\xdd\xf9\xad\x1c\x96\xc3,\x14\xe26\xc3G\x02\xbd\xf8\xbez\x94\xc3\x81\x92\x19\\\xe4\xa4bg\x8dR\xa6\xde\xbe\x93^\xd5j\x0c\xae7\x8azEc\x87:.]>\xce\x14xf\n\xbe\xe6\x8dr\xa67\xf2\xb7\x96\x03\xdd@l\xf4Jkw\'\x02\xeb\xcd\x176\xf1;J\x0121`3~h\xbd7\x1a\xb1\x85)\x16\x01\xc9\xe2\x01\xc7\x19\xe2\x97\x85\x8b\x00\x96\xdb\x10\x08\xadM^\x07\xa9y\xef\xa7\x9c\xc2+\x07%\xb6\x12\x8d\x82\x7f\x9c\xb6\xd3\xee\xc1\xa34\xce\xfc\n\xb0c[u\x80\x02\xab@\xb6\xea\xad7\xddi\xb0\x08\xff\x83\x07\xfd\x19.\xf0j\x15[\xdb6\xd7\x8f^\xd8=y\x95\xa6\xf5\n\x05\xb7\xc5\x00\xe5Q\xd7h\xda\xad\xc1ba0\xa6\xaa\x8c+h|\xb2\xc3WBQ\xa6\xa0T\x17C&M\xd5r\xe1\xbd\xd0\xcaZ@6O%\xf8O\x9b\x8c\x18\x8cy4C\x91\xb6dK\xf7\xe9\xb1d\xd9\xfd()\xcfz\xa8\xe6\xcb\xec\xd7$fM\x06#\x94\x14\xc6\xdd\xb8\x04\xcb\xa3U2\x9f3\x0b\x8d/r\xc1;j\xcd\xad\x05]\xbc\x134\xff\x0b\x95\x08\x04({o\xd9\x8f\x97\xfe\xb7\xf8\xdf\xb9o\x84\x9b\'\xd3\xc4\x1d\xfaX\xe6#\x9b/1\x83\xef\x8aL\x85\x98\xba\x15\x7f\x14\x8b\rO?=d\x17\xe1\xe9\xa4\xe6\x16v\xf7#\xc9\xdc\xd1\xa2\xc3U\xdfGa\xa2\xefB\x8a( \x8e!Q\xb3\xfe\x02\xef\x96\xf28\xffQr\xedwb\xb1|\x86!Z\x1c\xf4\xa3J\xd0?^%4\x18siK\xb9J}\xa4\x07\xec\x9c\x12\x8dV\xb5\x1a\xd2\x9e\xe0\xcb\xef4\xfa\xa1\xdc\xd6p\x07\xf6B\xd0\x06\xa4z\xdf)9\x1dc\x0c\xd7A8\x90\x16{b\xd7X\xef\xc7>\x8ah*\xed!\r6\xbfB\xed\x8f\x01\xd54\xde2\xed\x12\x14B\x0c\x0c\x8a"qV\xed6\x1fo\x9c[\xfa`j\xebX\xbc\xee\xf7\xe6.\x84\xe9pL\x1f\xbe\x0e\xb8\xd6\x80L\xfd3\xfb;U\xf2\xcd\xe0\xdcq\xb3\xb9\xa4\x8a\xeez\xf8fc\xefw\xc5nF\x05J\xd0\xe5\xc8Mg\xca\x08t\xd4[\x987\x16_l\xa3\x1b2{Nxp-Y\xf1\xca(\xd0\x062\xfe^02=b\xad\xf0\xae\xe3\x85\xe8\xb5\xaaLw\x8b5@\xc7\x1e\xa1\x0b\xd2\xc1#\xf7\x83\x16\x1a\x8c\x87\xf5\xe9E+\x0b\xd9\xebA\x05\xf8\x1ci\xde\xed3)\xb5\x18Zn8\xef\\Y\x96\xc45\xa0\x0f;HE\xc4I\xe8|\xa9\xd9t*\xff\x83z]\x9a\xc3\xd1`6\xa9\xd7\xfc+\xf7\x15,\x85\x1aR\xde\x8e\xfbuR,K\xdbD\xb5nh\xa1yL\x1bC\xb7\x1eL\xb4\x00+\xb9\xd9\x0e8C\x17G\xd0\xfe\xde\x8f\xb19\x90\xad\xe9\xc6P\xdfK\x00g\xa7\xf7\xd3s&\x94RE\xdd\xa4\xbf\xf2\x96\xcbL\x14|\xcdz\xc5vfi\xce\x98\xf0\xf4T\xbe0~\xfc\xa6\xe9\x15\n\x11\x90\xe1\x02y\tb\x8aR2\xbdy!\xd4CK\xb7+tR\xab\xa6\xf3\x80\xd0d\x13\x04\xa9\xdb\xbf\xb2\xb54\xbd\xb2\x97#4w\xb8`\xadVTZ\x869k\xa9n\x99\xad\x04V\x11\x07\xe88@\x88W~f\xcb\x02\x11H\xac\xc5\xe5<\x84\x1fr\xb9\x0cM\x80\xc1k\xca\xe4\x9f\xbc\xebS\x91\x92\xfe\x17#\x83l\xb5yt6\t\x87N\xc9\xcf?d\x99\x11\x85P\x979\x8f}\x12J\x87\x1f\x13\xca\xde\xd0d\xd6@\x93\xb6\xf1g\xf3\x0f6\x18\xb1@\x0b\xe4$\xf2%~\x06\xd0\n\x08\x04\xba\xab\xe3\xe8\x85\x88\x90^bYCb\xbe\xe5x4&\xd3\n\xdf&\x9e\x1b\x9c2U\xd2\xe8\x9e[\xe6\x9f\x1c>`\x8e\xff\x0b;L\xf8SLT\x80\xdfV\xd7x\t\x961Q\xac\x92\xed*z+\r\xb7.H\xc3\x10\x84\x88<\xb3\x82\xb2\x10?e\xf5\xf9**\xee\xaf\xe6\x89\xf2Lg\x96$h\x8d!\xff\x10\x9e#\xce\t\x18\xe3\xbdz\xe8\xbe\xb11\x86x\xf6+M\\\\\x15\xf0\x8bj\x8f$)\xf2\xcc \x8cD\xfa\x12\n\xff\x99\xe9g\xb1\xba<\x0b\x87\xba\x8dI$\xb3\x00\x90nG\xbb\x94\x7fp\x91\xb5\xd3)\x06\x99\xd6\xa1\x96\x91\xa4\xf0.%\xec#}\x9e\xa2Q\x95\xa9\xca\x1bAG\x14\x980\xac~#\xbf5\xb8\x11J\xf3\x90\x00\xec\xdf\x86\xf0\xd4\x9d\x84\x15\xd6fX`x\xa6\xea\xa2e\xc0e7\xfb\xfa~\x8bF{\xa7\xddR\x8f\xb0\x13\xf9\xaf\x0f\xe5\x96*\xfcz\xd9\'\xc5\x80W\x8clN\xbf\xe5@\xdf,\xee2\x9ey\x06L\xe7P\\\xf9\x9a\x15}.?>\xc4\xea\xf6\x84\xc3\x81\xc4\xebT\rP\x13\xb8j"-\xba\xde4\xec\x82+I\r\xa9$ \xab\xe4\xc6^\xca\x8d\xd3\xe2\xe3d\xc4\x16\x7f\x1bQ\xd6i\x95y\x1a\xf8\xc1\xf0\xd1\xd4\xa1\xe7\xacb\x13>\xfed[\xcc\x95K\x16\xdf\xd5\'\xa9o\xfa\xb9|F\xc9\xd4\x9d*\xe54r\xbd\x13X\xbd(T\xf5\xfd\xa3\xa6\x05\xd0\xf0\xe2\xb8\xbf\xdbKqj{\xf5fXH\x18e\xb8N\x8e\xe1\x04\xe5V\xb3\x82\xf4m\x1b\x99\nS\x9cT%\x08\x19Z\xce\xab\x9b(\x88\xa6\x16*\xa8Bb\x17t\x18\xc0\xf7\n\x97\xba\xbe\xe5R\xf3\xce \x03\xc0\x9co\xbf\x19\x9c\x957\xde\xe4a[\xb3 x&\xd5\xbf\xf4"\xfd]L\\A6\x06%!X4\x11kY\x12\x0f\xd4r\xb3\xd2\xd9&\x94U\x957\xfe3\xd7\xc0\t\xb52\xd3\xc8(q\x15\xba\xba\xf8\xa5\x844D\xa9\x0bJ\x8c\xebh\xc9p|\xf1^R\xc7\xd7\xc6\xfc\xfa\\hL\xd6*\xa7\x9d%\xec\xc3\x9a\x9f\xd2\x89\xeb}\xad\xb4\r\x04\xa4S\x03\x0e:\x8aWt\x80GF@\x9b\xd7\xad\xcd%\xdb\xbc\xec\xcd\xb3\xf0\xa3:M\x80\xa5\xabC\xacBx\xb4[\xdb\xc0O\x97F?\xd7\x05W\xe4\x18\xe7a\xda\xdaR\xc0\xc9\x95|n\x7f\xca\x1e\xcb8L\xf4~\xf8\x9f.\xb7\xcc/\xa4A\x8b\x8f\xe9\x1a\x10\x83^\xc3\xdbj\x03t\x04\xb5\xb8\x14\xbe\xf9\xde{\x12X\xb7\xd2[m\xf5\xed9\xfc>x\x9en\xd3x\xd1U{\xca\xdd\xbb\xf9\xe9D\xbd(MIq\xb60\x81T\xae?hmQ\x97=\xa7\xdf\x17\x04\x13~!a\xc9m\xb0\xdb\x84M\xbf\xd9u6v!\x96\xd9\xc6\xa4\x18\xff6\x1c3\x19RC\xc1O\x1a\xbc_T\xb0M \xe2\xca\xcc\x07Ki\xcb\xb5\t\x1bgUu\xbe\xaa\xbf\xb7\x18l\xe8\x07\xc2U\xf6\x1b\xa3\x81\xd6\x86\xce\x93"~\x1d\xa4\x81M\xe3\x1e8>Lq\xb1\xb5\xb9\x06\x17^C\x1c\xbe\xe3\x85\nVe\xb93\xf45\xe0\xa5\xcfI\x83\xfc\r}\t\xc1\xcdK\x9d\xb3p\xf9\x82px\xc5;\xd4\x01\xd2\xb7\xe7\xc0\x10\xfc\xb4Y\x9c\xff\xf4\xeb\xa8H\'l\xcc\xef\xba\xca\x859\x83\xc9-L\x91\x95<W\xfeB\x96n\x0b\xbe\x88\x18\x8d\xa4\x87\xb4g,+\x06m\xa5Q\x91\xf0:\x9dz\x0e\x19v*K\xbemj\xac\x15\xe3\x8b(d>\x94\xfcs\x18\\\xcc\x99:\x8a\xaaN\x16\x0f\xa1"\xdc"M\x160o\xa6\xc3\x97\x85\xd9\x9b\xe4\xf0\xe3\xab\xd1\xf5(\x96\x15\x0e\xee\x13\x91\x89\xe5\xc3W>\xd5\x1b\xbf]Qe\xc3\x85\xe9\tRT\xc7\xe3\x99\rn.\xc1\xee\x8e\x1aI\x18\xc8$\x068\xddM\xd5\x80R\x0bGA/\x8bv\xc6\xa3=\xce\x86\x19\n\x90\xd7;\xa2\xc6@\xd0ucP\x85|\xb8\xf1I\x9d\xd4\x8f\'{\xd5\x0f\xc6\xbfD\x18\x94\x1a\xad\xa5\xd2\xdd\xd0q\xe9\xb0?\xdf\x8e]\xca\xd0\xb1\xb8\x82\xbd\xbc\xffj\xe3\xc4\x86}\xcf\xca\x08\x8d*\xdf\xbd\xc8k\x1a\xfd\xdf\xefn1\x91\xae\xad\xec\xf9\xaaF\xf30tg\xb7P\xe9O\x19>\xa9_\nn;\x10\x9d1\xaa\xa6\xc7\r`\x03\xcf6\xb0\xab\x88p\xc6U\xad\xb9j\xf3\xc8\x1fW\xf3{h\x8a\x08\x03\tf;/\xab\xd5\xa4\xa9\x995>\xd4}\xb5\xa6\xb6K\xd8\xc7\xeaC~\xe2\xaa\xa2S\x88eD\x899\xdb&\xed\xb5`8\xf5\xb6\x17\xfd\x89Q,_\xcb%\x83\xc0\xccU!\x1f\xb1\xfe\xb6.\xaa\xc3\xa2\x89E\x91Hl]\x8b\x13dK\x7f\xa7;C\xc6\xc0\x8dH\x01Al\x03:q\xa5\xe1\x87\x9d\x90"]F\xc2\xb2\x1fK\x7f\xdd\xcd\xe3\xc5&]!\x9d\xcd\xb0U\xd8\x94\x12Tv\xa0\xe7y\xf8I\x90\xf3\xf5]\x82\xc7&\x06/\xfb\xbbm\xe1\xc80\x06\xbe\x14\xbei\xf6\x9cu\x03G\x94\xaf\xba.T\xc9\x03\x15\x9c\x969v{FP\x13\xb6\x8b\xe2d\xaa\x04\x95\xc3\'\xfb\xb4\x19\x18\xa4\x13?\xfa\xc7;\xa9\xfb\x96\xce\xb7\tO\xef\xa0\xfc\xc8\xfc\x8fu <\x7f#\xd0S\x14H\xf3n6zj\x03\xfd\xc1\xe9v\xec[\xf8\x00\xfb\xff];\xf7\x7fus\xb1\x05\xb3\xfdPA=\xc4\xc3\x05X\xa1"\xa7^\x98\x13l!\x9f-\xc2\xc5\xfa\x8dU\xa7v\xcf\x03{Y\xa4\x01\xfa\x87\xa7!\x1c\x8bY_\xb4x\x1d\xd9\xed\xf4\x11\xce\xd6\xda\x05\t\xaf&\xd1\xec\xf6B\xdcx\x15{\xdf\xea\xef\xe3D\xd1\xbc=\xfbM\xc4\xf6\x93%\x94\xc0\x8903z\xcd\x8f\xe5\x908\x02\xc8\x00\x80;}\xd8c\xd4\x05\x16\xb0ADj\xc4\xfe\xfd\xa6\x18N\xce\xf8\xe3a*v<h\x05\x15\xf8O,\xb8=\xa0\xe8\\ii\x83B\xcf\xf7c\xc6\xf3\xfbw\xfa\xde\xd0\x9d\xa4\x83f\xcb\x05\x1e\x00\xf7\xcd\xa1<6\xf1\xa6\x1e>u\xae\x9a\x1d\x88\xc3I\x0ev\xfe\x18w\x96b\t\xbb\x04\x92M=\xe8\xafx\x04!=\xe9\x15l\xeb\x93w\xd9\xe5}5\x1f\x9c.\xeeS\x0e\xc4Vs\xd0\xfc\xb7\xdbZN;@\x9f~\xf8\xc6:\x03\t\xae\xe4\x8f\x8c\x7f\x17\xef\x1a\xb3/\xe2=\x9a\x1cs\xa5$3\x8a)\x9f\x8b+\xe6%.9\xb7\xb3Q^T/\xcb\xd9\xe0\x87\xef\x03\xa7o\xb2\xbc\x0e\x80\x86)\x04\xfcT&\xb4\x07?\xd1\xc2\x93\xb6\xec\xdeP\xef\x91\xb6\x90]=\xfbm\xdcw\xa6\xbb\xa2\xe5[x"\xc1\ns\xcb\xe5:\x9cKRp\xe6\xd8,\xb6\xd7$\xd6\x8f\x8fP\x9cm\\\x82S\x088\x0b\x06TN\n\x1b8/\x910\xa1\xf9\xa6? h-M\x06x!\xbd\x90\xfaA\xed\xa5\x18\x1d\x813nr\xed\xdc\x94\xcf2\x15\xaa\xc0<\x18\xde<\xfa>\xc4\x88@f\xa7\x9ed\'\xbd\xfc\x93\x81D{\xd6\x08\xe3\xd0[`\x02\xa5\xce1d\x85\x90\xddS26\xcb\xe3\xfddU\xb3\x81\xd3\xa3\xb6\xca\x84Q#\xb8\\\xe1\xba\xb3\x8a\xbd\x10a6\xa9%\x1c^\xbfv\x7fN7\xc1\xf4\xd8\t\xa1x\xff\x0fC\x140\x8fc\xd5\x150\xce\x9a9\xf42T\xd5c\x04:\xc3\xf0\xc2\xf1\xe2\x90\x83b\x7f\n\xce\x82\xdd0\xd3\x0c\xbche-\xfd\xb68\x15iq\xdf\x88\x7f\xa4\x96}<@\xc4\x17\x8d\xf6\xa8{\xc3\xb8\x1d"\xa8\x1d$\xe4\xa6\x03~\x04cZ\x8etq\x1a\xbd\x11$\xae\xb9t\xf0C\xfdyI\xe3\xce\x94\xa6\xfcps\x97a\r\xaf\xa5\x00\xbc\xa1A\x8f\xc3:~\xf4r\xa5s\xeb p\x9ap@9\xa8\xcd\xe8\x04\xf3N\x1eS\xde\x8f0"E\xd2q0R\xbb\x8dyn\xe1\xfd?\xb6\xf1 \xf8\x05`\xe2\xf2@\xa0\x1e\xb4\xfc\xec%}%\xc7\x9c[\x92\xea\xa8\xbf\xbe5\xf6XhB\xd9\xe9\x1d\x7f\xb4\x00\x0e\xcdF\xaa\xce\xba\xba\xc2\x8dc\xb9\x80\x92\x8f[\xcf/\tr\x1f?\x1d\xb7\xb9%\xc91VI\x02\xe5\x14\xb6\t\xeb\x00\xff\xfc\x002\x9a\x84\xf4\xbb\x80\xf4\n\xd3\x86\xee\xdb2\xbd\x13\x83\xa1\x87\xe2\xb328\xff\xd3\xc5\x91\xe4\x1ax\xcbG\x99\xd5\x8f\xe8\x08\xe24\xbb\xaf\x81\x1f\x90\xb0\xb7tM@U\xad4\x8c\xbb\xbd\xef\x87\xc9(\xf4\x0f\xa5\x11QD\xaaa\xa5h\xe7\x86\xf5T%\xf7\x0f\xa8\x0c\xf6w\xee\xb1\x85\x1cxF\x1e\x0f.\xdc\x93?w\xc2\xe4\x97\xb7\x9beq\xa9\xdcK\x97\xcec\xbf\xd4"\xe8CY\xe0E\xdd>"\xd7\x9f\x89\xc1\x08\xfb\xcb\x87\xf6\x82ja\xe4;\x8c\xd3\xfa\xd3h\x82.\xfeu\xdb\xbcP[\x84^\xd9u\xa1V\xcb\xa8b\x97\xad\'\xdbdeJ\xf2\xff\x1e\x0f\xc4<\xe2\xde/\x98\xe5\x9ez\xac\xeeOp5\xb2\x88C+\x04\xffA\xf9\xe8\xc7)\x04g\xb1\x1b\xfc\xb3i4D\xba\x8e\x18\xf4\xa7\xd6\x19\xcb\x8b\xf0=\x97\xc8\x8d:\x9f[a\xda^\x89TFV\xcfN\x87^o\xc3\xd1ZZ\x83Rr*\xa0\xb1\xedp\xd0@\xe9\xe7\x14v\xcb\xc2\xca\x9a\x1d\x05\'NL\xf1a%\xe9\xfb\xbf^\x96\x04o\xaff#\x97g\x14XS\x1eT\xed\xb8\xe7O\x12\xe5}wj\xf0\xb4k\xc3x\x8e\n\xdf\xea\x15E\x86\xef\xa9\r8J6\x91\x83\xd3\xc9\xfd\xaf\x86rex\x9f=S\xbc]\x87yy\xe3U\xe1/\xd7\x01H\xaf\x18\x10\xfa\x00\xbd%\x8c\xc5\xb8C\x08\xdf\xbb?\xfc}\xb4#\xcfN\x0e.<zl\xc5\x8d\x14\xa50\xa2\xeeL\xc1\xe8\x8e\x8eg=\x1fwO\xe2\x19\xe9+_GA\x1aq"\xcbk\xc6\xb3\x926J\xd1\x9e\xff\xb7\x7f\tr\x16AQ\x85\x9eW\xc0\x1d\xac=5\x839>\x9a\xbf\xeaN@@H\xea\xcd+\xb3\xa4\x0fCQ\xf5\x99\xd8M\x8d\x1e\x99\x86\xe0(OXH\x10\xdb\xad\xcbYy\r\xd7\x1c\xe3\xd2\xa3\xe6)\x06\xa9\xf4w\xce\xf5N\xca*\x0b\x7f\x9c0\xc8|\xe80\x042\xcf\x15\xeb\x0e\xe7\xe1\x0b\xb8Xu\x00\x1e\xb45\xfa5\xbd\tu\x90\x8c\xd4s>on\xc1"\xbd\x7f\xa1F\xa5\x05Y\xedG\xa9\xcb\xad;\x99\xe8\x85Q\xa5\xa4j&\xc6\xc1\x0b>\xda\x00V\xe9\xe0\xa8\x96\xbc\xaa\xdcv\xe3\tuU\xfe\xa2\xd4\xeb\xadt \x9b\x1f*\x80xLV\x02\xd0p\x11\x05\xf9?p\xc6\xda\x97\x85a\xaf\xb8\x1b\xc6H\x823\xb0\xd1i#\x92\xaa\xdc\xf8a\xe4\xea\x0b\xa8\n\xc6w\x1a9Z#\x80\x07\xdei\x8bNTW{\xfd0\x1aYj\xa7\xde\xaa\x0b\xe4\xa3h\x18Z\xffQ\xc25\xb8\xf3\x95\x83q&\xea\x1dO\xc2\xe6\xf6\x15\x1b\xcc \x03\xc8\xeb\xa8+\xba\x01N\x9a\xcd\x0bX\\\xa6\xa7\xc8\xe4J\xb6\x9c`\xc0\xb1\x88\xcb~\x0b\xad\x0f\xc6u\xfd:.T{\x81\x82\xb2\x87\xfe\x19r\r\xb8{\x9b\x99O\xf1\xb3\xaf\xe1\xebz\xf3n\xca|-n\xa5\xe7\x18\xfb\x14\x89\x00\x8f\xe6\x95~\xe4\xac.\xfc\x16\xd5\xeeu\xc37\x10\xd5\xe7\xe2c\xcb\x8e\xe3\xb2;>\x041\x9d\tC\xf4\x05\xd2\x11\xbft\xb4\x99"\x06\xd6\xfb\x16Y\xf6\x0c_\xb3\xdc\xb301\x86\x1aw\xa4\x88\x06)\x91vl\x1b#y\x12/\xbda\xbb\x93\xbd\x1ad\x1ax\xb4C\xa7\xca\x11\xe5\xd4\xb3\xa3zb3\xa2\x07\x8dsY\x92\xeaX\x82\xf0\x8d\xc1\xefcF*\x8a\xf5\x92\x8c\xbe\xf7\xbc\xa1\xf8\xc4\xaa\x82\nB\xde+\x961J\x97v|\x1c:\xe0/\x82\xfah\xd7a\xe6\x88\xb3\xf2\x86\x9f\xa9\xb6C\xc4\xbdy[:-\x82\xa2\xcd\xae\x9f\x1b\xefpf\x04\xe2\x9b\xfa\xb7A\xfc[\x89d\xfd\x8f\xf9`\xb2\xc1\xa1\xf5V\x13\x0f\xeb\xfc\x1a[\x042j\xdf\xd8\x91\xc9TS\x14 \xcb\xb0 \xfdV\xfc\x1dV\x87D\x8aGtCy>7L%\x0e\xd3\xd17\xd5=\xa0\x1a"4X\xf8E5\x14\xa2s\xd8\x93\xbe\x1e+\xd5K5\x99b\xf6\x93\x15k\x90\x8e\x1f\x19?\x8ah\xd3\xb1\xa8\xb6\xa8\xee\xa21\x02Z\x9aiP\xa0C\xe7\xb5\n\x90\x9bA\xc7D\x04\xf1\x81\x00!\xd4\xd3P\xff\xf0\x9f\tO3Z=\x06\xc1\x89\x81\x19@ZA!K\x83;l\x94-)J>\x05]\x14\x86\x91\x0bl\xc8#;\xfb\xe5\xef(\x16g\x83\x8b`\x99\xec)9\xf1\xbd\xc5\xf1/\xe9\xaa<^\xf8\xf5~\x84\x82N\xed}\x8d\x8b\xd1\x12Qp\xb6\x93\x9a\x11\x0b\x89\xa6\x02\xac\x9d\x9aJ=\xd6#\xa9\xeeg|\xe5|\xa7v\x05.*\x11\xf8\x98\xb1}lUeR\xb3\xc5\x95}\xf9u%\xc2\x0b\x92&7\xad\x93\xc0F\xf8\x0b5l\x15\xdc\xfaY\x00\x03\x83]\xf8\xa4\xff\xda\x0c\x82\xbe\xa1\xeeTa8\xe8\x1c=,\xab\xa5\xe0\xc5\xd6\x9a8\xdb\xa8\xdf\x0f7v\xeeMj|\xb9\xf2y?\x10s\xfd\n GQ7\xe3\x10\x80\xeby\xf5^\xc4\xec\xda\x89\x02\xb8\xaa\xb4\xfa\xe5;)\xcdPZFvY\x8b\x10\xf34B\xb3\xc7\xbc\xf35z\xb9\x08\x9f>\xb0\xf9dj\xfc\xce8TE\xc6\xeer\xc6\xda\x03s$\x95\xdc\x07.\x14-\xfb\x9d\x03\x0e}%\x0e\xcbzu1C\xe4-\x1a\x88D\x1c\xa1\xd6\x11B\xe7\x1cHj:wk\xd4\x17u\xbd\x8c\x99h\x93\x04~\xb2\x1d\x014g#E\xd1\x0b\xac\xcbRY\x0f\xc8\x12u\xbdcI\xe8h\x0e\xb5\xcf\xfb\xd9\xeczQ\xf2\xd38\x05\x85=v}^\xb5\xd2\x99\xfc\xcf\xf2\xf4\x90\x9dF\x9c\xe2\xc9\xb8\xfd{F\xe3g\x9c\xfaW`@?32\xa7\x15b\xe8w\x07z\x1e\xd8\xbd\xd8C\x91\r>\x8a`N=q\x1c\x1c\xf2\xd1\x90\xd6\x87<\x00\x9e\x03h\x1eC(\xf9q\xb0}\xa9\x1f\x85\xbeN\x95\xb5\x00\x11\xbaw\n\x87\xe2\xd3\x95\x9d\xed\x8c\xca\xc6\x80\xe0\xca\x82Y\x1cg\t\xa5}r\xdd\xf8\x9a.\x91(\x99x\xae\x87UY\xa2~\xad\xf1\xcfZ\x86!\x04j\xb1a\x93v\xf5Z$D\x93\xc8\xf0\x08\xf2\xfc4iA\x07\xe1>\x8d\xabP\x93\x1fz/\xaf\r\x08\xeb\xbd\x16\x08\x0e\xab\xa4"M\xac\x0e\xae\xcfM^\xf8!\x98\xb9\x8e\xe5d\xa9N\x84\x8d@\x91e\xa4\xa8\xed\x9d\xe5\x04\xe3\xd1\x1d\x96\xbf\xa8\x13\xd9\t\xd7=\xd6\xd6ZW\xe2<\x1c\xfa$\xd1>f\\\xad\x89V}\xa6\x89\xff\xe5\xbe\x0e\x11\x0c\xc9B9&\x1f\xb1s\x93\x952\xcc\xa6xM\x93]-\x00\xf8\xecE\xafm\xc1 \x971tQ\xa7t\xe6 \xc4t\xe6\x15\xd6\xdem\x16\xdaX\xcbi\xf7\x87=\t\xe4\x0b\x8cP\xa1v\xa6\x01\'\xd3\x0b.>\xca\xa5}\x82'
    assert kp.verify(b'a', sig)
    assert kp.sign(b'a') == sig


def test5():
    def judge(para):
        kp = KeyPair.gen(para)
        msg = randbytes(100)
        sig = kp.sign(msg)
        assert not kp.verify(msg, randbytes(100))
        sig1 = sig
        for i in range(20):
            pos = randint(0, len(sig))
            sig1 = sig1[:pos] + randbytes(1) + sig1[pos+1:]
        assert not kp.verify(msg, sig1)
        sig2 = sig[:-10] + randbytes(10)
        assert not kp.verify(msg, sig2)
        sig3 = randbytes(10) + sig[10:]
        assert not kp.verify(msg, sig3)
    _for_all(judge)